//**********************************************************************/
//* Basic Data Center Room Floor Tile Dimensions/Definitions
//**********************************************************************/
#declare fCeilingTileWidth         = 2.0;
#declare fCeilingTileDepth         = 4.0;
#declare fCeilingTileHeight        = 0.125;
#declare fCeilingTileBorderWidth   = 0.5/12;               //* Ceiling Tile Border Width
#declare fCeilingTileBorderHeight  = 0.125/12;             //* Ceiling Tile Border Width
#declare vCeilingTileTexture       = texture {finish{ambient 0.65 diffuse 0.25} pigment{White*0.90} normal { bumps 0.4 scale 0.05 }};
#declare vCeilingLightTexture      = texture {finish{ambient 0.95 diffuse 0.50} pigment{White*1.00}};
#declare vCeilingTileBorderTexture = texture {finish{ambient 0.75 diffuse 0.85} pigment{White*0.95}};

#include "Sprinkler.inc" 
#include "CeilingVent.inc"
#include "SmokeDetector.inc"

//**********************************************************************/
//* Ceiling Tile Definition
//**********************************************************************/
#declare oCeilingTile =
  object {
    box {< 0, 0, 0>< fCeilingTileWidth, fCeilingTileHeight, fCeilingTileDepth> texture{vCeilingTileTexture}}
    }

#declare oCeilingLight =
  object {
    box {< 0, 0, 0>< fCeilingTileWidth, fCeilingTileHeight, fCeilingTileDepth> texture{vCeilingLightTexture}}
    }

#declare oCeilingFrame =
  object {
    union {
      #local dz = 0;
      #while (dz <= fCenterDepth)
        box {< 0,-fCeilingTileBorderHeight,-fCeilingTileBorderWidth>< fCenterWidth, 0, fCeilingTileBorderWidth> translate dz*z}
        #local dz = dz + fCeilingTileDepth;
      #end
      #local dx = 0;
      #while (dx <= fCenterWidth)
        box {<-fCeilingTileBorderWidth,-fCeilingTileBorderHeight, 0>< fCeilingTileBorderWidth, 0, fCenterDepth> translate dx*x}
        #local dx = dx + fCeilingTileWidth;
      #end
      }
    texture { vCeilingTileBorderTexture }
    }
    
#declare oCeiling =
  object {
    union {
      object { oCeilingFrame }
      #local dx = 0.0;
      #while (dx < fCenterWidth)
        #local dz = 0.0;
        #while (dz < fCenterDepth)
          object {
            #if ((mod(dx,8) = 2) & (mod(dz,8) = 4))
              oCeilingLight
            #else
              #if ((mod(dx,16) = 6) & (mod(dz,16)= 4))
                  CeilingVent()
              #else
                oCeilingTile
              #end  
            #end  
            translate <dx, 0, dz>
            }
          #if ((mod(dx,8) = 6) & (mod(dz,8)= 0))
            object {
              Sprinkler()
              translate <dx+fCeilingTileWidth/2,0,dz+fCeilingTileDepth/2>
              }
          #end
          #if ((mod(dx,8) = 2) & (mod(dz,8)= 0))
            #if (mod(int(dx/8)+int(dz/8),2) = 0)
              object {
                SmokeDetector()
                translate <dx+fCeilingTileWidth/2,0,dz+fCeilingTileDepth/2>
                }
            #end    
          #end
          #local dz = dz + fCeilingTileDepth;
        #end
        #local dx = dx + fCeilingTileWidth;
      #end 
      }
    translate fCenterHeight*y
    }
