#macro Cushion(fWidth,fHeight,fDepth,fRadius1,fRadius2,fRadius3,sMap)

  #local oCushion =
    object {
      union {
        //* Front Bottom Edge
        torus {fRadius2-fRadius3,fRadius3 rotate 90*z translate <fRadius3,fRadius2,fRadius2>}
        torus {fRadius2-fRadius3,fRadius3 rotate 90*z translate <fWidth-fRadius3,fRadius2,fRadius2>}
        cylinder{<fRadius3,0,0><fWidth-fRadius3,0,0>,fRadius2 translate <0,fRadius2,fRadius2>}
        cylinder{<0,0,0><fWidth,0,0>,fRadius2-fRadius3 translate <0,fRadius2,fRadius2>}
        //* Back Bottom Edge
        torus {fRadius2-fRadius3,fRadius3 rotate 90*z translate <fRadius3,fRadius2,fDepth-fRadius2>}
        torus {fRadius2-fRadius3,fRadius3 rotate 90*z translate <fWidth-fRadius3,fRadius2,fDepth-fRadius2>}
        cylinder{<fRadius3,0,0><fWidth-fRadius3,0,0>,fRadius2 translate <0,fRadius2,fDepth-fRadius2>}
        cylinder{<0,0,0><fWidth,0,0>,fRadius2-fRadius3 translate <0,fRadius2,fDepth-fRadius2>}
        //* Front Top Edge
        torus {fRadius1-fRadius3,fRadius3 rotate 90*z translate <fRadius3,fHeight-fRadius1,fRadius1>}
        torus {fRadius1-fRadius3,fRadius3 rotate 90*z translate <fWidth-fRadius3,fHeight-fRadius1,fRadius1>}
        cylinder{<fRadius3,0,0><fWidth-fRadius3,0,0>,fRadius1 translate <0,fHeight-fRadius1,fRadius1>}
        cylinder{<0,0,0><fWidth,0,0>,fRadius1-fRadius3 translate <0,fHeight-fRadius1,fRadius1>}
        //* Back Top Edge
        torus {fRadius1-fRadius3,fRadius3 rotate 90*z translate <fRadius3,fHeight-fRadius1,fDepth-fRadius1>}
        torus {fRadius1-fRadius3,fRadius3 rotate 90*z translate <fWidth-fRadius3,fHeight-fRadius1,fDepth-fRadius1>}
        cylinder{<fRadius3,0,0><fWidth-fRadius3,0,0>,fRadius1 translate <0,fHeight-fRadius1,fDepth-fRadius1>}
        cylinder{<0,0,0><fWidth,0,0>,fRadius1-fRadius3 translate <0,fHeight-fRadius1,fDepth-fRadius1>}
        //* Bottom Left Seam
        cylinder{<fRadius3,fRadius3,fRadius2><fRadius3,fRadius3,fDepth-fRadius2>,fRadius3}
        //* Bottom Right Seam
        cylinder{<fWidth-fRadius3,fRadius3,fRadius2><fWidth-fRadius3,fRadius3,fDepth-fRadius2>,fRadius3}
        //* Top Left Seam
        cylinder{<fRadius3,fHeight-fRadius3,fRadius1><fRadius3,fHeight-fRadius3,fDepth-fRadius1>,fRadius3}
        //* Top Right Seam
        cylinder{<fWidth-fRadius3,fHeight-fRadius3,fRadius1><fWidth-fRadius3,fHeight-fRadius3,fDepth-fRadius1>,fRadius3}
        //* Left Front Seam
        cylinder{<fRadius3,fRadius2,fRadius3><fRadius3,fHeight-fRadius1,fRadius3>,fRadius3}
        //* Right Front Seam
        cylinder{<fWidth-fRadius3,fRadius2,fRadius3><fWidth-fRadius3,fHeight-fRadius1,fRadius3>,fRadius3}
        //* Left Rear Seam
        cylinder{<fRadius3,fRadius2,fDepth-fRadius3><fRadius3,fHeight-fRadius1,fDepth-fRadius3>,fRadius3}
        //* Right Rear Seam
        cylinder{<fWidth-fRadius3,fRadius2,fDepth-fRadius3><fWidth-fRadius3,fHeight-fRadius1,fDepth-fRadius3>,fRadius3}
        //* Back Panel
        box{<fRadius3,fRadius2,fDepth-fRadius3><fWidth-fRadius3,fHeight-fRadius1,fDepth>} 
        //* Front Panel
        box{<fRadius3,fRadius2,0><fWidth-fRadius3,fHeight-fRadius1,fRadius3>}
        //* Right Panel
        box{<fWidth-fRadius3,fRadius3,fRadius2><fWidth,fRadius2,fDepth-fRadius2>} 
        box{<fWidth-fRadius3,fRadius2,fRadius3><fWidth,fHeight-fRadius1,fDepth-fRadius3>}
        box{<fWidth-fRadius3,fHeight-fRadius1,fRadius1><fWidth,fHeight-fRadius3,fDepth-fRadius1>}
        //* Left Panel 
        box{<0,fRadius3,fRadius2><fRadius3,fRadius2,fDepth-fRadius2>} 
        box{<0,fRadius2,fRadius3><fRadius3,fHeight-fRadius1,fDepth-fRadius3>}
        box{<0,fHeight-fRadius1,fRadius1><fRadius3,fHeight-fRadius3,fDepth-fRadius1>}
        //* Bottom Panel
        box{<fRadius3,0,fRadius2><fWidth-fRadius3,fRadius3,fDepth-fRadius2>}
        //* Top Panel
        box{<fRadius3,fHeight-fRadius3,fRadius1><fWidth-fRadius3,fHeight,fDepth-fRadius1>}
        }
      }

  oCushion
  
#end


#macro ArmBend(fRadius,fAngle,fArmDepth,fArmHeight,fArmRadius)
  #local oArmBend =
    object {
      intersection {
        union {
          difference {
            cylinder{<0,-fArmDepth/2,0><0, fArmDepth/2,0>,fRadius-fArmRadius}
            cylinder{<0,-(fArmDepth/2+0.1),0><0, (fArmDepth/2+0.1),0>,fRadius-(fArmHeight-fArmRadius)}
            }
          torus{fRadius-fArmRadius,fArmRadius}
          torus{fRadius-(fArmHeight-fArmRadius),fArmRadius}
          }
        object {Wedge(fAngle)}
        }
      rotate -90*x
      rotate -90*y    
      } 
  oArmBend 
#end

#macro ArmSegment(fArmLength,fArmDepth,fArmHeight,fArmRadius)
  #local oArmLeg =
    object {
      union {
        cylinder{<0,0,0><0,0,fArmLength>,fArmRadius translate fArmRadius*y}
        box{<-fArmRadius,fArmRadius,0><fArmRadius,fArmHeight-fArmRadius,fArmLength>}
        cylinder{<0,0,0><0,0,fArmLength>,fArmRadius translate (fArmHeight-fArmRadius)*y}
        }
      }
  oArmLeg     
#end

      
#macro ChairArm()
  #local fArmHeight    = 1.00;
  #local fArmDepth     = 0.50;
  #local fArmRadius    = 0.25;
  
#end

#macro Chair(sMap)
  #local fRadiusEdge   = 0.25;
  #local fRadiusCenter = 3.0;
  #local fRadiusLeg    = 0.75;
  #local fRadiusInner  = 0.5;
  #local fHeight       = 2.0;
  #local fLegLength    = 12;
  #local fRadiusInnerXOffset  = fRadiusInner+fRadiusLeg;
  #local fRadiusInnerZOffset  = sqrt(f_sqr(fRadiusInner+fRadiusCenter)-f_sqr(fRadiusInner+fRadiusLeg));
  #local fLegAngle     = degrees(asin((fRadiusInner+fRadiusLeg)/(fRadiusInner+fRadiusCenter)));
  #local fAngleInner   = 90-fLegAngle; 
  #local fWheelRadius  = 1.0;
  #local fWheelWidth   = 1.5;
  #local fWheelHeight  = 2.5;
  #local fWheelAxleRadius = 0.25;
  #local fWheelPivotRadius = 0.50;
  #local fFenderThickness = 0.0625;
  #local fFenderRadius = 1.1875;
  #local fFenderWidth  = 1.5;
  #local fWheelPivotHeight = fWheelHeight-fWheelRadius;
  #local fPostBaseRadius = 1.5;
  #local fPostBaseHeight = 6;
  #local fPostRadius   = 1.0;
  #local fPostHeight   = 12;
  #local fCushionRadius1 = 1.00;
  #local fCushionRadius2 = 0.50;
  #local fCushionRadius3 = 0.500;
  #local fCushionWidth   = 22.00;
  #local fCushionHeight  = 3.00;
  #local fCushionDepth   = 20.00;
  #local fBackWidth      = 22.00;
  #local fBackHeight     =  3.00;
  #local fBackDepth      = 20.00;
  #local fBackRadius1    =  1.00;
  #local fBackRadius2    =  0.25;
  #local fBackRadius3    =  0.0625;
  #local fBackAngle      =  85;
  #local fArmDepth       = 0.75;
  #local fArmHeight      = 1.50;
  #local fArmRadius      = fArmDepth/2;
  #local tArmTexture     = texture{pigment{White*0.15} 
                            normal { bumps 0.04 scale 0.0005 }
                            finish { phong 0.5 }
                            };
  #local fBendRadius     = 3.0;
  #local fBend2Radius    = 2.0;
  #local fBend2Angle     = 90;
  #local fBend3Radius    = 2.0;
  #local fBend3Angle     = 95;
  #local fArmLeg1Length  = 8;
  #local fArmLeg2Length  = 6;
  #local fArmLeg3Length  = 6;
  
  #local fArmSeg1Length  = 6.00;
  #local fArmBend1Radius = 2.00;
  #local fArmBend1Angle  = 95;
  #local fArmSeg2Length  = 8.00;
  #local fArmBend2Radius = 3.00;
  #local fArmBend2Angle  = 85;
  #local fArmSeg3Length  = 4.00;
  #local fArmBend3Radius = 2.00;
  #local fArmBend3Angle  = 95;
  #local fArmSeg4Length  = 12.00;
  #local fArmRestDepth   =  3.00;
  #local fArmRestLength  = 12.00;
  #local fArmRestHeight  = fArmDepth;
  #local fArmRestRadius  = 1.0;
  #local fArmRestOffset  = 4.00;
                                
  #local tCushionTexture  = texture {
                              pigment{
                                image_map {
                                  gif sMap 
//                                  gif "Zapotec" 
                                  map_type 0        
                                  interpolate 2
                                  }
                                }
                              };                              
  #local tPedestalTexture = texture{pigment{White*0.10} 
                            normal { bumps 0.04 scale 0.0005 }
                            finish { phong 0.5 }
                            };
  #local tPistonTexture   = T_Chrome_3C;
  #local oPivot =
    object {
      difference {
        cylinder {<0,0,0><0,fWheelPivotHeight,0>,fWheelPivotRadius}
        cylinder {<-fFenderWidth/2,0,0><fFenderWidth/2,0,0>,fFenderRadius translate -fWheelPivotRadius*z} 
        }
      }

  #local oCastor =
    object {
      union {
        sphere{<0,0,0>,fWheelRadius scale <0.25,1,1> translate -fWheelWidth/2*x}
        cylinder{<-fWheelWidth/2,0,0><-0.25,0,0>,fWheelRadius}
        cylinder{<-fWheelWidth/2,0,0><fWheelWidth/2,0,0>,fWheelAxleRadius}
        cylinder{< fWheelWidth/2,0,0>< 0.25,0,0>,fWheelRadius}
        sphere{<0,0,0>,fWheelRadius scale <0.25,1,1> translate  fWheelWidth/2*x}
        }
      translate -fWheelPivotRadius*z  
      }

  #local oFenderMask =
    object {
      difference {
        cylinder{<-0.001,0,0><fFenderWidth+0.001,0,0>,fFenderRadius+0.001}
        cylinder{<-0.1,0,0><fFenderWidth+0.1,0,0>,(fFenderRadius-fFenderThickness)+0.001}
        }
      }

  #local oFender =
    object {
      intersection {
        union {
          difference {
            object {
              difference {
                cylinder{<0,0,0><fFenderWidth,0,0>,fFenderRadius+0.1}
                cylinder{<-0.1,0,0><fFenderWidth+0.1,0,0>,fFenderRadius-fFenderThickness}
                }
              }
            union {
              cylinder{<0,0,-(fFenderRadius+0.1)><0,0,fFenderRadius+0.1>,fRadiusEdge }
              cylinder{<0,0,-(fFenderRadius+0.1)><0,0,fFenderRadius+0.1>,fRadiusEdge translate fFenderWidth*x}
              }
            }
          object {  
            union {
              cylinder{<0,0,-(fFenderRadius+0.1)><0,0,fFenderRadius+0.1>,fRadiusEdge translate <fRadiusEdge,fRadiusEdge,0>}
              cylinder{<0,0,-(fFenderRadius+0.1)><0,0,fFenderRadius+0.1>,fRadiusEdge translate <fFenderWidth-fRadiusEdge,fRadiusEdge,0>}
              }
            }  
          }
        object{oFenderMask} 
        } 
      clipped_by{plane{-y,0}}    
      translate -fFenderWidth/2*x
      translate -fWheelPivotRadius*z  
      }
      
  #local oWheel =
    object {
      union {
        object {oCastor}
        object {oFender}
        object {oPivot}
        }
      rotate 90*y
      texture{tPedestalTexture}  
      }
      
  #local oCenter =
    object {
      union {
        cylinder{<0,0,0><0,fHeight,0>,fRadiusCenter-fRadiusEdge}
        cylinder{<0,0,0><0,fHeight-fRadiusEdge,0>,fRadiusCenter}
        torus{fRadiusCenter-fRadiusEdge,fRadiusEdge translate (fHeight-fRadiusEdge)*y}
        }
      }
      
  #local oLegEnd =
    object {
      union {
        cylinder{<0,0,0><0,fHeight,0>,fRadiusLeg-fRadiusEdge}
        cylinder{<0,0,0><0,fHeight-fRadiusEdge,0>,fRadiusLeg}
        torus{fRadiusLeg-fRadiusEdge,fRadiusEdge translate (fHeight-fRadiusEdge)*y}
        object {oWheel translate -(fWheelHeight-fWheelRadius)*y }
        }
      }
      
      
  #local oLeg =
    object {
      union {
        object {
          union {
            box {<-fRadiusLeg,0,0>< fRadiusLeg,fHeight-fRadiusEdge,fLegLength>}
            box {<-(fRadiusLeg-fRadiusEdge),0,0>< (fRadiusLeg-fRadiusEdge),fHeight,fLegLength>}
            cylinder{<-(fRadiusLeg-fRadiusEdge),fHeight-fRadiusEdge,0><-(fRadiusLeg-fRadiusEdge),fHeight-fRadiusEdge,fLegLength>,fRadiusEdge}
            cylinder{< (fRadiusLeg-fRadiusEdge),fHeight-fRadiusEdge,0>< (fRadiusLeg-fRadiusEdge),fHeight-fRadiusEdge,fLegLength>,fRadiusEdge}
            object {oLegEnd}
            }               
          translate -fLegLength*z
          }
        object {
          intersection {
            union {
              difference {
                cylinder{<0,0,0><0,fHeight-fRadiusEdge,0>,fRadiusLeg+fRadiusInner}
                cylinder{<0,-0.1,0><0,fHeight-fRadiusEdge+0.1,0>,fRadiusInner}
                }
              difference {
                cylinder{<0,0,0><0,fHeight,0>,fRadiusLeg+fRadiusInner}
                cylinder{<0,-0.1,0><0,fHeight+0.1,0>,fRadiusInner+fRadiusEdge}
                }
              torus{fRadiusInner+fRadiusEdge,fRadiusEdge translate (fHeight-fRadiusEdge)*y}
              }  
            object {Wedge(fAngleInner) }
            }
          translate -(fRadiusCenter+fRadiusInner)*z 
          rotate fLegAngle*y 
          }  
        object {
          intersection {
            union {
              difference {
                cylinder{<0,0,0><0,fHeight-fRadiusEdge,0>,fRadiusLeg+fRadiusInner}
                cylinder{<0,-0.1,0><0,fHeight-fRadiusEdge+0.1,0>,fRadiusInner}
                }
              difference {
                cylinder{<0,0,0><0,fHeight,0>,fRadiusLeg+fRadiusInner}
                cylinder{<0,-0.1,0><0,fHeight+0.1,0>,fRadiusInner+fRadiusEdge}
                }
              torus{fRadiusInner+fRadiusEdge,fRadiusEdge translate (fHeight-fRadiusEdge)*y}
              }  
            object {Wedge(fAngleInner) rotate -fAngleInner*y }
            }
          translate -(fRadiusCenter+fRadiusInner)*z 
          rotate -fLegAngle*y 
          }  
        }  
      }
      
  #local oPost =
    object {
      union {
        cylinder{<0,0,0><0,fPostBaseHeight,0>,fPostBaseRadius translate (fHeight)*y texture{tPedestalTexture}}
        cylinder{<0,0,0><0,fPostHeight,0>,fPostRadius translate (fHeight)*y texture{tPistonTexture}}
        }
      }
      
  #local oCushion =
    object {
      Cushion(fCushionWidth,fCushionHeight,fCushionDepth,fCushionRadius1,fCushionRadius2,fCushionRadius3,sMap)
      texture{tCushionTexture scale 0.25}
      }
      
  #local oBack =
    object {    
      Cushion(fBackWidth,fBackHeight,fBackDepth,fBackRadius1,fBackRadius2,fBackRadius3,sMap)
      translate -fBackDepth*z
      rotate fBackAngle*x
      translate fCushionHeight*y
      texture{tCushionTexture scale 0.25}
      }

  #local oArmCap =
    object {
      union {                                                                    
        object { sphere  {<0,fArmRadius,0>,fArmRadius}}
        object { cylinder{<0,fArmRadius,0><0,fArmHeight-fArmRadius,0>,fArmRadius}}
        object { sphere  {<0,fArmHeight-fArmRadius,0>,fArmRadius}} 
        }
      }
      
  #local oArmRestCorner =
    object {
      union {
        torus{fArmRestRadius-fArmRadius,fArmRadius}
        cylinder{<0,-fArmRadius,0><0,fArmRadius,0>,fArmRestRadius-fArmRadius}
        }
      }
      
  #local oArmRest =
    object {
      union {
        object { oArmRestCorner translate <-(fArmRestDepth/2-fArmRestRadius),fArmRadius,fArmRestRadius>}
        object { oArmRestCorner translate < (fArmRestDepth/2-fArmRestRadius),fArmRadius,fArmRestRadius>}
        object { oArmRestCorner translate <-(fArmRestDepth/2-fArmRestRadius),fArmRadius,fArmRestLength-fArmRestRadius>}
        object { oArmRestCorner translate < (fArmRestDepth/2-fArmRestRadius),fArmRadius,fArmRestLength-fArmRestRadius>}
        object { cylinder {<-(fArmRestDepth/2-fArmRestRadius),fArmRadius,fArmRadius>< (fArmRestDepth/2-fArmRestRadius),fArmRadius,fArmRadius>,fArmRadius}}
        object { cylinder {<-(fArmRestDepth/2-fArmRestRadius),fArmRadius,fArmRestLength-fArmRadius>< (fArmRestDepth/2-fArmRestRadius),fArmRadius,fArmRestLength-fArmRadius>,fArmRadius}}
        object { cylinder {<-(fArmRestDepth/2-fArmRadius),fArmRadius,fArmRestRadius><-(fArmRestDepth/2-fArmRadius),fArmRadius,fArmRestLength-fArmRestRadius>,fArmRadius}}
        object { cylinder {< (fArmRestDepth/2-fArmRadius),fArmRadius,fArmRestRadius>< (fArmRestDepth/2-fArmRadius),fArmRadius,fArmRestLength-fArmRestRadius>,fArmRadius}}
        object { box{<-(fArmRestDepth/2-fArmRestRadius),0,fArmRadius>< (fArmRestDepth/2-fArmRestRadius),2*fArmRadius,fArmRestLength-fArmRadius>}}
        object { box{<-(fArmRestDepth/2-fArmRadius),0,fArmRestRadius>< (fArmRestDepth/2-fArmRadius),2*fArmRadius,fArmRestLength-fArmRestRadius>}}
        }
      }

  #local oArm =
    object {
      union {
        object { ArmBend(fArmBend2Radius,90,fArmDepth,fArmHeight,fArmRadius) rotate 180*x translate <0,fArmBend2Radius,fArmBend2Radius>}
        object { ArmSegment(fArmSeg2Length,fArmDepth,fArmHeight,fArmRadius) translate <0,0,fArmBend2Radius>}
        object { ArmBend(fArmBend1Radius,90,fArmDepth,fArmHeight,fArmRadius) rotate 90*x translate <0,fArmBend1Radius,fArmBend2Radius+fArmSeg2Length>}
        object { ArmSegment(fArmSeg3Length,fArmDepth,fArmHeight,fArmRadius) rotate -90*x translate <0,fArmBend2Radius,fArmHeight>}
        object { ArmBend(fArmBend3Radius,90,fArmDepth,fArmHeight,fArmRadius) rotate -90*x translate <0,fArmBend2Radius+fArmSeg3Length,fArmBend3Radius>}
        object { ArmSegment(fArmSeg4Length,fArmDepth,fArmHeight,fArmRadius) translate <0,fArmBend2Radius+fArmSeg3Length+fArmBend3Radius-fArmHeight,fArmBend3Radius>}
        object { ArmSegment(fArmSeg1Length,fArmDepth,fArmHeight,fArmRadius) rotate -90*x translate <0,fArmBend1Radius,fArmHeight+fArmBend2Radius+fArmSeg2Length+fArmBend1Radius-fArmHeight>}
        object { 
          union {
            torus{fArmHeight-fArmRadius,fArmRadius}
            cylinder{<0,-fArmRadius,0><0 fArmRadius,0>,fArmHeight-fArmRadius}
            }
          rotate 90*z
          clipped_by{plane{y,0}}
          translate<0,fArmBend2Radius+fArmSeg3Length+fArmBend3Radius,fArmBend3Radius+fArmSeg4Length>
          }
        object { oArmRest translate <0,fArmBend2Radius+fArmSeg3Length+fArmBend3Radius-1*fArmRadius,fArmRestOffset>}
        }
      Shear_Trans(x,y-tan(radians(5))*z,z)
      }
                
  #local oSeat =
    object {
      union {
        object {oCushion}
        object {oBack}
        object {oArm translate (fCushionWidth+fArmRadius)*x texture{tArmTexture}}
        object {oArm translate (             -fArmRadius)*x texture{tArmTexture}}
        }
      translate <-fCushionWidth/2,0,-fCushionDepth/2>
      }
       
  #local oPedestal =
    object {                      
      union {
        object {oPost}
        object {oCenter}
        object {oLeg rotate 0*72*y}
        object {oLeg rotate 1*72*y}
        object {oLeg rotate 2*72*y}
        object {oLeg rotate 3*72*y}
        object {oLeg rotate 4*72*y}
        }
      translate fWheelHeight*y
      }
      
  #local oChair =
    object {
      union {
        object {oSeat rotate -5*x translate (fHeight+fPostHeight)*y}
        object {oPedestal texture{tPedestalTexture}}
        }
      scale 1/12
      }                     
      
  oChair
#end