#macro Clock(fHour,fMinute,fSecond)
  #local fRadius            = 8.0;
  #local fDepth             = 1.75;
  #local fDialRadius        = 6.0;
  #local tClockTexture      = pigment{Black};
  #local tDialTexture       = pigment{White};
  #local fHourHandWidth     = 0.125;
  #local fHourHandHeight    = fDialRadius*0.7;
  #local fHourHandDepth     = 0.0625;
  #local fHourHandYOffset   = fHourHandHeight*0.20;
  #local fHourHandZOffset   = 0.1250;
  
  #local fMinuteHandWidth   = 0.1000;
  #local fMinuteHandHeight  = fDialRadius*1.1;
  #local fMinuteHandDepth   = 0.0625;
  #local fMinuteHandYOffset = fMinuteHandHeight*0.20;
  #local fMinuteHandZOffset = 0.250;
  
  #local fSecondHandWidth   = 0.0750;
  #local fSecondHandHeight  = fDialRadius*1.2;
  #local fSecondHandDepth   = 0.0625;
  #local fSecondHandYOffset = fMinuteHandHeight*0.30;
  #local fSecondHandZOffset = 0.375;
  
  #local fHourMarkWidth     = 0.125;
  #local fHourMarkHeight    = fHourMarkWidth*5;
  #local fHourMarkYOffset   = fDialRadius-0.25;
  
  #local fMinuteMarkWidth   = fHourMarkWidth/2;
  #local fMinuteMarkHeight  = fMinuteMarkWidth*5;
  #local fMinuteMarkYOffset = fDialRadius-0.25;
  
  #local fNumberYOffset     = fDialRadius*0.75;
  
  #local oHourMark =
    object {
      box{<-fHourMarkWidth,0,0>< fHourMarkWidth,-fHourMarkHeight,-0.002>}
      pigment{Black}
      }  
  
  #local oMinuteMark =
    object {
      box{<-fMinuteMarkWidth,0,0>< fMinuteMarkWidth,-fMinuteMarkHeight,-0.002>}
      pigment{Black}
      }  
  
  #local oHourHand =
    object {
      box{<-fHourHandWidth,0,0>< fHourHandWidth,fHourHandHeight,fHourHandDepth>}
      translate <0,-fHourHandYOffset,-fHourHandZOffset>
      rotate -((fHour+fMinute/60)/12)*360*z
      }
  
  #local oMinuteHand =
    object {
      box{<-fMinuteHandWidth,0,0>< fMinuteHandWidth,fMinuteHandHeight,fMinuteHandDepth>}
      translate <0,-fMinuteHandYOffset,-fMinuteHandZOffset>
      rotate -(fMinute/60)*360*z
      }
  
  #local oSecondHand =
    object {
      box{<-fSecondHandWidth,0,0>< fSecondHandWidth,fSecondHandHeight,fSecondHandDepth>}
      translate <0,-fSecondHandYOffset,-fSecondHandZOffset>
      rotate -(fSecond/60)*360*z
      }
  
  #local oClock =
    object {
      union {
        cylinder{<0,0,0><0,0,fDepth>,fRadius texture{tClockTexture}}
        torus{fDialRadius+(fRadius-fDialRadius)/2,(fRadius-fDialRadius)/2 rotate 90*x texture{tClockTexture}}
        sphere{<0,0,0>,fDialRadius+(fRadius-fDialRadius)/2 scale <1,1,0.1> texture {T_Glass1}}
        cylinder{<0,0,0><0,0,-0.001>,fDialRadius texture{tDialTexture}}
        cylinder{<0,0,0><0,0,-0.5>,0.125 pigment{Red}}
        #local hr = 1;
        #while (hr <= 12)
          object {
            oHourMark
            translate fHourMarkYOffset*y
            rotate -hr*(360/12)*z
            }
          #local oNumber =
            object {
              text{ttf "tahoma.ttf" str(hr,2,0) 1, <0,0,0>}
              scale <1.625,1.625,0.01>
              }
          #local fNumberWidth  = max_extent(oNumber).x;
          #local fNumberHeight = max_extent(oNumber).y;
          object {
            oNumber
            translate <-fNumberWidth/2,-fNumberHeight/2,-0.002>
            rotate (hr/12)*360*z
            translate fNumberYOffset*y
            rotate -(hr/12)*360*z
            pigment{Black}
            }
          #local hr = hr + 1;
        #end
        object {oHourHand pigment{Black}}
        #local mn = 1;
        #while (mn <= 60)
          object {
            oMinuteMark
            translate fMinuteMarkYOffset*y
            rotate -mn*(360/60)*z
            }
          #local mn = mn + 1;
        #end
        object {oMinuteHand pigment{Black}}
        object {oSecondHand pigment{Red}}
        }
      translate -fDepth*z
      scale 1/12  
      }
  oClock
#end