#include "Knob.inc"

#macro Compass()                    
  #local fCompassAngle =  30;
  #local fTopKnobHeight = 0.75;
  #local fTopKnobRadius = 7/64;
  #local iTopKnobTeeth  = 32;  
  #local fTopKnobShaftRadius = 6/64;
  #local fTopKnobShaftHeight = 0.5;
  #local fTopKnobRodRadius   = 1/32;
  #local fTopKnobRodHeight   = 1.00;
  #local fScrewWidth = 2+7/16;
  #local fScrewRadius = 3/64;
  #local fScrewCapWidth = 0.125;
  #local fScrewCapRadius = 0.0625;
  #local fPivotRadius    = 11/64;
  #local fPivotHeight    = 11/32;
  #local fLegWidth       = 0.250;
  #local fLegHeight      = 4.25; 
  #local fLegDepth       = 0.250;
  #local fLegXOffset     = 0.0625;
  #local fLegYOffset     = 9/32;
  #local fLegZOffset     = -fLegDepth/2;
  #local fLegAngle       = 35;
  #local fLegNotch1Width = 1/32;
  #local fLegNotch1Height = 5/8;
  #local fLegNotch1YOffset = -1.125;
  #local fLegHole1Radius   = 1/16;
  #local fLegHole1XOffset  =  fLegWidth/2;
  #local fLegHole1YOffset  = -1.4375;
  #local fKnobHeight = 3/32;
  #local fKnobRadius = 9/32;
  #local iKnobTeeth  = 48;
  #local fKnobYOffset = vrotate(<fLegXOffset+fLegHole1XOffset,fLegYOffset+fLegHole1YOffset,0>,fCompassAngle/2*z).y;
  #local fLegEndWidth = 0.125;
  #local fLegEndHeight = 0.500;
  #local fLegEndAngle =degrees(atan((fLegWidth-fLegEndWidth)/fLegEndHeight));
  #local fPointRadius = 1/32;
  #local fPointHeight = 0.375;
  #local fSpringRadius = 0.375;
  #local fSpringDepth  = 0.375;
  #local fSpringThickness = 0.0625;
  #local fSpringAngle = 3*fCompassAngle;
  #local fLegKnobRadius = 11/64;
  #local fLegKnobHeight = 1/16;
  #local iLegKnobTeeth = 48;
  #local fLegKnobShaftRadius = 1/64;
  #local fLegKnobShaftHeight = 0.125;
  #local fLegKnobXOffset = fLegEndWidth/2;
  #local fLegKnobYOffset = fLegHeight-fLegEndHeight;
  
  #local oLegKnob =
    object {
      union {
        object {Knob(fLegKnobHeight,fLegKnobRadius,48) translate (fLegKnobShaftHeight-fLegKnobHeight)*y}
        cylinder{<0,0,0><0,fLegKnobShaftHeight,0>,fLegKnobShaftRadius}
        }
      rotate -90*x
      }
  
  #local oSpring =
    object {
      difference {
        difference {
          cylinder{<0,0,0><0,0,fSpringDepth>,fSpringRadius}
          cylinder{<0,0,-0.1><0,0,fSpringDepth+0.1>,fSpringRadius-fSpringThickness}
          }
        object {Wedge(fSpringAngle) rotate -90*x }
        }
      rotate -(180-fSpringAngle/2)*z
      translate <0,fSpringRadius,-fSpringDepth/2>
      }
  
  #local oPoint =
    object {
      union {
        cone{<0, 0, 0>, fPointRadius, <0,-fPointHeight, 0>, 0.0 }
        cylinder{<0,0,0><0,fPointHeight,0>,fPointRadius}
        }
      rotate -fLegEndAngle*z
      }
  
  #local oLeg =
    object {
      union {
        object {
          difference {
            box{<0,0,0>< fLegWidth,-fLegHeight,fLegDepth>}
            box{<0,0.1,-0.1><-3*fLegWidth,-3*fLegWidth,fLegDepth+0.1> rotate -fLegAngle*z translate fLegWidth*x}
            box{<-0.1,0,-0.1><fLegNotch1Width,-fLegNotch1Height,fLegDepth+0.1> translate <0,fLegNotch1YOffset,0>}
            cylinder{<0,0,-0.1><0,0,fLegDepth+0.1>,fLegHole1Radius translate <fLegHole1XOffset, fLegHole1YOffset,0>}
            box{<0,-0.1,-0.1><fLegWidth,3*fLegWidth,fLegDepth+0.1> rotate -fLegEndAngle*z translate <fLegEndWidth,-fLegHeight,0>}
            }  
          }
        object {
          oPoint
          translate <fLegEndWidth/2,-fLegHeight,-fLegZOffset>
          }
        object {
          oLegKnob
          translate <fLegKnobXOffset,-fLegKnobYOffset,0>
          }  
        }                                           
      translate <fLegXOffset, fLegYOffset,fLegZOffset>
      rotate fCompassAngle/2*z  
      }             
  
  #local oPivot =
    object {
      cylinder{<0,0,0><0,0,fPivotHeight>,fPivotRadius}
      translate -fPivotHeight/2*z
      }
  
  #local oScrewCap =
    object {
      cylinder{<0,0,0><fScrewCapWidth,0,0>,fScrewCapRadius}
      translate -fScrewCapWidth/2*x
      }
  
  #local oTopKnob =
    object {
      union {
        object {Knob(fTopKnobHeight,fTopKnobRadius,iTopKnobTeeth) translate (fTopKnobShaftHeight+fTopKnobRodHeight)*y}
        object {cylinder{<0,0,0><0,fTopKnobShaftHeight,0>,fTopKnobShaftRadius} translate fTopKnobRodHeight*y}
        object {cylinder{<0,0,0><0,fTopKnobRodHeight,0>,fTopKnobRodRadius}}
        object {oPivot}
        }
      }
  
      
  #local oKnobScrew =
    object {
      union {
        object {
          Knob(fKnobHeight,fKnobRadius,iKnobTeeth) 
          translate -fKnobHeight/2*y 
          rotate 90*z
          }
        object {
          cylinder{<-fScrewWidth/2,0,0>< fScrewWidth/2,0,0>,fScrewRadius}
          }
        object {
          oScrewCap
          translate fScrewWidth/2*x
          }
        object {
          oScrewCap
          translate -fScrewWidth/2*x
          }
        }
      }
      
  #local oCompass =
    object {
      union {
        object {oTopKnob}
        object {oSpring}
        object {oLeg}
        object {oLeg rotate 180*y}
        object {oKnobScrew translate fKnobYOffset*y}
        }
      scale 1/12
      }
  oCompass
#end