// Persistence of Vision Ray Tracer Scene Description File
// File: Cover.inc
// Vers: 3.5
// Desc: Basic Scene Example
// Date: mm/dd/yy
// Auth: ?
//
 
#macro Lobe(fRadius,fAngle,fArc)
  #local oLobe =
    object {
      difference {
        cylinder{<0, 0, -0.001>,<0,0,fCenterRadius+0.001>,fRadius
          }
        cylinder{<0, 0,-0.002>,<0,0,fCenterRadius+0.002>,fRadius-fCoverStripeWidth
          }
        }
      clipped_by{Wedge(fArc) rotate 90*x}
      rotate (fAngle+180)*z
      pigment{Red}
      }
  oLobe
#end
 
#macro ControlPanelDoor()
  #local vCoverTexture = T_Glass1;
  #local fCoverHingeWidth = 0.4;
  #local fCoverDoorWidth  = 3.7;
  #local fCoverStripeWidth = 3/16;
  #local fLobeWidth       = 0.75/2;
  #local fLobeHeight      = 0.25/2;
  #local fLobeRadius      = ((fLobeWidth*fLobeWidth)+(fLobeHeight*fLobeHeight))/(2*fLobeHeight);
  #local fLobeAngle       = degrees(asin(fLobeWidth/fLobeRadius));
  #local oCoverHinge =
    object {
      union {
        cylinder {< 0, fCenterRadius, 0>< 0, fControlPanelHeight-fCenterRadius, 0>, fCenterRadius}
        box{<-(fCoverHingeWidth-fCenterRadius), fCenterRadius, -fCenterRadius>
            <                                  0, fControlPanelHeight-fCenterRadius, fCenterRadius>}
        }
      translate < -fCenterRadius, 0, fCenterRadius>
      pigment{White*0.1}
      }
 
  #local oCoverDoor =
    object {
      union {
        box{< 0, fCenterRadius, 0>< -(fCoverDoorWidth-fLobeRadius), fControlPanelHeight-fCenterRadius, fCenterRadius>}
        object {                    //* Top Corner */
          union {
            cylinder{<0, 0, 0>,<0,0,fCenterRadius>,fLobeRadius}
            object {Lobe(fLobeRadius,   0, 90)}
            }
          translate <-(fCoverDoorWidth-fLobeRadius), fControlPanelHeight-fCenterRadius-fLobeRadius, 0 >
          }
        box{
          < -fCoverDoorWidth, fCenterRadius+fLobeRadius, 0>
          < -(fCoverDoorWidth-fLobeRadius), fControlPanelHeight-fCenterRadius-fLobeRadius, fCenterRadius>
          }
        box{
          < -(fCoverDoorWidth-fLobeRadius), fCenterRadius, 0>
          < -(fCoverDoorWidth+2*fLobeHeight-fLobeRadius), fCenterRadius+fLobeRadius, fCenterRadius>
          }
        difference {
          box {
            < -fCoverDoorWidth, fCenterRadius+fLobeRadius, 0>
            < -(fCoverDoorWidth+fLobeHeight), fCenterRadius+fLobeRadius+10*fLobeWidth, fCenterRadius>
            }
          union {
            cylinder{<0, 0, -0.01>,<0,0,fCenterRadius+0.01>,fLobeRadius
              translate < -(fCoverDoorWidth+fLobeRadius), fCenterRadius+fLobeRadius+2*fLobeWidth, 0 >
              }
            cylinder{<0, 0, -0.01>,<0,0,fCenterRadius+0.01>,fLobeRadius
              translate < -(fCoverDoorWidth+fLobeRadius), fCenterRadius+fLobeRadius+6*fLobeWidth, 0              >
              }
            cylinder{<0, 0, -0.01>,<0,0,fCenterRadius+0.01>,fLobeRadius
              translate < -(fCoverDoorWidth+fLobeRadius), fCenterRadius+fLobeRadius+10*fLobeWidth, 0              >
              }
            }
          }
        object {
          union {
            cylinder{<0, 0, 0>,<0,0,fCenterRadius>,fLobeRadius}
            object {Lobe(fLobeRadius, 90-fLobeAngle, 90+fLobeAngle)}
            }
          translate < -(fCoverDoorWidth+2*fLobeHeight-fLobeRadius), fCenterRadius+fLobeRadius, 0              >
          }
        object {
          union {
            cylinder{<0, 0, 0>,<0,0,fCenterRadius>,fLobeRadius}
            object {Lobe(fLobeRadius, 90-fLobeAngle, 2*fLobeAngle)}
            }
          translate < -(fCoverDoorWidth+2*fLobeHeight-fLobeRadius), fCenterRadius+fLobeRadius+4*fLobeWidth, 0              >
          }
        object {
          union {
            cylinder{<0, 0, 0>,<0,0,fCenterRadius>,fLobeRadius}
            object {Lobe(fLobeRadius, 90-fLobeAngle, 2*fLobeAngle)}
            }
          translate < -(fCoverDoorWidth+2*fLobeHeight-fLobeRadius), fCenterRadius+fLobeRadius+8*fLobeWidth, 0              >
          }
        object {
          Lobe(fLobeRadius+fCoverStripeWidth, 270-fLobeAngle, 2*fLobeAngle)
          translate < -(fCoverDoorWidth+fLobeRadius), fCenterRadius+fLobeRadius+2*fLobeWidth, 0 >
          }
        object {
          Lobe(fLobeRadius+fCoverStripeWidth, 270-fLobeAngle, 2*fLobeAngle)
          translate < -(fCoverDoorWidth+fLobeRadius), fCenterRadius+fLobeRadius+6*fLobeWidth, 0 >
          }
        object {
          Lobe(fLobeRadius+fCoverStripeWidth, 270-fLobeAngle, fLobeAngle)
          translate < -(fCoverDoorWidth+fLobeRadius), fCenterRadius+fLobeRadius+10*fLobeWidth, 0 >
          }
        object {
          box { <-fCoverDoorWidth, fCenterRadius+fLobeRadius+10*fLobeWidth, -0.001>
                <-(fCoverDoorWidth-fCoverStripeWidth), (fControlPanelHeight-fCenterRadius-fLobeRadius), fCenterRadius+0.001>}
          pigment{Red}
          }   
        }
      translate -fCoverHingeWidth*x
      texture{vCoverTexture}
      }
 
  #local oDoor =
    object {
      union {
        object { oCoverHinge }
        object { oCoverDoor  translate  fCenterRadius*z}
        }
      }
  oDoor
#end
