//***************************************************************************************************************/
//* Persistence of Vision Ray Tracer Scene Description File                                                     */
//* File: DataCenter.pov                                                                                        */
//* Vers: 3.6                                                                                                   */
//* Desc: Data Center Scene                                                                                     */
//* Date: 11/10/2004                                                                                            */
//* Auth: D. E. LeMasters                                                                                       */
//***************************************************************************************************************/
#version 3.6;                                                           //*                                     */
                                                                        //*                                     */
#include "colors.inc"
#include "glass.inc"
#include "shapes.inc"
#include "transforms.inc"
#include "metals.inc"
#include "woods.inc" 

#include "zoomin.inc"
 
global_settings {
  assumed_gamma 1.0
  ambient_light White
  max_trace_level 10
    radiosity {
      pretrace_start 0.08
      pretrace_end   0.04
      count 35

      nearest_count 5
      error_bound 1.8
      recursion_limit 3

      low_error_factor 0.5
      gray_threshold 0.0
      minimum_reuse 0.015
      brightness 1

      adc_bailout 0.01/2
    }      
  }
 
#ifndef (camare_location)
  #declare camera_location =  6;
#end
 
  #switch (camera_location)
    #case (0)                                                       //* Primary 
      camera {
        location  <31.000, 5.00, 12.0>                               
        look_at   < 8.000, 4.00, 50.0>
        right     x*image_width/image_height
        }      
    #break
    #case (1)                                                       //* Close-Up 1, 3494 Convenience Station
      camera {
        location  <31.00, 5.00, 12.00>                              
        look_at   <31.25, 4.25, 44.00>
        right     x*image_width/image_height
        angle 2.5
        }      
    #break
    #case (2)                                                      //* Close-Up 2, 9037 Sysplex Timer
      camera {
        location  <31.00, 5.00, 12.00>                              
        look_at   <20.75, 3.625, 44.00>
        right     x*image_width/image_height
        angle 3
        }      
    #break
    #case (3)                                                      //* Close-Up 3, 2105 ESS
      camera {
        location  <31.00, 5.00, 12.00>                              
        look_at   <7, 3.50, 44.00>
        right     x*image_width/image_height
        angle 8
        }      
    #break
    #case (4)                                                      //* Close-Up 4, 2066-800
      camera {
        location  <31.00, 5.00, 12.00>                              
        look_at   <14.50, 2.75, 44.00>
        right     x*image_width/image_height
        angle 7
        }
    #break          
    #case (5)                                                      //* Close-Up 5, 9032
      camera {
        location  <31.00, 5.00, 12.00>                              
        look_at   < 5.25, 2.25, 38.00>
        right     x*image_width/image_height
        angle 4
        }      
    #break
    #case (6)                                                      //* Close-Up 6, Monitor
      camera {
        location  <31.00, 5.00, 12.00>                              
        look_at   <24.50, 3.25, 22.00>
        right     x*image_width/image_height
        angle 9
        }      
    #break
    #case (7)                                                      //* Close-Up 7, 3290
      camera {
        location  <31.00, 5.00, 12.00>                              
        look_at   <21.75, 3.625, 20.00>
        right     x*image_width/image_height
        angle 12
        }      
    #break
    #case (8)                                                      //* Close-Up 8, Desk 1
      camera {
        location  <31.00, 5.00, 12.00>                              
        look_at   <27.5, 3.25, 20.00>
        right     x*image_width/image_height
        angle 12
        }      
    #break
    #case (9)                                                      //* Close-Up 9, Desk 2
      camera {
        location  <31.00, 5.00, 12.00>                              
        look_at   <29.00, 3.25, 20.00>
        right     x*image_width/image_height
        angle 12
        }      
    #break
    #case (10)                                                     //* Close-Up 10, 3174
      camera {
        location  <31.00, 5.00, 12.00>                              
        look_at   < 4.00, 2.75, 24.00>
        right     x*image_width/image_height
        angle 7
        }      
    #break
    #case (88)
      #local camera_location = <31.000, 5.00, 12.0>;                               //* Primary View
      #local camera_look_at  = < 8.00, 4.00, 50.00>;
      Set_Zoom_Area(camera_location, camera_look_at, "+sc0.946842 +sr0.472141 +ec0.980613 +er0.632454") 
      Update_Camera_Zoom()    
      #break
    #case (97)
      camera {
        location  < 16.50, 32.00/12, 23.00>                             //* Overhead View of 3290
        look_at   < 18.50, 32.00/12, 23.00>
        right     x*image_width/image_height
        }
    #break      
    #case (96)
      camera {
        location  < 24.00,   5.00, 30.00>                             //* Overhead View of Operator Station
        look_at   < 24.00,   3.00, 22.00>
        right     x*image_width/image_height
        }
    #break      
    #case (98)
      camera {
        location  < 24.00,   8.00, 26.00>                             //* Overhead View of Operator Station
        look_at   < 24.00,   0.00, 22.00>
        right     x*image_width/image_height
        }      
    #break
    #case (99)
      camera {
        location  < 24.00, 75.00, 26.00>                             //* Overhead View
        look_at   < 24.00,   0.00, 26.00>
        right     x*image_width/image_height
        }      
    #break
  #end
  
//***************************************************************************************************************/
//* User Defined Includes                                                                                       */
//***************************************************************************************************************/
#declare b2105Detail = true;
//#declare b2105Detail = false;
                             
#declare bShow2066  = true;                          
#declare bShow2105  = true;                          
#declare bShow2914  = true;                          
#declare bShow3174  = true;                          
#declare bShow3494  = true;                          
#declare bShow9032  = true;                          
#declare bShowTable = true;                          
#declare bShowLight = true;
//#declare bShow2066  = false;                          
//#declare bShow2105  = false;                          
//#declare bShow2914  = false;                          
//#declare bShow3174  = false;                          
//#declare bShow3494  = false;                          
//#declare bShow9032  = false;                          
//#declare bShowTable = false;
#declare bShowLight = false;
                          
#include "DataCenter.inc"
#include "Walls.inc"
#include "Floor.inc"
#include "Ceiling.inc"
 
#if (bShow2066)
  #include "Sysplex.inc"
#end  
#if (bShow2105)
  #include "IBM2105.inc"
#end  
#if (bShow2914)
  #include "IBM2914.inc"
#end  
#if (bShow3174)
  #include "IBM3174.inc"
#end  
#if (bShow3494)
  #include "IBM3494.inc"
  #include "TapeCart.inc"
#end  
#if (bShow9032)
  #include "IBM9032.inc"
#end  
#if (bShowTable)
  #include "OperatorStation.inc"
#end  
 
//***************************************************************************************************************/
//* Define Overhead Lights                                                                                      */
//***************************************************************************************************************/ 
#if (bShowLight)
  #declare fXLight = 4; 
  #while (fXLight < fCenterWidth)
    #declare fZLight = 4;
    #while (fZLight < fCenterDepth)
      light_source {
        <0, 0, 0>            // light's position (translated below)
        color rgb <0.03, 0.03, 0.03>  // light's color
        translate <fXLight, 9.5, fZLight>
        }
      #declare fZLight = fZLight + 8;
    #end
    #declare fXLight = fXLight + 8;
  #end
#else
  light_source {
    <0, 0, 0>            // light's position (translated below)
    color rgb <1, 1, 1>  // light's color
    translate <fCenterWidth/2, 9.5, fCenterDepth/2>
    }
#end  
 
//***************************************************************************************************************/
//* Define Basic Room                                                                                           */
//***************************************************************************************************************/
#declare oRoom =
  object {
    union {
      object {Walls()}
      object {oFloor}
      #if (camera_location < 90)
        object {oCeiling}
      #end  
      }
    }
 
//***************************************************************************************************************/
//* Define Data Center                                                                                          */
//***************************************************************************************************************/
#declare oDataCenter =
  object {
    union {
      object { oRoom }
//***************************************************************************************************************/
//* 2066 Processors                                                                                             */
//***************************************************************************************************************/
      #if (bShow2066)
        object {
          Sysplex()
          translate < 15.00, 0.00, 40.00>
          }
      #end
    
//***************************************************************************************************************/
//* 9032 Escon Directors                                                                                        */
//***************************************************************************************************************/
      #if (bShow9032) 
        object {
          union {
            object { IBM9032(true)           translate < 0.00, 0.00,  0.00> }
            object { IBM9032(false)          translate < 2.25, 0.00,  0.00> }
            }
          rotate -90*y
          translate < 5.00,  0.00, 35.00>
          }
      #end
    
//***************************************************************************************************************/
//* 2105 ESS                                                                                                    */
//***************************************************************************************************************/
      #if (bShow2105)
        object {
          IBM2105(b2105Detail)
          translate < 7.00, 0.00, 40.00>
          }
      #end
        
//***************************************************************************************************************/
//* 2914                                                                                                        */
//***************************************************************************************************************/
      #if (bShow2914)
       object {
          IBM2914()
          translate <6.00, 0.00, 49>
          }
      #end
        
//***************************************************************************************************************/
//* 3494 Auto Tape Library                                                                                      */
//***************************************************************************************************************/
      #if (bShow3494)    
        object {
          IBM3494(6)
          translate < 28.00, 0.00, 40.00>
          }                              
        object {
          TapeCart()
          rotate 120*y
          translate <28,0,38>
          }
      #end    
    
//***************************************************************************************************************/
//* Operator Station                                                                                            */
//***************************************************************************************************************/
      #if (bShowTable)
        object {
          OperatorStation()
          translate <24, 0, 22>
          }
      #end
 
//***************************************************************************************************************/
//* 3174 Controllers                                                                                            */
//***************************************************************************************************************/
      #if (bShow3174)
        object { IBM3174() rotate -90*y translate <4.00,  0.00, fDoorZOffset-5> }
        object { IBM3174() rotate -90*y translate <4.00, 23/12, fDoorZOffset-5> }
      #end  
      }
    }
 
//***************************************************************************************************************/
//* Create Data Center                                                                                          */
//***************************************************************************************************************/
object {
  oDataCenter
  }
 
//***************************************************************************************************************/
