#declare bLeft  = false;
#declare bRight = true;

#macro Door(bSide)
  #local fDoorWidth     = 35.5;
  #local fDoorHeight    = 79.5;
  #local fDoorDepth     = 1.5;  

  #local fOpenBarWidth  = fDoorWidth-1.5;
  #local fOpenBarHeight = 3;
  #local fOpenBarDepth  = 2;
  #local fOpenBarRadius = 0.125;
  #local fOpenBarXOffset = 0.5; 
  #local fOpenBarYOffset = 36; 

  #local fPushBarWidth  = 24;
  #local fPushBarHeight = fOpenBarHeight-0.5;
  #local fPushBarDepth  = 1.0;
  #local fPushBarXOffset = 1;
  #local fPushBarZOffset = fOpenBarDepth;
  
  #local fRodRadius      = 0.25;
  #local fRodHeight      = fDoorHeight-fOpenBarYOffset;
  #local fRodXOffset     = 1.5;
  #local fRodZOffset     = 0.0;

  #local tOpenBarTexture = T_Chrome_1B ;
//  #local tOpenBarTexture = pigment{Green} ;

  #local oOpenBar =
    object {
      union {
        object {Round_Box(<0,0,0>,<fOpenBarWidth,fOpenBarHeight,-fOpenBarDepth>,fOpenBarRadius,false)} 
        object {Round_Box(<0,0,0>,<fPushBarWidth,fPushBarHeight,-fPushBarDepth>,fOpenBarRadius,false)  
          #if (bSide)
            translate <fPushBarXOffset,(fOpenBarHeight-fPushBarHeight)/2,-(fOpenBarDepth-fOpenBarRadius)>
          #else
            translate <fOpenBarWidth-fPushBarWidth-fPushBarXOffset,(fOpenBarHeight-fPushBarHeight)/2,-(fOpenBarDepth-fOpenBarRadius)>
          #end
          }
        object {
          union {
            object {
              cylinder{<0,0,0><0,fRodHeight,0>,fRodRadius}
              }
            object {
              union {
                object {Round_Box(<-(fRodRadius+0.25),0,-fOpenBarRadius><(fRodRadius+0.25),6,fRodZOffset+fOpenBarRadius>,fOpenBarRadius,false)} 
                object {Round_Cylinder(<0,0,0>,<0,6,0>,fRodRadius+0.25,fOpenBarRadius,false)}
                }
              translate (fRodHeight-6.25)*y
              }
            #if (bSide)
              translate <fRodXOffset,0,-fRodZOffset>
            #else
              translate <fOpenBarWidth-fRodXOffset,0,-fRodZOffset>
            #end
            }
          }
        }
      texture { tOpenBarTexture}
      }
      
  #local oDoor =
    object {
      union {
        object { box{<0,0,0><fDoorWidth,fDoorHeight,fDoorDepth>}}
        object { 
          oOpenBar
            #if (bSide)
              translate <fOpenBarXOffset,fOpenBarYOffset,-0.75>
            #else
              translate <fDoorWidth-fOpenBarWidth-fOpenBarXOffset,fOpenBarYOffset,-0.75>
            #end  
          }
        }
      }
      
  oDoor
#end

#macro Doors()
  #local fDoorwayWidth  = 72;
  #local fDoorwayHeight = 80;
  #local fDoorwayDepth  = 4.5;
  #local fFrameWidth    = 0.5;
  #local fFrameDepth    = fDoorwayDepth;
  #local fTrimWidth     = 3.0;
  #local fTrimDepth     = 0.5;
  #local fDoorWidth     = 35.5;
  #local fDoorHeight    = 79.5;
  #local fDoorDepth     = 1.5;  
  #local tDoorTexture   = texture{pigment{DarkSlateBlue}          
                          normal { bumps 0.04 scale 0.0005 }   
                          finish { phong 0.5 }                 
                          };                                    
                         
                         
                         
  #local oDoorFrame =
    object {
      union {
        box{<0,0,0>< fFrameWidth,fDoorwayHeight+fFrameWidth,fFrameDepth> translate -fFrameWidth*x}
        box{<0,0,0>< fFrameWidth,fDoorwayHeight+fFrameWidth,fFrameDepth> translate  fDoorwayWidth*x}
        box{<-fFrameWidth,0,0>< fDoorwayWidth+fFrameWidth,fFrameWidth,fFrameDepth> translate fDoorwayHeight*y}
        box{<0,0,0>< fTrimWidth,fDoorwayHeight+fTrimWidth,-fTrimDepth> translate -fTrimWidth*x}
        box{<0,0,0>< fTrimWidth,fDoorwayHeight+fTrimWidth,-fTrimDepth> translate  fDoorwayWidth*x}
        box{<0,0,0>< fDoorwayWidth,fTrimWidth,-fTrimDepth> translate fDoorwayHeight*y}
        }
      }
  
  #local oDoorway =
    object {
      union {
        object { oDoorFrame }
        object { Door(bLeft ) translate <0.25, 0.25,fDoorwayDepth-fDoorDepth>}
        object { Door(bRight) translate <fDoorwayWidth/2+0.25, 0.25,fDoorwayDepth-fDoorDepth>}
        }
      texture{tDoorTexture}
      scale 1/12
      }         
  oDoorway    
#end