#macro FireAlarm()
  #local fBaseWidth    = 4.00;
  #local fBaseHeight   = 6.00;
  #local fBaseDepth    = 0.25;
  #local fBaseRadius   = 0.50;
  #local fBaseEdge     = 0.0625;
  #local fAlarmWidth   = 2.00;
  #local fAlarmHeight  = 5.50;
  #local fAlarmDepth   = 2.00;
  #local fAlarmRadius  = 0.50;
  #local fAlarmXOffset = (fBaseWidth-fAlarmWidth)/2;
  #local fAlarmYOffset = (fBaseHeight-fAlarmHeight)/2;
  #local fAlarmZOffset = -(fAlarmRadius-fBaseDepth);
  #local fSlotWidth    = fAlarmWidth+0.1;
  #local fSlotHeight   = 1/16;
  #local fSlotDepth    = fAlarmRadius+0.1;
  #local fSlotXOffset  = -0.05;
  #local fSlotYOffset  = 2.5;
  #local fSlotZOffset  = fAlarmDepth-fAlarmRadius;
  #local fSlotSpace    = fSlotHeight+1/8;
  #local fSlotCount    = 10;
  #local fLightWidth   = fAlarmWidth;
  #local fLightRadius  = 1.00;
  #local fLightEdge    = fAlarmRadius; 
  #local fLightXOffset = 0;
  #local fLightYOffset = fLightRadius;
  #local fLightZOffset = fAlarmDepth-fAlarmRadius;
  #local fHoleWidth    = fLightWidth +0.05;
  #local fHoleRadius   = fLightRadius+0.05;
  #local fHoleEdge     = fLightEdge; 
  #local fHoleXOffset  = -0.025;
  #local fHoleYOffset  = fLightYOffset;
  #local fHoleZOffset  = fLightZOffset;
  #local fMirrorWidth  = fLightWidth-0.05;
  #local fMirrorRadius = fLightRadius-0.05;
  #local fMirrorEdge   = fLightEdge;
  #local fMirrorXOffset= (fLightWidth-fMirrorWidth)/2;
  #local fMirrorYOffset= fLightYOffset;
  #local fMirrorZOffset= fLightZOffset; 
  #local fTextWidth    = fAlarmWidth-2*fAlarmRadius;
  #local fTextHeight   = 0.5;    
  #local fTextXOffset  = fAlarmRadius;
  #local fTextYOffset  = fAlarmHeight-fAlarmRadius-0.625;
  #local fTextZOffset  = fAlarmDepth+0.001;
  
  
  #local tAlarmTexture = texture{pigment{Red}       
                         normal { bumps 0.04 scale 0.0005 }
                         finish { phong 0.25 }
                         };
  #local tTextTexture  = pigment{White};                        
  #local tLightTexture = T_Glass1;
  #local tMirrorTexture= T_Chrome_5E;
  
  #local oText = 
    object {
      text{ttf "ariblk.ttf" "FIRE" 1,<0,0,0>}
      texture { tTextTexture}
      }
      
  #local oTextF =
    object {
      text{ttf "ariblk.ttf" "F" 1,<0,0,0>}
      texture { tTextTexture}
      }
      
  #local oTextI =
    object {
      text{ttf "ariblk.ttf" "I" 1,<0,0,0>}
      texture { tTextTexture}
      }
      
  #local oTextR =
    object {
      text{ttf "ariblk.ttf" "R" 1,<0,0,0>}
      texture { tTextTexture}
      }
      
  #local oTextE =
    object {
      text{ttf "ariblk.ttf" "E" 1,<0,0,0>}
      texture { tTextTexture}
      }
      
  #local oBase =             
    object {
      union {
        object { Round_Cylinder(<0,0,-fBaseEdge>,<0,0,fBaseDepth>,fBaseRadius,fBaseEdge,false) translate < fBaseRadius,fBaseRadius,0>}
        object { Round_Cylinder(<0,0,-fBaseEdge>,<0,0,fBaseDepth>,fBaseRadius,fBaseEdge,false) translate < fBaseWidth-fBaseRadius,fBaseRadius,0>}
        object { Round_Cylinder(<0,0,-fBaseEdge>,<0,0,fBaseDepth>,fBaseRadius,fBaseEdge,false) translate < fBaseRadius,fBaseHeight-fBaseRadius,0>}
        object { Round_Cylinder(<0,0,-fBaseEdge>,<0,0,fBaseDepth>,fBaseRadius,fBaseEdge,false) translate < fBaseWidth-fBaseRadius,fBaseHeight-fBaseRadius,0>}
        object { Round_Box(<0,fBaseRadius-fBaseEdge,-fBaseEdge>,<fBaseWidth,fBaseHeight-fBaseRadius+fBaseEdge,fBaseDepth>,fBaseEdge,false)}
        object { Round_Box(<fBaseRadius-fBaseEdge,0,-fBaseEdge>,<fBaseWidth-fBaseRadius+fBaseEdge,fBaseHeight,fBaseDepth>,fBaseEdge,false)}
        }
      }
  
  #local oSlot  =
    object {
      box{<0,0,0><fSlotWidth,fSlotHeight,fSlotDepth>}
      }
      
  #local oSlots =
    object {
      union {
        #local n = 0;
        #while (n < fSlotCount)
          object {oSlot translate n*fSlotSpace*y}
          #local n = n + 1;
        #end
        }
      }
  
  #local oBulb =
    object {
      cylinder{<0,0,0><fMirrorWidth,0,0>,fMirrorRadius/5}
      }
          
  #local oLight =      
    object {    
      union {
        object { 
          Round_Cylinder(<0,0,0>,<fLightWidth,0,0>,fLightRadius,fLightEdge,true) 
          texture{tLightTexture}
          }
        object { 
          Round_Cylinder(<0,0,0>,<fMirrorWidth,0,0>,fMirrorRadius,fMirrorEdge,true)
          translate fMirrorXOffset*x
          clipped_by{plane{z,0}} 
          texture{tMirrorTexture}
          }
        object {
          oBulb
          translate fMirrorXOffset*x
          texture{tMirrorTexture}
          }
        }
      }
  
  #local oHole =    
    object { 
      Round_Cylinder(<0,0,0>,<fHoleWidth,0,0>,fHoleRadius,fHoleEdge,false) 
      }
      
  #local oAlarm =
    object {
      union {
        difference {
          object { Round_Box(<0,0,0>,<fAlarmWidth,fAlarmHeight,fAlarmDepth>,fAlarmRadius,false)}
          object { oSlots translate <fSlotXOffset, fSlotYOffset, fSlotZOffset>}
          object { oHole translate <fHoleXOffset,fHoleYOffset,fHoleZOffset> }
          }
        object {oLight translate <fLightXOffset,fLightYOffset,fLightZOffset>}
        object {
          oText 
          scale <fTextWidth/max_extent(oText).x,fTextHeight/max_extent(oText).y,1>
          rotate 180*y
          translate <fTextWidth,0,0> 
          translate <fTextXOffset, fTextYOffset, fTextZOffset >
          } 
        }
      translate <fAlarmXOffset,fAlarmYOffset,fAlarmZOffset>      
      } 
      
  #local oFireAlarm =
    object {
      union {
        object { oBase  }
        object { oAlarm }
        }
      texture { tAlarmTexture }
      scale 1/12
      }
      
  oFireAlarm
#end