#macro FirePull()
  #local fWidth = 3.5;
  #local fHeight = 4.75;
  #local fDepth = 1.0; 
  #local fRadius = 0.0625;
  
  #local fBorderWidth = 2.75;
  #local fBorderHeight = 2.75;
  #local fBorderDepth = 0.0625;
  #local fBorderRadius = 0.25;
  #local fBorderXOffset = (fWidth-fBorderWidth)/2;
  #local fBorderYOffset = (fHeight-fBorderHeight)/2;
  #local fHoleDepth = 0.875;
  #local fHoleHeight = 1.5; 
  #local fSlotWidth = 0.5;
  #local fSlotHeight = 2;
  #local fSlotDepth = fHoleDepth;
  #local fSlotXOffset = (fBorderWidth-fSlotWidth)/2;
  #local fSlotYOffset = fBorderDepth;
  #local tFireTexture = pigment{Red};
   
  #local oBorderCorner =
    object {
      intersection { 
        torus{fBorderRadius,fBorderDepth}
        object{Wedge(90)}
        }
      rotate 90*x  
      }
      
  #local oBorder =
    object {
      union {
        cylinder{<fBorderRadius,0,0><fBorderWidth-fBorderRadius,0,0>,fBorderDepth }
        cylinder{<fBorderRadius,0,0><fBorderWidth-fBorderRadius,0,0>,fBorderDepth translate <0,fBorderHeight,0>}
        cylinder{<0,fBorderRadius,0><0,fBorderHeight-fBorderRadius,0>,fBorderDepth }
        cylinder{<0,fBorderRadius,0><0,fBorderHeight-fBorderRadius,0>,fBorderDepth translate <fBorderWidth,0,0> }
        object {oBorderCorner              translate <fBorderWidth-fBorderRadius,fBorderRadius,0>}
        object {oBorderCorner rotate -90*z translate <fBorderRadius,fBorderRadius,0>}
        object {oBorderCorner rotate  90*z translate <fBorderWidth-fBorderRadius,fBorderHeight-fBorderRadius,0>}
        object {oBorderCorner rotate 180*z translate <fBorderRadius,fBorderHeight-fBorderRadius,0>}
        }
      }
      
  #local oHole =
    object { 
      union {
        object {Round_Box(<fBorderDepth,fBorderHeight-fHoleHeight,-0.1>,<fBorderWidth-fBorderDepth,fBorderHeight-fBorderDepth,fHoleDepth>,fBorderRadius-fBorderDepth,false)}
        object {box{<0,0,-0.1><fSlotWidth,fSlotHeight,fSlotDepth> translate <fSlotXOffset,fSlotYOffset,0>}}
        }
      }
      
  #local oFireText =
    object {
      text{ttf "arial" "FIRE ALARM" 1,<0,0,0>}
      pigment{White}
      }
      
  #local fFireTextWidth = fBorderWidth;
  #local fFireTextHeight = (fHeight-(fBorderYOffset+fBorderHeight));
  #local fFireTextDepth = fBorderDepth; 
  #local fFireTextXOffset = fBorderXOffset;
  #local fFireTextYOffset = fBorderYOffset+fBorderHeight+0.15*fFireTextHeight;
  #local fFireTextZOffset = -fFireTextDepth;
  
  #local oSimplexText =
    object {
      text{ttf "arial" "SIMPLEX" 1,<0,0,0>}
      pigment{White}
      }
      
  #local fSimplexTextWidth = fBorderWidth;
  #local fSimplexTextHeight = fBorderYOffset;
  #local fSimplexTextDepth = fBorderDepth; 
  #local fSimplexTextXOffset = fBorderXOffset;
  #local fSimplexTextYOffset = 0.15*fSimplexTextHeight;
  #local fSimplexTextZOffset = -fFireTextDepth;
  
   
           
  #local oCase =
    object { 
      difference {                                                 
        union {
          object {oFireText scale <fFireTextWidth/max_extent(oFireText).x,0.7*fFireTextHeight/max_extent(oFireText).y,fFireTextDepth> translate <fFireTextXOffset,fFireTextYOffset,fFireTextZOffset>}
          object {oSimplexText scale <fSimplexTextWidth/max_extent(oSimplexText).x,0.7*fSimplexTextHeight/max_extent(oSimplexText).y,fSimplexTextDepth> translate <fSimplexTextXOffset,fSimplexTextYOffset,fSimplexTextZOffset>}
          object {Round_Box(<0,0,0>,<fWidth,fHeight,fDepth>,fRadius,false)}
          object {oBorder translate <fBorderXOffset,fBorderYOffset,0>}
          }
        object {oHole translate <fBorderXOffset,fBorderYOffset,0>}
        }    
      } 
      
   
                                       
  #local fHandleWidth = fBorderWidth-2*fBorderDepth;
  #local fHandleHeight = fHoleHeight/2;    
  #local fHandleDepth = fHandleHeight/2;
  #local fHandleRadius = fBorderRadius-fBorderDepth;
  #local fHandleXOffset = fBorderXOffset+fBorderDepth;
  #local fHandleYOffset = fBorderYOffset+fBorderHeight-fHoleHeight+fHandleDepth+fBorderDepth;                                                                                                   
   
  #local oHandleText =
    object {
      text {ttf "arial" "PULL  HANDLE" 1,<0,0,0>}
      pigment{tFireTexture}
      }
      
  #local fHandleTextWidth = fHandleWidth;
  #local fHandleTextHeight = fHandleDepth*2;
  #local fHandleTextDepth = fBorderDepth;
  #local fHandleTextXOffset = 0.10*fHandleTextWidth;
  #local fHandleTextYOffset = 0.20*fHandleTextHeight-fHandleDepth;
  #local fHandleTextZOffset = -fHandleTextDepth;
    
  #local fTabWidth = fSlotWidth-0.05;
  #local fTabHeight = 1.25;
  #local fTabDepth = 0.25;
  #local fTabXOffset = (fHandleWidth-fTabWidth)/2;
  #local fTabYOffset = 0;
  #local fTabZOffset = 0;
  
  #local oTab =
    object {
      box{<0,0,0><fTabWidth,-fTabHeight,fTabDepth>}
      }  
                                                                                                     
  #local oHandle =
    object {
      union {
        object {
          intersection {
            object {Round_Cylinder(<0,0,0>,<fHandleWidth,0,0>,fHandleDepth,fHandleRadius,false)}
            object {box{<-0.1,-fHandleDepth-0.1,0><fHandleWidth+0.1, fHandleDepth+0.1,fHandleDepth+0.1>}}
            }
          }
        object {
          oTab
          translate <fTabXOffset,fTabYOffset,fTabZOffset>
          }  
        object {
          oHandleText 
          scale <0.8*fHandleTextWidth/max_extent(oHandleText).x,0.6*fHandleTextHeight/max_extent(oHandleText).y,fHandleTextDepth>
          translate <fHandleTextXOffset,fHandleTextYOffset,fHandleTextZOffset>
          }
        }
      translate <fHandleXOffset,fHandleYOffset,0> pigment{White}
      }
                 
  #local oFirePull =
    object {
      union {
        object {oCase}
        object {oHandle}
        }
      texture {tFireTexture }
      scale 1/12  
      }
  oFirePull
#end
