#declare fFloppyDriveWidth  = 1.625;
#declare fFloppyDriveHeight  = 5.50;
#macro FloppyDrive()
  #local fOuterRadius   = 0.05;
  #local fInnerRadius   = 0.10;
  #local fWidth1        = 0.125;
  #local fWidth2        = 0.550;
  #local fWidth3        = 0.850;
  #local fWidth4        = fFloppyDriveWidth-fInnerRadius;
  #local fHeight1       = 0.125;
  #local fHeight2       = 1.700;
  #local fHeight3       = 1.900;
  #local fHeight4       = 2.100;
  #local fHeight5       = 3.200;
  #local fHeight6       = 3.400;
  #local fHeight7       = 5.375;
  #local fDepth1        = 0.500;
  #local fLeverWidth    = 1.375;
  #local fLeverHeight   = 0.250;
  #local fLeverDepth    = 0.250;
  #local fLeverRadius   = 0.050;
 
  #local vArray         = array[22]
    {
      < fOuterRadius, fOuterRadius, 0>,                   //*  0 */
      < fFloppyDriveWidth-fOuterRadius, fOuterRadius, 0>,       //*  1 */
      < fFloppyDriveWidth-fOuterRadius, fFloppyDriveHeight-fOuterRadius, 0>, //* 2 */
      < fOuterRadius, fFloppyDriveHeight-fOuterRadius, 0>, //* 3 */
      < fWidth2, fHeight1, 0>,                            //*  4 */
      < fWidth2, fHeight3, 0>,                            //*  5 */
      < fWidth1, fHeight3, 0>,                            //*  6 */
      < fWidth1, fHeight6, 0>,                            //*  7 */
      < fWidth2, fHeight6, 0>,                            //*  8 */
      < fWidth2, fHeight7, 0>,                            //*  9 */
      < fWidth3, fHeight7, 0>,                            //* 10 */
      < fWidth3, fHeight6, 0>,                            //* 11 */
      < fWidth4, fHeight6, 0>,                            //* 12 */
      < fWidth4, fHeight3, 0>,                            //* 13 */
      < fWidth3, fHeight2, 0>,                            //* 14 */
      < fWidth3, fHeight1, 0>,                            //* 15 */
      < fWidth2, fHeight4, fDepth1>,                      //* 16 */
      < fWidth1, fHeight4, fDepth1>,                      //* 17 */
      < fWidth1, fHeight5, fDepth1>,                      //* 18 */
      < fWidth2, fHeight5, fDepth1>,                      //* 19 */
      < fWidth3, fHeight5, fDepth1>,                      //* 20 */
      < fWidth3, fHeight4, fDepth1>                       //* 21 */
    }
 
  #local vNormVector1 = vnormalize(vcross(vArray[21]-vArray[13],vArray[21]-vArray[14]))*fInnerRadius;
  #local vNormVector2 = vnormalize(vcross(vArray[20]-vArray[11],vArray[20]-vArray[12]))*fInnerRadius;
  #local vNormVector3 = vnormalize(vcross(vArray[20]-vArray[12],vArray[20]-vArray[13]))*fInnerRadius;
  #local vNormVector4 = vnormalize(vcross(vArray[19]-vArray[ 7],vArray[19]-vArray[ 8]))*fInnerRadius;
  #local vNormVector5 = vnormalize(vcross(vArray[16]-vArray[ 5],vArray[16]-vArray[ 6]))*fInnerRadius;
  #local vNormVector6 = vnormalize(vcross(vArray[16]-vArray[17],vArray[16]-vArray[18]))*fInnerRadius;
  #local vNormVector7 = vnormalize(vcross(vArray[17]-vArray[ 6],vArray[17]-vArray[ 7]))*fInnerRadius;
                                                          //* Outer Surface */
  #local oPolygon1 =
    object {
      polygon {
        18,
        vArray[0],
        vArray[1],
        vArray[2],
        vArray[3],
        vArray[0],
        vArray[4],
        vArray[5],
        vArray[6],
        vArray[7],
        vArray[8],
        vArray[9],
        vArray[10],
        vArray[11],
        vArray[12],
        vArray[13],
        vArray[14],
        vArray[15],
        vArray[4]
        }
      }
 
  #local oOuterPerimeter =
    object {
      union {
        cylinder{vArray[0],vArray[1],fOuterRadius}
        cylinder{vArray[1],vArray[2],fOuterRadius}
        cylinder{vArray[2],vArray[3],fOuterRadius}
        cylinder{vArray[3],vArray[0],fOuterRadius}
        sphere  {vArray[0],fOuterRadius}
        sphere  {vArray[1],fOuterRadius}
        sphere  {vArray[2],fOuterRadius}
        sphere  {vArray[3],fOuterRadius}
        }
      }
 
  #local oInnerPerimeter1 =
    object {
      union {
        cylinder{vArray[4],vArray[5],fInnerRadius}
        cylinder{vArray[5],vArray[6],fInnerRadius}
        cylinder{vArray[6],vArray[7],fInnerRadius}
        cylinder{vArray[7],vArray[8],fInnerRadius}
        cylinder{vArray[8],vArray[9],fInnerRadius}
        cylinder{vArray[9],vArray[10],fInnerRadius}
        cylinder{vArray[10],vArray[11],fInnerRadius}
        cylinder{vArray[11],vArray[12],fInnerRadius}
        cylinder{vArray[12],vArray[13],fInnerRadius}
        cylinder{vArray[13],vArray[14],fInnerRadius}
        cylinder{vArray[14],vArray[15],fInnerRadius}
        cylinder{vArray[15],vArray[4],fInnerRadius}
        sphere  {vArray[4],fInnerRadius}
        sphere  {vArray[5],fInnerRadius}
        sphere  {vArray[6],fInnerRadius}
        sphere  {vArray[7],fInnerRadius}
        sphere  {vArray[8],fInnerRadius}
        sphere  {vArray[9],fInnerRadius}
        sphere  {vArray[10],fInnerRadius}
        sphere  {vArray[11],fInnerRadius}
        sphere  {vArray[12],fInnerRadius}
        sphere  {vArray[13],fInnerRadius}
        sphere  {vArray[14],fInnerRadius}
        sphere  {vArray[15],fInnerRadius}
        }
      }
 
  #local oInnerPerimeter2 =
    object {
      union {
        cylinder{vArray[5],vArray[16],fInnerRadius}
        cylinder{vArray[16],vArray[19],fInnerRadius}
        cylinder{vArray[19],vArray[8],fInnerRadius}
        cylinder{vArray[11],vArray[20],fInnerRadius}
        cylinder{vArray[20],vArray[21],fInnerRadius}
        cylinder{vArray[21],vArray[14],fInnerRadius}
        sphere  {vArray[16],fInnerRadius}
        sphere  {vArray[17],fInnerRadius}
        sphere  {vArray[18],fInnerRadius}
        sphere  {vArray[19],fInnerRadius}
        sphere  {vArray[20],fInnerRadius}
        sphere  {vArray[21],fInnerRadius}
        }
      }
 
  #local oLever =
    object {
      union {
        object { Round_Cylinder(<0,0,0>,<0,fLeverHeight,0>,fLeverDepth/2,fLeverRadius,false)}
        object { Round_Box(<0,0,0>,<fLeverWidth,fLeverHeight,fLeverDepth>,fLeverRadius,false) translate<-fLeverRadius,0,-fLeverDepth/2>}
        object { Round_Cylinder(<0,0,0>,<0,fLeverHeight,0>,fLeverDepth/2,fLeverRadius,false) translate<fLeverWidth-2*fLeverRadius,0,0>}
        object { Round_Cylinder(<0,0,fLeverRadius>,<0,0,fLeverDepth>,fLeverDepth/2,fLeverRadius,false) translate <fLeverDepth/2,0,0>}
        }
      }
 
  #local fFloppyIconAngle = degrees(atan(fDepth1/(fWidth4-fWidth3)));
  #local oFloppyIcon =
    object {
      union {
        box{<0,0,0><0.5,1/64,-0.01>}
        box{<0,0,0><1/64,0.5,-0.01>}
        box{<0,0,0><0.5,1/64,-0.01> translate (0.5-1/64)*y}
        box{<0,0,0><1/64,0.5,-0.01> translate (0.5-1/64)*x}
        difference {
          cylinder{<0,0,0><0,0,-0.01>,1/16 translate <0.25,0.25,0>}
          cylinder{<0,0,0.01><0,0,-0.02>,3/64 translate <0.25,0.25,0>}
          }
        box{<0,0,0><17/64,0.125,-0.01> translate <3/64,3/64,0>}
        box{<0,0,0><0.125,0.125,-0.01> translate <21/64,3/64,0>}
        object {
          union {
            cylinder{<0,0,0><0,0,-0.01>,2/64}
            box{<-2/64,0,0><2/64,4/64,-0.01>}
            cylinder{<0,0,0><0,0,-0.01>,2/64 translate 4/64*y}
            }
          translate <0.25,23/64,0>
          }
        object {
          polygon {
            8,
            <4,0,0>/64,
            <4,4,0>/64,
            <8,4,0>/64,
            <0,8,0>/64,
            <-8,4,0>/64,
            <-4,4,0>/64,
            <-4,0,0>/64,
            <4,0,0>/64
            }
          translate <0.250,34/64,-0.01>
          }
        object { text { ttf "crystal.ttf" "2.4" 0.125, <0,0,0>} scale 0.125 translate <0.5625,0,-0.01> }
        }
      rotate 90*z
      rotate fFloppyIconAngle*y
      translate vArray[13]+0.375*y
      translate vNormVector3
      translate fInnerRadius*z+0.010*z
      pigment{White}
      }
 
  #local oFloppyDrive =
    object {
      union {
        object { oFloppyIcon }
        object { oOuterPerimeter translate fOuterRadius*z }
        object { oPolygon1 }                            //* Surface */
        object { oLever translate <(fFloppyDriveWidth-fLeverWidth)/2, (fHeight3-fLeverHeight-fLeverRadius),-(fLeverDepth+fLeverRadius)>}
        object {
          union {
            object {oInnerPerimeter1}                 //* Inner Perimeter */
            object {oInnerPerimeter2}                 //* Slot Inner Perimeter */
            object {                                  //* Slot Right bottom Surface
              triangle {
                vArray[13],
                vArray[14],
                vArray[21]
                }
              translate vNormVector1
              }
            object {                                  //* Slot Right Top Surface
              triangle {
                vArray[11],
                vArray[12],
                vArray[20]
                }
              translate vNormVector2
              }
            object {                                  //* Slot Right Middle Surface
              union {
                triangle {
                  vArray[13],
                  vArray[20],
                  vArray[21]
                  }
                triangle {
                  vArray[12],
                  vArray[13],
                  vArray[20]
                  }
                }
              translate vNormVector3
              }
            object {                                  //* Slot Left Top Surface
              union {
                triangle {
                  vArray[19],
                  vArray[7],
                  vArray[8]
                  }
                triangle {
                  vArray[19],
                  vArray[7],
                  vArray[18]
                  }
                }
              translate vNormVector4
              }
            object {                                  //* Slot Left Bottom Surface
              union {
                triangle {
                  vArray[16],
                  vArray[6],
                  vArray[5]
                  }
                triangle {
                  vArray[16],
                  vArray[6],
                  vArray[17]
                  }
                }
              translate vNormVector5
              }
            object {                                  //* Slot Left Middle Surface
              union {
                triangle {
                  vArray[16],
                  vArray[18],
                  vArray[17]
                  }
                triangle {
                  vArray[16],
                  vArray[18],
                  vArray[19]
                  }
                }
              translate vNormVector6
              }
            object {
              union {
                triangle {
                  vArray[17],
                  vArray[ 7],
                  vArray[ 6]
                  }
                triangle {
                  vArray[17],
                  vArray[ 7],
                  vArray[18]
                  }
                }
              translate vNormVector7
              }
            }
          translate fInnerRadius*z
          }
        }
      }
  oFloppyDrive
#end
