#declare fSin60 = sin(radians(60));

#macro Hexagon(fSide,fThickness)
  #local fWidth  = fSide*0.5;
  #local fHeight = fSide*fSin60;
  #local fDepth  = fThickness*0.5;
           
  #local oHexagon =
    object {
      prism {
        linear_sweep
        linear_spline
        -fDepth,
         fDepth,
        7,
        <-fWidth, fHeight>,
        < fWidth, fHeight>,
        < 2*fWidth, 0>,
        < fWidth,-fHeight>,
        <-fWidth,-fHeight>,
        <-2*fWidth, 0>,
        <-fWidth, fHeight> 
        }
      rotate 90*x
      }
  oHexagon
#end

#macro HollowHexagon(fSide,fThickness,fBorder)
  #local fWidth  = fSide*0.5;
  #local fHeight = fSide*fSin60;
  #local fDepth  = fThickness*0.5;
  #local fScale  = (fSide-fBorder)/fSide;
           
  #local oHexagon =
    object {
      prism {
        linear_sweep
        linear_spline
        -fDepth,
         fDepth,
        15,
        <-fWidth, fHeight>,
        < fWidth, fHeight>,
        < 2*fWidth, 0>,
        < fWidth,-fHeight>,
        <-fWidth,-fHeight>,
        <-2*fWidth, 0>,
        <-fWidth, fHeight>, 
        <-fWidth, fHeight>*fScale,
        < fWidth, fHeight>*fScale,
        < 2*fWidth, 0>*fScale,
        < fWidth,-fHeight>*fScale,
        <-fWidth,-fHeight>*fScale,
        <-2*fWidth, 0>*fScale,
        <-fWidth, fHeight>*fScale, 
        <-fWidth, fHeight>
        }
      rotate 90*x
      }
  oHexagon
#end

#macro HexGrid(fSide,fThickness,fBorder,nx,ny)
  #local fWidth     = fSide*0.5;
  #local fHeight    = fSide*fSin60;
  
  #local oHexagon =
    object {
      Hexagon(fSide,fThickness)
      }
               
  #local oHollowHexagon =
    object {
      HollowHexagon(fSide,fThickness,fBorder)
      }
               
  #local oGrid =
    object {
      union {
        #local ix = 0;
        #while (ix < nx+1)
          #local iy = 0;
          #while (iy < ny+1)
            #if ((ix = 0) | (ix = nx) | (iy = 0) | (iy = ny))
              object { oHexagon       translate < 6*fWidth*ix, 2*fHeight*iy, 0>}
            #else  
              object { oHollowHexagon translate < 6*fWidth*ix, 2*fHeight*iy, 0>}
            #end  
            #local iy = iy + 1;
          #end
          #local ix = ix + 1;
        #end
        #local ix = 0;
        #while (ix < nx)
          #local iy = 0;
          #while (iy < ny)
            object { oHollowHexagon translate < 6*fWidth*ix+3*fWidth, 2*fHeight*iy+1*fHeight, 0> }
            #local iy = iy + 1;
          #end
          #local ix = ix + 1;
        #end
        }
      translate -fWidth*x
      }
  oGrid
#end      
 