//***************************************************************************************************************/
//* Persistence of Vision Ray Tracer Scene Description File                                                     */
//* File: 2066.inc                                                                                              */
//* Vers: 3.6                                                                                                   */
//* Desc: z800 Processor Definition                                                                             */
//* Date: 11/10/2004                                                                                            */
//* Auth: D. E. LeMasters                                                                                       */
//***************************************************************************************************************/
#version 3.6;                                                           //*                                     */
#include "IBMLogo.inc"
#include "MyShapes.inc"                                                 //*                                     */
//***************************************************************************************************************/
//* Calculate Equation of a Line defined by 2D Vectors v0, v1                                                   */
//*   Returns 2D-Vector <Slope,Y-Intercept>                                                                     */
//***************************************************************************************************************/
#macro vLine(v0,v1)
  #local fa0 = (v1.y-v0.y)/(v1.x-v0.x);
  #local fb0 = v0.y-fa0*v0.x;
  <fa0,fb0>
#end
 
//***************************************************************************************************************/
//* Calculate Intersection of 2  Lines defined by 2D Vectors v0, v1                                             */
//*   Returns 2D-Vector <X,Y>                                                                                   */
//***************************************************************************************************************/
#macro vIntersect(vl0,vl1)
  #local fx  = (vl1.y-vl0.y)/(vl0.x-vl1.x);
  #local fy  = vl0.x*fx+vl0.y;
  <fx,fy>
#end
 
#macro PanelY(v0,v1,fR)
  #local fW = sqrt(f_sqr(v1.x-v0.x)+f_sqr(v1.z-v0.z));
  #local fH = v1.y-v0.y;
  #local oPanel =
    object {
      union {
        box     {<  0,  0,-fR>< fW, fH, fR>}
        cylinder{<  0,  0,  0><  0, fH,  0>, fR}
        cylinder{< fW,  0,  0>< fW, fH,  0>, fR}
        cylinder{<  0,  0,  0>< fW,  0,  0>, fR}
        cylinder{<  0, fH,  0>< fW, fH,  0>, fR}
        sphere  {<  0,  0,  0>, fR}
        sphere  {<  0, fH,  0>, fR}
        sphere  {< fW,  0,  0>, fR}
        sphere  {< fW, fH,  0>, fR}
        }
      rotate -degrees(atan2((v1.z-v0.z),(v1.x-v0.x)))*y
      translate v0
      }
  oPanel
#end
                                                                        //*                                     */
#macro PanelZ(v0,v1,fR)
  //*************************************************************************************************************/
  //* IBM Logo Dimensions                                                                                       */
  //*************************************************************************************************************/
  #local fIBMLogoWidth      = 2+5/8;                                    //* IBM Logo Width                      */
  #local fIBMLogoHeight     = 1+1/16;                                   //* IBM Logo Height                     */
  #local fIBMLogoDepth      = 0.125;                                    //* IBM Logo Depth                      */
  #local fIBMLogoXOffset    = 4.50;                                     //* IBM Logo X-Offset                   */
  #local fIBMLogoYOffset    = 2+3/8;                                    //* IBM Logo Y-Offset                   */
  #local fW = sqrt(f_sqr(v1.x-v0.x)+f_sqr(v1.z-v0.z));
  #local fH = v1.y-v0.y;
  #local oPanel =
    object {
      union {
        box     {<  0,  0,-fR>< fW, fH, fR>}
        cylinder{<  0,  0,  0><  0, fH,  0>, fR}
        cylinder{< fW,  0,  0>< fW, fH,  0>, fR}
        cylinder{<  0,  0,  0>< fW,  0,  0>, fR}
        cylinder{<  0, fH,  0>< fW, fH,  0>, fR}
        sphere  {<  0,  0,  0>, fR}
        sphere  {<  0, fH,  0>, fR}
        sphere  {< fW,  0,  0>, fR}
        sphere  {< fW, fH,  0>, fR}
        object  {IBMLogo(fIBMLogoWidth,fIBMLogoHeight,fIBMLogoDepth) translate <fIBMLogoXOffset,fH-fIBMLogoYOffset,0> pigment{White}}
        }
      rotate -degrees(atan2((v1.z-v0.z),(v1.x-v0.x)))*y
      translate v0
      }
  oPanel
#end
                                                                        //*                                     */
//***************************************************************************************************************/
//* z800 Macro Definition                                                                                       */
//***************************************************************************************************************/
#macro IBM2066(sSerial)
  //*************************************************************************************************************/
  //* Basic External Dimensions                                                                                 */
  //*************************************************************************************************************/
//  #local vz800Texture     = pigment{White*0.05};                        //* Base Texture                        */
  #local vz800Texture     = texture{pigment{White*0.05} 
                            normal { bumps 0.04 scale 0.0005 }
                            finish { phong 0.5 }
                            }
  #local fHeight          = 69.50;                                      //* Overall Height                      */
  #local fWidth           = 28.375;                                     //* Overall Width                       */
  #local fDepth           = 41.75;                                      //* Overall Depth                       */
  #local fPanelHeight     = 68.00;                                      //* Main Height                         */
//  #local fBaseHeight      =  3.25;                                      //* Base Height                         */
  #local fBaseHeight      =  0.00;                                      //* Base Height                         */
  #local fRadius          =  0.050;                                     //*                                     */
  #local fFrontWidth      = fWidth;                                     //*                                     */
  #local fFrontDepth      =  1.00;                                      //*                                     */
  #local fFrontHeight     = fPanelHeight;                               //*                                     */
  #local fFrontDoor3Top   = 1.75;                                       //*                                     */
  #local fFrontDoor3Len   = 0.625;                                      //*                                     */
  #local fFrontDoor4Top   = 1.75;                                       //*                                     */
  #local fFrontDoor4Len   = 0.625;                                      //*                                     */
  #local fRearWidth       = fWidth;                                     //*                                     */
  #local fRearDepth       =  1.00;                                      //*                                     */
  #local fSideWidth       = fDepth-((fFrontDepth+0.5)+(fRearDepth+0.5));//*                                     */
  #local fSideDepth       =  1.00;                                      //*                                     */
                                                                        //*                                     */
  #local vFrontDoor = array[9];                                         //* Construct Array of Corner vectors   */
  #local vFrontDoor[0] = < fRadius, 0.0, -fRadius>;                     //* Left Rear Corner                    */
  #local vFrontDoor[1] = < fRadius, 0.0,-(fFrontDepth-fRadius)>;        //* Left Front Corner                   */
  #local vFrontDoor[2] = < 4.3750, 0.0,-(fFrontDepth-fRadius)>;         //*                                     */
  #local vFrontDoor[3] = < 12.7058, 0.0, -2.5625>;                      //*                                     */
  #local vFrontDoor[4] = < 14.4379, 0.0, -1.5625>;                      //*                                     */
  #local vFrontDoor[5] = < 17.5277, 0.0, -3.6875>;                      //*                                     */
  #local vFrontDoor[6] = < fFrontWidth-fRadius, 0.0, -(fFrontDepth-fRadius)>; //* Right Front Corner            */
  #local vFrontDoor[7] = < fFrontWidth-fRadius, 0.0, -fRadius>;         //* Right Rear Corner                   */
  #local vFrontDoor[8] = < fRadius, 0.0, -fRadius>;                     //* Left Rear Corner                    */
                                                                        //*                                     */
  #local n = 0;
  #while (n < 9)
    #local n = n + 1;
  #end
                                                                        //*                                     */
  #local vFrontDoorPanelHeight = array[4];                              //*                                     */
  #local vFrontDoorPanelHeight[0] = fFrontHeight-23.5;                  //*                                     */
  #local vFrontDoorPanelHeight[1] = fFrontHeight-20.75;                 //*                                     */
  #local vFrontDoorPanelHeight[2] = fFrontHeight-20.75;                 //*                                     */
  #local vFrontDoorPanelHeight[3] = fFrontHeight-23.5;                  //*                                     */
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Switch Panel Definitions)                                                     */
  //*************************************************************************************************************/
  #local fSwitchPanelWidth   = 2.50;                                    //*                                     */
  #local fSwitchPanelHeight  = 3.75;                                    //*                                     */
  #local fSwitchPanelDepth   = 0.5;                                     //*                                     */
  #local fSwitchPanelXOffset = 1+13/16;                                 //*                                     */
  #local fSwitchPanelYOffset = fFrontHeight-fSwitchPanelHeight-16.50;   //*                                     */
  #local vSwitchPanelCoverTexture = T_Glass1;
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Switch Panel Cover Definitions)                                               */
  //*************************************************************************************************************/
  #local fSwitchCoverOffset = 0.10;
  #local fSwitchCoverWidth = fSwitchPanelWidth-2*fSwitchCoverOffset;
  #local fSwitchCoverHeight = fSwitchPanelHeight-2*fSwitchCoverOffset;
  #local fSwitchCoverDepth = 2*fRadius;
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Switch Definitions)                                                           */
  //*************************************************************************************************************/
  #local fSwitchWidth        = 1.0;                                     //*                                     */
  #local fSwitchHeight       = 2.0;                                     //*                                     */
  #local fSwitchDepth        = 0.5;                                     //*                                     */
  #local fSwitchBorder       = 0.125;                                   //*                                     */
  #local fSwitchXOffset      = 0.25;                                    //*                                     */
  #local fSwitchYOffset      = 0.75;                                    //*                                     */
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Latch Panel Definitions)                                                      */
  //*************************************************************************************************************/
  #local fLatchPanelWidth   = 1.625;                                    //*                                     */
  #local fLatchPanelHeight  = 4.000;                                    //*                                     */
  #local fLatchPanelDepth   = 0.75;                                     //*                                     */
  #local fLatchPanelXOffset = fFrontWidth-fLatchPanelWidth-1.750;       //*                                     */
  #local fLatchPanelYOffset = fFrontHeight-fLatchPanelHeight-27.75;     //*                                     */
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Latch Definitions)                                                            */
  //*************************************************************************************************************/
  #local fLatchWidth        = fLatchPanelWidth-0.5;                     //*                                     */
  #local fLatchHeight       = fLatchPanelHeight-0.5;                    //*                                     */
  #local fLatchDepth        = 1/8;                                      //*                                     */
  #local fLatchXOffset      = 0.325;
  #local fLatchYOffset      = 0.25;
  #local fLatchBorder       = 3/16;
  #local fLatchHandleGap    = 1/32;
  #local fLatchHandleWidth  = fLatchWidth -2*fLatchBorder-2*fLatchHandleGap;
  #local fLatchHandleHeight = fLatchHeight-2*fLatchBorder-2*fLatchHandleGap;
  #local fLatchHandleRadius = fLatchHandleWidth*0.5;
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Calc Base Line Equations)                                                     */
  //*************************************************************************************************************/
  #local vFrontBLine = array[8];
  #local VFrontBPerp = array[8];
  #local VFrontBPerp[0] = <0,0,0>;
  #local n = 0;
  #while (n < 8)
    #local vFrontBLine[n] = vLine(<vFrontDoor[n].x,vFrontDoor[n].z>,<vFrontDoor[n+1].x,vFrontDoor[n+1].z>);
    #local VFrontBPerp[n] = VPerp_To_Vector(vFrontDoor[n+1]-vFrontDoor[n]);
    #local n = n + 1;
  #end
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Calc Parallel Line Equations                                                  */
  //*************************************************************************************************************/
  #local vFrontPLine = array[4];
  #local vFrontPLine[0] = vLine(<vFrontDoor[2].x,vFrontDoor[2].z>-<vFrontDoor[2].x-vFrontDoor[1].x, 2*fRadius>,<vFrontDoor[3].x,vFrontDoor[3].z>-<vFrontDoor[2].x-vFrontDoor[1].x, 2*fRadius>);
  #local vFrontPLine[1] = vLine(<vFrontDoor[3].x,vFrontDoor[3].z>,<vFrontDoor[4].x,vFrontDoor[4].z>);
  #local vFrontPLine[2] = vLine(<vFrontDoor[2].x,vFrontDoor[2].z>-<VFrontBPerp[2].x,VFrontBPerp[2].z>*2*fRadius,<vFrontDoor[3].x,vFrontDoor[3].z>-<VFrontBPerp[2].x,VFrontBPerp[2].z>*2*fRadius);
  #local vFrontPLine[3] = vLine(<vFrontDoor[1].x,vFrontDoor[1].z>-< 0, 2*fRadius>,<vFrontDoor[2].x,vFrontDoor[2].z>-< 0, 2*fRadius>);
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Calc Front Panel Corner Point Vectors)                                        */
  //*************************************************************************************************************/
  #local vFrontBPoint = array[4];                                       //* Bottom Corner Points                */
  #local vFrontTPoint = array[4];                                       //* Top Corner Points                   */
  #local n = 0;
  #while (n < 4)
    #local vPoint = vIntersect(vFrontPLine[n],vFrontPLine[mod(n+1,4)]);
    #local vFrontBPoint[n] = <vPoint.x, 0, vPoint.y>;
    #local vFrontTPoint[n] = vFrontBPoint[n]+vFrontDoorPanelHeight[n]*y;
    #local n = n + 1;
  #end
 
  #local n = 0;
  #while (n < 4)
    #local n = n + 1;
  #end
 
  #local vFrontSPoint = array[6];                                       //* Side Slot Corner Points             */
  #local vFrontSPoint[0] = vFrontBPoint[0]+fFrontDoor3Top*y;
  #local vFrontSPoint[1] = vFrontBPoint[1]+fFrontDoor3Top*y;
  #local vFrontSPoint[2] = vFrontTPoint[0]-fFrontDoor3Top*y;
  #local vFrontSPoint[3] = vFrontTPoint[1]-fFrontDoor3Top*y;
  #local vFrontSPoint[4] = vFrontBPoint[0]+fFrontDoor3Len*vnormalize(vFrontBPoint[1]-vFrontBPoint[0])+fFrontDoor3Top*y;
  #local vFrontSPoint[5] = vFrontTPoint[0]+fFrontDoor3Len*vnormalize(vFrontBPoint[1]-vFrontBPoint[0])                 ;
 
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Construct Endcap)                                                             */
  //*************************************************************************************************************/
  #local oFrontDoorCap =                                                //*    Construct Endcap                 */
    object {                                                            //*                                     */
      prism {                                                           //*                                     */
        linear_spline                                                   //*                                     */
        0, fRadius                                                      //*                                     */
        9                                                               //*                                     */
        <vFrontDoor[0].x,vFrontDoor[0].z>                               //*                                     */
        <vFrontDoor[1].x,vFrontDoor[1].z>                               //*                                     */
        <vFrontDoor[2].x,vFrontDoor[2].z>                               //*                                     */
        <vFrontDoor[3].x,vFrontDoor[3].z>                               //*                                     */
        <vFrontDoor[4].x,vFrontDoor[4].z>                               //*                                     */
        <vFrontDoor[5].x,vFrontDoor[5].z>                               //*                                     */
        <vFrontDoor[6].x,vFrontDoor[6].z>                               //*                                     */
        <vFrontDoor[7].x,vFrontDoor[7].z>                               //*                                     */
        <vFrontDoor[0].x,vFrontDoor[0].z>                               //*                                     */
        }                                                               //*                                     */
      }                                                                 //*                                     */
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Front Cover Panels)                                                           */
  //*************************************************************************************************************/
  #local oFrontCoverPanels =
    object {
      union {
        #local n = 0;
        #while (n < 7)
          #switch (n)
            #case (3)
              #local vFrontDoor3 = vFrontDoor[n]+(vFrontDoor[n+1]-vFrontDoor[n])*fFrontDoor3Len/vlength(vFrontDoor[n+1]-vFrontDoor[n]);
              object {PanelY(vFrontDoor[n],vFrontDoor3+fFrontHeight*y,fRadius)}
              object {PanelY(vFrontDoor[n],vFrontDoor[n+1]+fFrontDoor3Top*y,fRadius)}
              object {PanelY(vFrontDoor[n],vFrontDoor[n+1]+fFrontDoor3Top*y,fRadius) translate (fFrontHeight-fFrontDoor3Top)*y}
            #break
            #case (4)
              #local vFrontDoor4 = vFrontDoor[n]+(vFrontDoor[n+1]-vFrontDoor[n])*(vlength(vFrontDoor[n+1]-vFrontDoor[n])-fFrontDoor4Len)/vlength(vFrontDoor[n+1]-vFrontDoor[n]);
              object {PanelY(vFrontDoor4,vFrontDoor[n+1]+fFrontHeight*y,fRadius)}
              object {PanelY(vFrontDoor[n],vFrontDoor[n+1]+fFrontDoor4Top*y,fRadius)}
              object {PanelY(vFrontDoor[n],vFrontDoor[n+1]+fFrontDoor4Top*y,fRadius) translate (fFrontHeight-fFrontDoor4Top)*y}
            #break
            #case (5)
              object {PanelZ(vFrontDoor[n],vFrontDoor[n+1]+fFrontHeight*y,fRadius)}
            #break
            #else
              object {PanelY(vFrontDoor[n],vFrontDoor[n+1]+fFrontHeight*y,fRadius)}
          #end
          #local n = n + 1;
        #end
        }
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (eServer Logo)                                                                 */
  //*************************************************************************************************************/
  #local feServerXOffset =  9.5;
  #local feServerYOffset = 43.5;
  #local feServerDepth   = 0.061250;
  #local feServerAngle = atan((vFrontBPoint[0].z-vFrontBPoint[3].z)/(vFrontBPoint[0].x-vFrontBPoint[3].x));
  #local oeE =
    object {
    intersection {
      height_field {
        gif
        "BigRedE" 
        scale <1,10,1>
        }
      box{<0,0.05,0><1,1,1>}
      }
    rotate -90*x
    translate <0.2,-0.1,0.25>
    scale <0.75,0.75,0.75>
    pigment{Red}
    }        
  
  #local oeServer =
    object {
      union {
        object {oeE}
        text { ttf "timrom.ttf" "server" 0.250, <0,0,0>  pigment{White} translate 1*x}
        }
      scale 0.5
      translate < feServerXOffset, feServerYOffset,-(fRadius+feServerDepth)>
      rotate -degrees(feServerAngle)*y
      translate <vFrontBPoint[3].x, vFrontBPoint[3].y, vFrontBPoint[3].z>
      pigment{White}
      }
  //*************************************************************************************************************/
  //* z800 Front Door Definition (zServer Logo)                                                                 */
  //*************************************************************************************************************/
  #local fzSeriesDepth   = 0.250;
  #local fzSeriesXOffset = 0.25;
  #local fzSeriesYOffset = 48;
  #local fzSeriesAngle = atan((vFrontDoor[3].z-vFrontDoor[2].z)/(vFrontDoor[3].x-vFrontDoor[2].x));
  #local ozSeries =
    object {
      text { ttf "ariblk.ttf" "zSeries" 0.125, <0,0,0>}
      scale 0.375
      translate <fzSeriesXOffset,fSwitchPanelYOffset+fSwitchPanelHeight*0.5,-(fRadius+fzSeriesDepth)>
      rotate -degrees(fzSeriesAngle)*y
      translate vFrontDoor[2]
      pigment{White}
      }
 
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Switch Panel Text)                                                            */
  //*************************************************************************************************************/
  #local fSwitchPanelText0Len = Text_Width("crystal.ttf","Emergency Power Off",1, 0);
  #local fSwitchPanelText0Scale = 0.70*fSwitchPanelWidth/fSwitchPanelText0Len;
  #local oSwitchPanelText0 =
    object {
      text { ttf "crystal.ttf" "Emergency Power Off" 0.125, <0,0,0>}
      scale fSwitchPanelText0Scale
      pigment{White}
      }
  #local fSwitchPanelText1Len = Text_Width("crystal.ttf","After using the emergency switch,",1, 0);
  #local fSwitchPanelText1Scale = 0.75*fSwitchPanelWidth/fSwitchPanelText1Len;
  #local oSwitchPanelText1 =
    object {
      text { ttf "crystal.ttf" "After using the emergency switch," 0.125, <0,0,0>}
      scale fSwitchPanelText1Scale
      pigment{White}
      }
  #local fSwitchPanelText2Len = Text_Width("crystal.ttf","trained service personnel are required",1, 0);
  #local oSwitchPanelText2 =
    object {
      text { ttf "crystal.ttf" "trained service personnel are required" 0.125, <0,0,0>}
      scale fSwitchPanelText1Scale
      pigment{White}
      }
  #local fSwitchPanelText3Len = Text_Width("crystal.ttf","to restore power to the server",1, 0);
  #local oSwitchPanelText3 =
    object {
      text { ttf "crystal.ttf" "to restore power to the server" 0.125, <0,0,0>}
      scale fSwitchPanelText1Scale
      pigment{White}
      }
  #local fSwitchPanelText4Len = Text_Width("crystal.ttf","Type  2066",1, 0);
  #local oSwitchPanelText4 =
    object {
      text { ttf "crystal.ttf" "Type  2066" 0.125, <0,0,0>}
      scale fSwitchPanelText1Scale
      pigment{White}
      }
  #local fSwitchPanelText5Len = Text_Width("crystal.ttf","S/N  02-2410A",1, 0);
  #local oSwitchPanelText5 =
    object {
      text { ttf "crystal.ttf" sSerial 0.125, <0,0,0>}
      scale fSwitchPanelText1Scale
      pigment{White}
      }
 
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Switch On/Off Text)                                                           */
  //*************************************************************************************************************/
  #local oSwitchPanelTextI =
    object {
      box{< 0, 0, 0>< 3/64, 1/4, 1/8>}
      pigment{White}
      }
  #local oSwitchPanelTextO =
    object {
      difference {
        cylinder{< 0, 0, 0><0,0,1/8>,1/8}
        cylinder{< 0, 0, -0.01><0,0,1/8+0.01>,5/64}
        }
      pigment{White}
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Switch Panel Hole)                                                            */
  //*************************************************************************************************************/
  #local oSwitchPanelHole =
    object {
      box{< 0, 0, -(fFrontDepth+0.1)>< fSwitchPanelWidth, fSwitchPanelHeight, fSwitchPanelDepth+0.01>}
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Switch Hole)                                                                  */
  //*************************************************************************************************************/
  #local oSwitchHole =
    object {
      box{< 0, 0, -(fFrontDepth+0.1)>< fSwitchWidth, fSwitchHeight, fSwitchDepth+0.01>}
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Switch )                                                                      */
  //*************************************************************************************************************/
  #local oSwitch =
    object {
      union {
        difference {
          box{< 0, 0, 0><fSwitchWidth,fSwitchHeight,fSwitchDepth> pigment{Black}}
          box{<fSwitchBorder,fSwitchBorder,-0.01><fSwitchWidth-fSwitchBorder,fSwitchHeight-fSwitchBorder,fSwitchDepth>}
          }
        object{RoundBoxHole(fSwitchWidth-2*fSwitchBorder,fSwitchHeight-2*fSwitchBorder,fSwitchDepth,fRadius) translate <fSwitchBorder,fSwitchBorder,0>}
        object {
          union {
            cylinder{<fSwitchBorder+0.05,0.0,0.0>< fSwitchWidth-fSwitchBorder-0.05,0.0,0.0>,(fSwitchHeight*0.5-2*fSwitchBorder-0.10)}
            box {<fSwitchBorder+0.05,-0.0625,0.0>< fSwitchWidth-fSwitchBorder-0.05,+0.0625,-fSwitchHeight*0.6>}
            }
          rotate 30*x
          translate < 0,fSwitchHeight*0.5, fSwitchHeight*0.5>
          pigment{Red}
          }
        }
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Switch Panel Cover)                                                           */
  //*************************************************************************************************************/
  #local oSwitchPanelCover =
    object {
      union {
        cylinder{<-fSwitchCoverOffset,fSwitchCoverHeight-fRadius,fRadius><fSwitchCoverWidth+fSwitchCoverOffset,fSwitchCoverHeight-fRadius,fRadius>,fRadius}
        box{<0,0,0><fSwitchCoverWidth,fSwitchCoverHeight,fSwitchCoverDepth>}
        cylinder{<2*fSwitchCoverDepth,0,0><2*fSwitchCoverDepth,fRadius*0.5,0>,2*fSwitchCoverDepth}
        cylinder{<fSwitchCoverWidth-2*fSwitchCoverDepth,0,0><fSwitchCoverWidth-2*fSwitchCoverDepth,fRadius*0.5,0>,2*fSwitchCoverDepth}
        box{<2*fSwitchCoverDepth,0,0><fSwitchCoverWidth-2*fSwitchCoverDepth,fRadius*0.5,-2*fSwitchCoverDepth>}
        cylinder{<2*fSwitchCoverDepth,fRadius*0.5,-2*fSwitchCoverDepth+fRadius*0.5><fSwitchCoverWidth-2*fSwitchCoverDepth,fRadius*0.5,-2*fSwitchCoverDepth+fRadius*0.5>,fRadius*0.5}
        }
      translate <fSwitchCoverOffset, fSwitchCoverOffset, fRadius>
      texture{vSwitchPanelCoverTexture}
      }
 
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Switch Panel)                                                                 */
  //*************************************************************************************************************/
  #local oSwitchPanel =
    object {
      union {
        difference {
          object{RoundBoxHole(fSwitchPanelWidth,fSwitchPanelHeight,fSwitchPanelDepth,fRadius)}
          object{oSwitchHole translate<fSwitchXOffset,fSwitchYOffset,fSwitchPanelDepth>}
          }
        object{oSwitch translate<fSwitchXOffset,fSwitchYOffset,fSwitchPanelDepth>}
        object{oSwitchPanelText0 translate < 0.15, fSwitchPanelHeight-0.25, fSwitchPanelDepth-0.01>}
        object{oSwitchPanelText1 translate < 0.15, fSwitchPanelHeight-0.42, fSwitchPanelDepth-0.01>}
        object{oSwitchPanelText2 translate < 0.15, fSwitchPanelHeight-0.54, fSwitchPanelDepth-0.01>}
        object{oSwitchPanelText3 translate < 0.15, fSwitchPanelHeight-0.66, fSwitchPanelDepth-0.01>}
        object{oSwitchPanelTextI translate < 1.50, 2.25, fSwitchPanelDepth-0.01>}
        object{oSwitchPanelTextO translate < 1.50, 1.25, fSwitchPanelDepth-0.01>}
        object{oSwitchPanelText4 translate < 0.30, 0.60, fSwitchPanelDepth-0.01>}
        object{oSwitchPanelText5 translate < 0.30, 0.48, fSwitchPanelDepth-0.01>}
        object{oSwitchPanelCover}
        }
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Latch Panel Hole )                                                            */
  //*************************************************************************************************************/
  #local fLatchAngle    = atan((vFrontDoor[6].z-vFrontDoor[5].z)/(vFrontDoor[6].x-vFrontDoor[5].x)) ;
  #local fLatchPanelX1  = vFrontDoor[6].x - fLatchPanelXOffset;
  #local fLatchPanelY1  = fLatchPanelYOffset;
  #local fLatchPanelZ1  = vFrontDoor[6].z-fLatchPanelX1*tan(fLatchAngle)-fRadius/cos(fLatchAngle);
  #local fLatchPanelX2  = fLatchPanelX1-fLatchPanelWidth;
  #local fLatchPanelY2  = fLatchPanelY1+fLatchPanelHeight;
  #local fLatchPanelZ2  = vFrontDoor[6].z-fLatchPanelX2*tan(fLatchAngle)-fRadius/cos(fLatchAngle);
  #local vLatchPoint    = array[4];
  #local vLatchPoint[0] = <fLatchPanelXOffset,fLatchPanelY1,fLatchPanelZ1>;
  #local vLatchPoint[1] = <fLatchPanelXOffset,fLatchPanelY2,fLatchPanelZ1>;
  #local vLatchPoint[2] = <fLatchPanelXOffset+fLatchPanelWidth,fLatchPanelY1,fLatchPanelZ2>;
  #local vLatchPoint[3] = <fLatchPanelXOffset+fLatchPanelWidth,fLatchPanelY2,fLatchPanelZ2>;
  #local vLatchNorm     = vnormalize(vcross(vLatchPoint[0]-vLatchPoint[1],vLatchPoint[0]-vLatchPoint[3]))*fRadius;
  #local n = 0;
  #while (n < 4)
    #local vLatchPoint[n] = vLatchPoint[n]-vLatchNorm;
    #local n = n + 1;
  #end
 
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Latch Panel Hole )                                                            */
  //*************************************************************************************************************/
  #local oLatchPanelHole =
    object {
      box{< 0, 0, -3*(fFrontDepth+0.1)>< fLatchPanelWidth, fLatchPanelHeight, fLatchPanelDepth>}
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Latch Handle Hole)                                                            */
  //*************************************************************************************************************/
  #local oLatchHandleHole =
    object {
      union {
        Round_Box(<fLatchBorder,fLatchBorder+fLatchHandleGap+fLatchHandleRadius-fRadius,-(fLatchDepth+0.1)>,
                  <fLatchWidth-fLatchBorder,fLatchHeight-fLatchBorder, 0>,
                  fRadius,true)
        cylinder{<fLatchWidth*0.5,fLatchBorder+fLatchHandleGap+fLatchHandleRadius,-(fLatchDepth+0.1)>
                 <fLatchWidth*0.5,fLatchBorder+fLatchHandleGap+fLatchHandleRadius,                 0>,
                 fLatchHandleRadius+fLatchHandleGap
          }
        }
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Latch Handle)                                                                 */
  //*************************************************************************************************************/
  #local oLatchHandle =
    object {
      union {
        Round_Cylinder(<fLatchBorder+fLatchHandleGap,fLatchHeight-fLatchBorder-fLatchHandleGap-fLatchDepth*0.5,fLatchDepth*0.5>,
                       <fLatchWidth-fLatchBorder-fLatchHandleGap,fLatchHeight-fLatchBorder-fLatchHandleGap-fLatchDepth*0.5,-fLatchDepth*0.5>,
                       fLatchDepth*0.5,fRadius,true)
        difference {
          union {
            Round_Box(<fLatchBorder+fLatchHandleGap,fLatchHeight-fLatchBorder-fLatchHandleGap-fLatchDepth*0.5+fRadius,0>
                      <fLatchWidth-fLatchBorder-fLatchHandleGap,fLatchBorder+fLatchHandleGap+fLatchHandleRadius-fRadius,-fLatchDepth>,
                      fRadius,true)
            Round_Cylinder(<fLatchWidth*0.5,fLatchBorder+fLatchHandleGap+fLatchHandleRadius,0>,
                           <fLatchWidth*0.5,fLatchBorder+fLatchHandleGap+fLatchHandleRadius,-fLatchDepth>,
                           fLatchHandleRadius,fRadius,true)
            }
          union {
            box{< 0, 0, 0><fLatchWidth,1/64,1/64> translate<0,fLatchBorder+fLatchHandleGap+2*fLatchHandleRadius+fLatchHandleGap,-(fLatchDepth+0.1)>}
            cylinder{<fLatchWidth*0.5,fLatchBorder+fLatchHandleGap+fLatchHandleRadius,0>,
                     <fLatchWidth*0.5,fLatchBorder+fLatchHandleGap+fLatchHandleRadius,-(fLatchDepth+0.1)>,
                     fLatchHandleRadius-1/16}
            }
          }
        difference {
          cylinder{<fLatchWidth*0.5,fLatchBorder+fLatchHandleGap+fLatchHandleRadius,0>,
                   <fLatchWidth*0.5,fLatchBorder+fLatchHandleGap+fLatchHandleRadius,-fLatchDepth>,
                   fLatchHandleRadius-1/16-0.02}
          object {
            union {
              box{<-3/64,-3/32,-3/32><3/64,3/32,3/32> rotate 45*x}
              box{<-3/64,-3/32,-3/32><3/64,3/32,3/32> rotate 45*x rotate 90*z}
              }
            translate < fLatchWidth*0.5,fLatchBorder+fLatchHandleGap+fLatchHandleRadius,-fLatchDepth>
            }
          }
        }
      }
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Latch)                                                                        */
  //*************************************************************************************************************/
  #local oLatch =
    object {
      union {
        difference {
          object{Round_Box(<0,0,-fLatchDepth>,<fLatchWidth,fLatchHeight, 0>,fRadius,true)}
          object{oLatchHandleHole}
          }
        object { oLatchHandle }
//      object {
//        object{Round_Box(<fLatchBorder+1/16,fLatchBorder+1/16,-(fLatchDepth+0.1)>,<fLatchWidth-fLatchBorder-1/16,fLatchHeight-fLatchBorder-1/16,0>,fRadius,true)}
//        }
        }
//    pigment{Red}
      }
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Latch Panel)                                                                  */
  //*************************************************************************************************************/
  #local oLatchPanel =
    object {
      union {
        sphere{vLatchPoint[0], fRadius}
        sphere{vLatchPoint[1], fRadius}
        sphere{vLatchPoint[2], fRadius}
        sphere{vLatchPoint[3], fRadius}
        cylinder{vLatchPoint[0] vLatchPoint[1], fRadius}
        cylinder{vLatchPoint[1] vLatchPoint[3], fRadius}
        cylinder{vLatchPoint[3] vLatchPoint[2], fRadius}
        cylinder{vLatchPoint[2] vLatchPoint[0], fRadius}
        box{vLatchPoint[0],vLatchPoint[0]+< fRadius,fLatchPanelHeight,fLatchPanelDepth>}
        box{vLatchPoint[1],vLatchPoint[0]+<-fRadius,fLatchPanelHeight,fLatchPanelDepth>}
        polygon{
          5
          vLatchPoint[0]+< 0, fRadius, 0>
          vLatchPoint[2]+< 0, fRadius, 0>
          vLatchPoint[2]+< 0, fRadius, fLatchPanelDepth>
          vLatchPoint[0]+< 0, fRadius, fLatchPanelDepth>
          vLatchPoint[0]+< 0, fRadius, 0>
          }
        polygon{
          5,
          vLatchPoint[1]+< 0,-fRadius, 0>
          vLatchPoint[3]+< 0,-fRadius, 0>
          vLatchPoint[3]+< 0,-fRadius, fLatchPanelDepth>
          vLatchPoint[1]+< 0,-fRadius, fLatchPanelDepth>
          vLatchPoint[1]+< 0,-fRadius, 0>
          }
        polygon{
          5
          <vLatchPoint[0].x,vLatchPoint[0].y,vLatchPoint[0].z+fLatchPanelDepth>
          <vLatchPoint[1].x,vLatchPoint[1].y,vLatchPoint[0].z+fLatchPanelDepth>
          <vLatchPoint[3].x,vLatchPoint[3].y,vLatchPoint[0].z+fLatchPanelDepth>
          <vLatchPoint[2].x,vLatchPoint[2].y,vLatchPoint[0].z+fLatchPanelDepth>
          <vLatchPoint[0].x,vLatchPoint[0].y,vLatchPoint[0].z+fLatchPanelDepth>
          }
        object {
          oLatch
          translate vLatchPoint[0]+<fLatchXOffset,fLatchYOffset,fLatchPanelDepth>
          }
        }
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Front Cover)                                                                  */
  //*************************************************************************************************************/
  #local oFrontCover =
    object {
      difference {
        object { oFrontCoverPanels}
        object { oSwitchPanelHole translate < fSwitchPanelXOffset, fSwitchPanelYOffset,-fFrontDepth>}
        object { oLatchPanelHole  translate < fLatchPanelXOffset , fLatchPanelYOffset ,0>}
        }
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Top Cap of Front Panel)                                                       */
  //*************************************************************************************************************/
//#local oSwitch =
//  object {
//    union {
//      cylinder{< 0, 0, 0><fSwitchWidth, 0, 0>,fRadius}
//      cylinder{< 0,fSwitchHeight,0><fSwitchWidth,fSwitchHeight,0>,fRadius}
//      cylinder{< 0, 0,0><0,fSwitchHeight,0>,fRadius}
//      cylinder{<fSwitchWidth,0,0><fSwitchWidth,fSwitchHeight,0>,fRadius}
//      }
//    }
 
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Top Cap of Front Panel)                                                       */
  //*************************************************************************************************************/
  #local oFrontPanelCap =
    object {
      union {
        triangle {
          vFrontTPoint[0], vFrontTPoint[1], vFrontTPoint[2]
          }
        triangle {
          vFrontTPoint[0], vFrontTPoint[2], vFrontTPoint[3]
          }
        }
      translate vnormalize(vcross(vFrontTPoint[2]-vFrontTPoint[0],vFrontTPoint[1]-vFrontTPoint[0]))*fRadius
      }
 
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Front Side of Front Panel)                                                    */
  //*************************************************************************************************************/
  #local oFrontPanelFront =
    object {
      union {
        object {
          union {
            triangle {
              vFrontBPoint[0], vFrontTPoint[0], vFrontTPoint[3]
              }
            triangle {
              vFrontBPoint[0], vFrontBPoint[3], vFrontTPoint[3]
              }
            }
          translate vnormalize(vcross(vFrontTPoint[3]-vFrontBPoint[0],vFrontTPoint[0]-vFrontBPoint[0]))*fRadius
          }
        object{ ozSeries }
        object{ oeServer }
        }
      }
 
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Right Side of Front Panel)                                                    */
  //*************************************************************************************************************/
  #local oFrontPanelSide =
    object {
      union {
        triangle {
          vFrontTPoint[0], vFrontTPoint[1], vFrontSPoint[3]
          }
        triangle {
          vFrontTPoint[0], vFrontSPoint[2], vFrontSPoint[3]
          }
        triangle {
          vFrontTPoint[0], vFrontSPoint[5], vFrontSPoint[4]
          }
        triangle {
          vFrontTPoint[0], vFrontSPoint[4], vFrontSPoint[0]
          }
        triangle {
          vFrontBPoint[0], vFrontSPoint[0], vFrontSPoint[1]
          }
        triangle {
          vFrontBPoint[0], vFrontBPoint[1], vFrontSPoint[1]
          }
        }
      translate -vnormalize(vcross(vFrontSPoint[3]-vFrontTPoint[0],vFrontTPoint[1]-vFrontTPoint[0]))*fRadius
      }
 
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Front Panel)                                                                  */
  //*************************************************************************************************************/
  #local oFrontPanelFrame =
    object {
      union {
        sphere   { vFrontBPoint[0],fRadius}
        sphere   { vFrontBPoint[1],fRadius}
        sphere   { vFrontBPoint[2],fRadius}
        sphere   { vFrontBPoint[3],fRadius}
        sphere   { vFrontTPoint[0],fRadius}
        sphere   { vFrontTPoint[1],fRadius}
        sphere   { vFrontTPoint[2],fRadius}
        sphere   { vFrontTPoint[3],fRadius}
        sphere   { vFrontSPoint[1],fRadius}
        sphere   { vFrontSPoint[3],fRadius}
        cylinder { vFrontBPoint[0],vFrontBPoint[1],fRadius}
        cylinder { vFrontBPoint[1],vFrontBPoint[2],fRadius}
        cylinder { vFrontBPoint[2],vFrontBPoint[3],fRadius}
        cylinder { vFrontBPoint[3],vFrontBPoint[0],fRadius}
        cylinder { vFrontTPoint[0],vFrontTPoint[1],fRadius}
        cylinder { vFrontTPoint[1],vFrontTPoint[2],fRadius}
        cylinder { vFrontTPoint[2],vFrontTPoint[3],fRadius}
        cylinder { vFrontTPoint[3],vFrontTPoint[0],fRadius}
        cylinder { vFrontBPoint[0],vFrontTPoint[0],fRadius}
        cylinder { vFrontBPoint[3],vFrontTPoint[3],fRadius}
        cylinder { vFrontSPoint[0],vFrontSPoint[1],fRadius}
        cylinder { vFrontSPoint[2],vFrontSPoint[3],fRadius}
        cylinder { vFrontSPoint[4],vFrontSPoint[5],fRadius}
        cylinder { vFrontBPoint[1],vFrontSPoint[1],fRadius}
        cylinder { vFrontTPoint[1],vFrontSPoint[3],fRadius}
        }
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Front Panel)                                                                  */
  //*************************************************************************************************************/
  #local oFrontPanel =
    object {
      union {
        object {oFrontPanelFrame}
        object {oFrontPanelCap  }
        object {oFrontPanelSide }
        object {oFrontPanelFront}
        }
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition (Cooper Colored Insert)                                                        */
  //*************************************************************************************************************/
  #local oFrontInsert =
    object{
      union {
        cylinder{<0,0.001,0><0,fFrontHeight-0.001,0>,fFrontDepth}
        box{<0,0.001,-fFrontDepth>< 3*fFrontDepth,fFrontHeight-0.001,-(fFrontDepth-0.001)> rotate -30*y}
        box{<0,0.001,-fFrontDepth><-3*fFrontDepth,fFrontHeight-0.001,-(fFrontDepth-0.001)> rotate  30*y}
        }
      translate vFrontDoor[4].x*x
      texture{T_Copper_5C}
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 Front Door Definition                                                                                */
  //*************************************************************************************************************/
  #local oFrontDoor =                                                   //* Complete Front Door                 */
    object {
      union {
        object{oFrontCover}                                             //* Base Front Door Cover               */
        object{oFrontInsert}                                            //* Front Copper Insert                 */
        object{oFrontDoorCap}                                           //* Bottom Door Cap                     */
        object{oFrontDoorCap translate (fFrontDoor3Top)*y}              //* Bottom Door Cap (Inside)            */
        object{oFrontDoorCap translate (fFrontHeight)*y}                //* Top Door Cap                        */
        object{oFrontDoorCap translate (fFrontHeight-fFrontDoor3Top)*y} //* Top Door Cap (Inside)               */
        object{oFrontPanel}                                             //* Front Panel                         */
        object {
          oSwitchPanel
          translate <fSwitchPanelXOffset,fSwitchPanelYOffset,-fFrontDepth>
          }
        object {
          oLatchPanel
          }
        }
      translate fFrontDepth*z
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* z800 FSide Panel Definition                                                                               */
  //*************************************************************************************************************/
  #local oSidePanel =
    object {
      Round_Box(< 0, 0, 0>,< fSideDepth, fPanelHeight, fSideWidth>, fRadius, true)
      }
 
  //*************************************************************************************************************/
  //* z800 Rear Door Definition                                                                                 */
  //*************************************************************************************************************/
  #local oRearDoor =
    object {
      Round_Box(< 0, 0, 0>,< fRearWidth, fPanelHeight, fRearDepth>, fRadius, true)
      }
 
  #local fFootPadRadius   =  1.25;
  #local fFootPadHeight   =  0.5;
  #local fFootRadius      =  0.25;
  #local fFootHeight      =  1.50;
  #local oFoot =
    object {
      union {
        cylinder{<0,0,0><0,fFootPadHeight,0>,fFootPadRadius pigment{Black}}
        cylinder{<0,0,0><0,fFootHeight,0>,fFootRadius pigment{White*0.5}}
        }
      }
 
  //*************************************************************************************************************/
  //* z800 Definition                                                                                           */
  //*************************************************************************************************************/
  #local oz800 =
    object {
      union {
        box {
          < 0, fFootHeight, 0>< fWidth-(2*fSideDepth), fHeight, fDepth-(fFrontDepth+fRearDepth)>
          translate < fSideDepth, 0, fFrontDepth>
          pigment{Black}
          }
        object {
          union {
            object { oFrontDoor }
            object { oRearDoor  translate < 0, 0, fDepth-fRearDepth>}
            object { oSidePanel translate < 0, 0, fFrontDepth+0.5>}
            object { oSidePanel translate < fWidth-fSideDepth, 0, fFrontDepth+0.5>}
            }
          translate < 0, fHeight-fPanelHeight, 0>
          }
        object {oFoot translate <2,0,2>}  
        object {oFoot translate <fWidth-2,0,2>}  
        object {oFoot translate <2,0,fDepth-2>}  
        object {oFoot translate <fWidth-2,0,fDepth-2>}  
        }
      scale 1/12
      texture { vz800Texture }
      }
  oz800
#end
