//***************************************************************************************************************/
//* Persistence of Vision Ray Tracer Scene Description File                                                     */
//* File: Shark.inc                                                                                             */
//* Vers: 3.6                                                                                                   */
//* Desc: Shark - 2105 Enterprise System - Common Data Definitions                                              */
//* Date: 10/27/2004                                                                                            */
//* Auth: D. E. LeMasters                                                                                       */
//***************************************************************************************************************/
#version 3.6;                                                           //*                                     */
                                                                        //*                                     */
#include "Cover.inc"
#include "Hex.inc"
#include "SharkFin.inc" 
//***************************************************************************************************************/
//* Basic External Dimensions                                                                                   */
//***************************************************************************************************************/
#declare fESSHeight       = 72.00;                                      //* Overall Height                      */
#declare fESSWidth        = 54.50;                                      //* Overall Width                       */
#declare fESSDepth        = 35.75;                                      //* Overall Depth                       */
#declare fESSPanelHeight  = 67.50;                                      //* Main Height                         */
#declare fESSBaseHeight   =  3.00;                                      //* Base Height                         */
                                                                        //*                                     */
//***************************************************************************************************************/
//* Rear Door Vent Grid Dimensions                                                                              */
//***************************************************************************************************************/
//*
//* #declare fGridRadius      = 3/32;                                       //* Rear Door Vent Grid Hole Radius     */
//* #declare fGridSpacing     = 1/4;                                        //* Rear Door Grid Hole Spacing         */
//* #declare fGridLeft        = 2.5;                                        //* Rear Door Vent Grid X-Offset        */
//* #declare fGridTop         = 5.2;                                        //* Rear Door Vent Grid Y-Offset        */
//* #declare fGridX           = 90;                                         //* Rear Door Vent Grid X-Number        */
//* #declare fGridY           =  8;                                         //* Rear Door Vent Grid Y-Number        */
                                                                            //*                                     */
#declare v2105Texture     = texture{pigment{White*0.05} 
                            normal { bumps 0.04 scale 0.0005 }
                            finish { phong 0.5 }
                            }
                                                                        //*                                     */
//***************************************************************************************************************/
//* ESS 2105 Definition                                                                                         */
//***************************************************************************************************************/
#macro IBM2105(bDetail)                                                 //*                                     */
  //*************************************************************************************************************/
  //* Top Cap Dimensions                                                                                        */
  //*************************************************************************************************************/
  #local fTopHeight         = 4.00;                                     //* Top Cap Height                      */
  #local fTopWidth          = fESSWidth;                                //* Top Cap Width                       */
  #local fTopDepth          = fESSDepth;                                //* Top Cap Depth                       */
  #local fTopRadius         = 0.050;                                    //* Top Cap Corner Radius               */
  //*************************************************************************************************************/
  //* IBM Logo Dimensions                                                                                       */
  //*************************************************************************************************************/
  #local fIBMLogoWidth      = 3.1;                                      //* IBM Logo Width                      */
  #local fIBMLogoHeight     = 1.3;                                      //* IBM Logo Height                     */
  #local fIBMLogoDepth      = 0.25;                                     //* IBM Logo Depth                      */
  #local fIBMLogoXOffset    = 3.00;                                     //* IBM Logo X-Offset                   */
  //*************************************************************************************************************/
  //* Common Front Door Dimensions                                                                              */
  //*************************************************************************************************************/
  #local fFrontWidth        = 22.0;                                     //* Front Door Width                    */
  #local fFrontHeight       = fESSPanelHeight;                          //* Front Door Width                    */
  #local fFrontDepth        =  3.25;                                    //* Front Door Depth                    */
  #local fFrontRadius       = 0.050;                                    //* Front Door Corner Radius            */
  #local fFrontSideWidth    = 3.00;
  #local fFrontPanelWidth   = 1.50;
  #local fFrontPanelDepth   = 1.00;
  #local fFrontGridWidth    = fFrontPanelWidth*0.9;
  #local fFrontGridHeight   = fFrontHeight-3.0;
  #local fFrontGridNX       = 4;
  //*************************************************************************************************************/
  //* Center Panel Dimensions                                                                                   */
  //*************************************************************************************************************/
  #local fCenterWidth       = 9.5;                                      //* Center Panel Width                  */
  #local fCenterHeight      = fESSPanelHeight;                          //* Center Panel Height                 */
  #local fCenterDepth       =  3.25;                                    //* Center Panel Depth                  */
  #local fCenterRadius      = 0.050;                                    //* Center Panel Corner Radius          */
  //*************************************************************************************************************/
  //* Control Panel Dimensions                                                                                  */
  //*************************************************************************************************************/
  #local fControlPanelWidth     = 5.5;                                  //* Control Panel Width                 */
  #local fControlPanelHeight    = 8.5;                                  //* Control Panel Height                */
  #local fControlPanelDepth     = 1.25;                                 //* Control Panel Deoth                 */
  #local fControlPanelYOffset   = fCenterHeight-24;                     //* Control Panel Y-Offset              */
  #local fControlPanelXOffset   = (fCenterWidth-fControlPanelWidth)/2;  //* Control Panel X-Offset (Centered)   */
  #local fControlFaceWidth      = 4.5;                                  //* Contrpl Panel Face Width            */
  #local fSwitchWidth           = 1.0;
  #local fSwitchHeight          = 2.2;
  #local fSwitchDepth           = 0.25;
  #local fSwitchTopAngle        = degrees(atan(fSwitchDepth/(fSwitchHeight/4)));
  #local fSwitchSideAngle       = degrees(atan(fSwitchDepth/(fSwitchWidth/4)));
  #local fLEDWidth              = 0.25;
  #local fLEDHeight             = 0.125;
  #local fLEDDepth              = 2*fCenterRadius;
  //*************************************************************************************************************/
  //* "TotalStorage" Logo Dimensions                                                                            */
  //*************************************************************************************************************/
  #local fTotalWidth        = 2.50;                                     //* Width of TotalStorage Logo          */
  #local fTotalXOffset      = (fCenterWidth-fTotalWidth)/2;             //* Total Storage X Offset              */
  #local fTotalYOffset      = 2.50;                                     //* Total Storage Y Offset              */
  //*************************************************************************************************************/
  //* Rear Door Dimensions                                                                                      */
  //*************************************************************************************************************/
  #local fRearWidth         = 27.0;                                     //* Rear Door Width                     */
  #local fRearHeight        = fESSPanelHeight;                          //* Rear Door Width                     */
  #local fRearDepth         =  2.375;                                   //* Rear Door Height                    */
  #local fRearRadius        =  0.050;                                   //* Rear Door Corner Radius             */
  //*************************************************************************************************************/
  //* Side Door Dimensions                                                                                      */
  //*************************************************************************************************************/
  #local fSideWidth         = 28.75;                                    //* Side Door Width                     */
  #local fSideHeight        = fESSPanelHeight;                          //* Side Door Width                     */
  #local fSideDepth         = 1.0;                                      //* Side Door Depth                     */
  #local fSideRadius        = 0.050;                                    //* Side Door Corner Radius             */
  #local fSideGap = (fESSDepth-(fFrontDepth+fSideWidth+fRearDepth))/2;  //* Side Door Gap On Each Side          */
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* 2105 Internal Frame                                                                                       */
  //*************************************************************************************************************/
  #local oFrame =
    object {
      box {
        < fSideDepth, 0, fFrontDepth>
        < fESSWidth-fSideDepth, fESSHeight, fESSDepth-fRearDepth>
        }
      }
 
  //*************************************************************************************************************/
  //* 2105 Top Cap Definition                                                                                   */
  //*************************************************************************************************************/
  #local oTopCap =
    object {
      union {
        object {
          Round_Box(< 0, 0, 0>,< fTopWidth, fTopHeight, fTopDepth-fFrontDepth>,fTopRadius,true)
          translate fFrontDepth*z
          }
        object {
          Round_Box(< 0, 0, 0>,< fTopWidth, fTopHeight, fTopHeight>,fTopRadius,true)
          Shear_Trans(x,y-(fFrontDepth/fTopHeight)*z,z)
          translate fFrontDepth*z
          }
        object {
          union {
            box {< 0, 0, 0>< fIBMLogoWidth, fIBMLogoHeight, fIBMLogoHeight>}
            object {
              IBMLogo(fIBMLogoWidth,fIBMLogoHeight,fIBMLogoDepth)
              pigment{White}
              }
            }
          translate < fIBMLogoXOffset, (fTopHeight-fIBMLogoHeight)/2, 0>
          }
        object {
          SharkFin()
          translate <fTopWidth/2,fTopHeight,fTopDepth/3>
          }
        }
      }
 
  //*************************************************************************************************************/
  //* 2105 Front Door Definition                                                                                */
  //*************************************************************************************************************/
  #local fFrontPanelAngle  = degrees(atan(fFrontPanelDepth/fFrontPanelWidth));
  #local fFrontPanelLength = fFrontPanelDepth/sin(radians(fFrontPanelAngle));
  #local fFrontGridSize    = fFrontGridWidth/(3*fFrontGridNX-1);
  #local fFrontGridSizeY   = fFrontGridSize*sin(radians(60));
  #local fFrontGridNY      = int(fFrontGridHeight/(2*fFrontGridSizeY));
  #local fFrontGridHeight  = 2*fFrontGridSizeY*fFrontGridNY;
  #local fFrontGridXOffset = (fFrontPanelLength-fFrontGridWidth)/2;
  #local fFrontGridYOffset = (fFrontHeight-fFrontGridHeight)/2;
 
  #local oFrontPanel =
    object {
      #if (bDetail)
      union {
        difference {
      #end
          Round_Box(<-fFrontRadius, 0, -fFrontRadius>,<fFrontPanelLength+fFrontRadius, fFrontHeight, fFrontRadius>,fFrontRadius,true)
      #if (bDetail)
          box{< fFrontGridXOffset, fFrontGridYOffset,-(fFrontRadius+0.001)><fFrontPanelLength-fFrontGridXOffset,fFrontHeight-fFrontGridYOffset, (fFrontRadius+0.001)>}
          }
        object {
          HexGrid(fFrontGridSize,2*fFrontRadius,fFrontGridSize*0.2,fFrontGridNX,fFrontGridNY)
          translate <fFrontGridXOffset, fFrontGridYOffset, 0>
          }
        }
      #end
      }
 
  #local oFrontPanelWedgeCap =
        object {
          prism {
            0,
            fFrontRadius,
            6,
            < 0, fFrontPanelDepth+fFrontRadius>
            < fFrontPanelWidth, fFrontRadius>
            < 2*fFrontPanelWidth, fFrontPanelDepth+fFrontRadius>
            < 2*fFrontPanelWidth, fFrontDepth-fFrontRadius>
            < 0, fFrontDepth-fFrontRadius>
            < 0, fFrontPanelDepth+fFrontRadius>
            }
          }
 
  #local oFrontPanelWedge =
    object {
      union {
        object {
          union {
            object { oFrontPanel rotate -2*fFrontPanelAngle*y translate fFrontPanelLength*x}
            object { oFrontPanel }
            }
          rotate  fFrontPanelAngle*y
          translate (fFrontPanelDepth+fFrontRadius)*z
          }
        object { oFrontPanelWedgeCap }
        object { oFrontPanelWedgeCap  translate (fFrontHeight-fFrontRadius)*y }
        }
      }
 
  #local oFrontDoor =
    object {
      union {
        object {
          union {
            object { oFrontPanel rotate -fFrontPanelAngle*y translate fFrontRadius*z }
            object { oFrontPanelWedgeCap translate -fFrontPanelWidth*x }
            object { oFrontPanelWedgeCap translate -fFrontPanelWidth*x translate (fFrontHeight-fFrontRadius)*y }
            #local ix = 0;
            #while (ix < 6)
              object { oFrontPanelWedge translate (ix*2+1)*fFrontPanelWidth*x }
              #local ix = ix + 1;
            #end
            object { Round_Box(<13*fFrontPanelWidth,0,fFrontPanelDepth>,<13*fFrontPanelWidth,fFrontHeight,fFrontDepth>,fFrontRadius,true)}
            cylinder{< 0, fFrontHeight-fFrontRadius, fFrontDepth-fFrontRadius><13*fFrontPanelWidth,fFrontHeight-fFrontRadius, fFrontDepth-fFrontRadius>,fFrontRadius}
            }
          translate (fFrontSideWidth-fFrontRadius)*x
          }
        object {
          Round_Box(< 0, 0, 0>,< fFrontSideWidth, fFrontHeight, fFrontDepth>, fFrontRadius, true)
          }
        }
      }
 
  //*************************************************************************************************************/
  //* 2105 Center Panel Definition                                                                              */
  //*************************************************************************************************************/
  #local oTotalStorage =
    object {
      text { ttf "timrom.ttf" "TotalStorage" 0.125, <0,0,0>}
      translate -0.125*z
      }
  #local fTotalScale = fTotalWidth/(max_extent(oTotalStorage).x - min_extent(oTotalStorage).x);
 
  #local fControlPanelAngle = degrees(atan(fControlPanelDepth/(fControlPanelWidth-fControlFaceWidth)));
 
  #local oControlPanelFrame =                                           //* Control Panel Frame                 */
    object {
      union {
        sphere{<-fCenterRadius                   ,-fCenterRadius                    , fCenterRadius>,fCenterRadius}
        sphere{< fControlPanelWidth+fCenterRadius,-fCenterRadius                    , fCenterRadius>,fCenterRadius}
        sphere{< -fCenterRadius                  , fControlPanelHeight+fCenterRadius, fCenterRadius>,fCenterRadius}
        sphere{< fControlPanelWidth+fCenterRadius, fControlPanelHeight+fCenterRadius, fCenterRadius>,fCenterRadius}
        cylinder{
          <-fCenterRadius                   ,-fCenterRadius                    , fCenterRadius>
          < fControlPanelWidth+fCenterRadius,-fCenterRadius                    , fCenterRadius>,
          fCenterRadius
          }
        cylinder{
          <-fCenterRadius                   , fControlPanelHeight+fCenterRadius, fCenterRadius>
          < fControlPanelWidth+fCenterRadius, fControlPanelHeight+fCenterRadius, fCenterRadius>,
          fCenterRadius
          }
        cylinder{
          <-fCenterRadius                   ,-fCenterRadius                    , fCenterRadius>
          <-fCenterRadius                   , fControlPanelHeight+fCenterRadius, fCenterRadius>,
          fCenterRadius
          }
        cylinder{
          < fControlPanelWidth+fCenterRadius,-fCenterRadius                    , fCenterRadius>
          < fControlPanelWidth+fCenterRadius, fControlPanelHeight+fCenterRadius, fCenterRadius>,
          fCenterRadius
          }
        box{
          <-fCenterRadius                   ,-fCenterRadius                    , fCenterRadius     >
          < fControlPanelWidth+fCenterRadius, 0                                , fControlPanelDepth>
          }
        box{
          <-fCenterRadius                   , fControlPanelHeight              , fCenterRadius     >
          < fControlPanelWidth+fCenterRadius, fControlPanelHeight+fCenterRadius, fControlPanelDepth>
          }
        box{
          < fControlPanelWidth              ,-fCenterRadius                    , fCenterRadius     >
          < fControlPanelWidth+fCenterRadius, fControlPanelHeight+fCenterRadius, fControlPanelDepth>
          }
        box{
          < 0                                                  ,-fCenterRadius                    , 0                 >
          < fControlPanelDepth/sin(radians(fControlPanelAngle)), fControlPanelHeight+fCenterRadius,-fCenterRadius     >
          rotate -fControlPanelAngle*y
          translate <-fCenterRadius, 0, fCenterRadius>
          }
        }
      }
 
  #local oUnitSwitch =                                                  //*                                     */
    object {
      union {
        box{<-fCenterRadius, 0, 0>< 0,-fSwitchHeight, fSwitchDepth>}
        box{<-fCenterRadius, 0, 0>< 0,-fSwitchHeight, fSwitchDepth> translate (fCenterRadius+fSwitchWidth)*x}
        box{< 0, 0, 0>< fSwitchWidth,-(fSwitchHeight/4)/cos(radians(fSwitchTopAngle)), fCenterRadius>
          rotate -degrees(asin(0.25/(fSwitchHeight/4)))*x
          }
        box{< 0, 0, 0>< fSwitchWidth, (fSwitchHeight/4)/cos(radians(fSwitchTopAngle)), fCenterRadius>
          rotate  degrees(asin(0.25/(fSwitchHeight/4)))*x
          translate -fSwitchHeight*y
          }
        object {
          intersection {
            cylinder { <fCenterRadius,0,0>< fSwitchWidth-fCenterRadius,0,0>,fSwitchHeight/4-fCenterRadius}
            box {<fCenterRadius,-fSwitchHeight/2,0><fSwitchWidth-fCenterRadius, fSwitchHeight/2,fSwitchHeight/2>}
            }
          rotate  15*x
          translate -fSwitchHeight/2*y
          translate fSwitchDepth/2*z
          pigment{Red}
          }
        }
      }
 
  #local oLocalSwitch =
    object {
      union {
        box{<-fCenterRadius, 0, 0>< 0,-fSwitchHeight, fSwitchDepth>}
        box{<-fCenterRadius, 0, 0>< 0,-fSwitchHeight, fSwitchDepth> translate (fCenterRadius+fSwitchWidth)*x}
        box{< 0, 0, 0>< fSwitchWidth,-(fSwitchHeight/4)/cos(radians(fSwitchTopAngle)), fCenterRadius>
          rotate -fSwitchTopAngle*x
          }
        box{< 0, 0, 0>< fSwitchWidth, (fSwitchHeight/4)/cos(radians(fSwitchTopAngle)), fCenterRadius>
          rotate  fSwitchTopAngle*x
          translate -fSwitchHeight*y
          }
        box{< 0, 0, 0>< (fSwitchWidth/4)/cos(radians(fSwitchSideAngle)),-fSwitchHeight, fCenterRadius>
          rotate -fSwitchSideAngle*y
          }
        box{< 0, 0, 0><-(fSwitchWidth/4)/cos(radians(fSwitchSideAngle)),-fSwitchHeight, fCenterRadius>
          rotate  fSwitchSideAngle*y
          translate  fSwitchWidth*x
          }
        object {
          intersection {
            cylinder {
              <fSwitchWidth/4+fFrontRadius,0,0>
              < fSwitchWidth-fSwitchWidth/4-fFrontRadius,0,0>,
              fSwitchHeight/4-fFrontRadius
              }
            box {<fFrontRadius,-fSwitchHeight/2,0><fSwitchWidth-fFrontRadius, fSwitchHeight/2,fSwitchHeight/2>}
            }
          translate -fSwitchHeight/2*y
          translate fSwitchDepth/2*z
          pigment{White}
          }
        }
      }
 
  #local oPowerOff =
    object {
      box { < 0, 0, -0.003>< 1/32, 1/4, fCenterRadius>}
      pigment{White}
      }
 
  #local oPowerOn =
    object {
      union {
        cylinder {< 0, 0, -0.001>< 0, 0, fCenterRadius>,1/8}
        cylinder {< 0, 0, -0.002>< 0, 0, fCenterRadius>,3/32 texture{v2105Texture}}
        box { < -2/64, 0, -0.002>< 4/64, 1/4, fCenterRadius> texture{v2105Texture}}
        box { < 0, 0, -0.003>< 1/32, 1/4, fCenterRadius>}
        }
      pigment{White}
      }
 
  #local oLED =
    object {
      box {<0,0,0><fLEDWidth,fLEDHeight,fLEDDepth>}
      texture {pigment{Green} finish{ambient Green}}
      }
 
  #local oControlPanelFace =
    object {
      union {
        difference {                                                      //* Cut Holes for Switchs and LEDs      */
          box { < 0, 0, 0> < fControlPanelWidth, fControlPanelHeight, fCenterRadius>}
          union {
            box{< 0, 0, -0.1>< fSwitchWidth,-fSwitchHeight, fCenterRadius+0.1> translate < 2, fControlPanelHeight-1.1, 0>}
            box{< 0, 0, -0.1>< fSwitchWidth,-fSwitchHeight, fCenterRadius+0.1> translate < 2, fControlPanelHeight-3.8, 0>}
            box{< 0, 0, -0.1>< fLEDWidth, fLEDHeight, fCenterRadius+0.1> translate < 2+fSwitchWidth/2-fLEDWidth/2, fControlPanelHeight-6.40,0>}
            box{< 0, 0, -0.1>< fLEDWidth, fLEDHeight, fCenterRadius+0.1> translate < 2+fSwitchWidth/2-fLEDWidth/2, fControlPanelHeight-6.60,0>}
            box{< 0, 0, -0.1>< fLEDWidth, fLEDHeight, fCenterRadius+0.1> translate < 2+fSwitchWidth/2-fLEDWidth/2, fControlPanelHeight-7.20,0>}
            box{< 0, 0, -0.1>< fLEDWidth, fLEDHeight, fCenterRadius+0.1> translate < 2+fSwitchWidth/2-fLEDWidth/2, fControlPanelHeight-7.40,0>}
            box{< 0, 0, -0.1>< fLEDWidth, fLEDHeight, fCenterRadius+0.1> translate < 2+fSwitchWidth/2-fLEDWidth/2, fControlPanelHeight-8.00,0>}
            box{< 0, 0, -0.1>< fLEDWidth, fLEDHeight, fCenterRadius+0.1> translate < 2+fSwitchWidth/2-fLEDWidth/2, fControlPanelHeight-8.20,0>}
            }
          }
        object {                                       //* Unit Emergency Power Switch */
          oUnitSwitch
          translate < 2, fControlPanelHeight-1.10, 0>
          }
        object {                                       //* Local/Remote Power Switch */
          oLocalSwitch
          translate < 2, fControlPanelHeight-3.80, 0>
          }
        object {                                                        //* LED                                 */
          oLED
          translate < 2+fSwitchWidth/2-fLEDWidth/2, fControlPanelHeight-6.40,0>
          }
        object {                                       //* LED */
          oLED
          translate < 2+fSwitchWidth/2-fLEDWidth/2, fControlPanelHeight-6.60,0>
          }
        object {                                       //* LED */
          oLED
          translate < 2+fSwitchWidth/2-fLEDWidth/2, fControlPanelHeight-7.20,0>
          }
        object {                                       //* LED */
          oLED
          translate < 2+fSwitchWidth/2-fLEDWidth/2, fControlPanelHeight-7.40,0>
          }
        object {                                       //* LED */
          oLED
          translate < 2+fSwitchWidth/2-fLEDWidth/2, fControlPanelHeight-8.00,0>
          pigment{White*0.2}
          }
        object {                                       //* LED */
          oLED
          translate < 2+fSwitchWidth/2-fLEDWidth/2, fControlPanelHeight-8.20,0>
          pigment{White*0.2}
          }
        object {
          text { ttf "crystal.ttf" "Unit" fCenterRadius <0,0,0>}
          scale <0.25,0.25,1>
          translate < 3.5, fControlPanelHeight-1.50, -0.001>
          pigment{White}
          }
        object {
          text { ttf "crystal.ttf" "Emergency" fCenterRadius <0,0,0>}
          scale <0.25,0.25,1>
          translate < 3.5, fControlPanelHeight-1.75, -0.001>
          pigment{White}
          }
        object {
          oPowerOff
          translate < 3.5, fControlPanelHeight-2.35, 0.00>
          pigment{White}
          }
        object {
          oPowerOn
          translate < 3.5, fControlPanelHeight-2.85, 0.00>
          pigment{White}
          }
        object {
          text { ttf "crystal.ttf" "Local" fCenterRadius <0,0,0>}
          scale <0.25,0.25,1>
          translate < 3.5, fControlPanelHeight-4.20, -0.001>
          pigment{White}
          }
        object {
          text { ttf "crystal.ttf" "Power" fCenterRadius <0,0,0>}
          scale <0.25,0.25,1>
          translate < 3.5, fControlPanelHeight-4.45, -0.001>
          pigment{White}
          }
        object {
          oPowerOff
          translate < 3.5, fControlPanelHeight-5.05, 0.00>
          pigment{White}
          }
        object {
          oPowerOn
          translate < 3.5, fControlPanelHeight-5.55, 0.00>
          pigment{White}
          }
        object {
          text { ttf "crystal.ttf" "Ready" fCenterRadius <0,0,0>}
          scale <0.20,0.20,1>
          translate < 2.5, fControlPanelHeight-6.20, -0.001>
          pigment{White}
          }
        object {
          text { ttf "crystal.ttf" "Cluster 1" fCenterRadius <0,0,0>}
          scale <0.15,0.15,1>
          translate < 2.8, fControlPanelHeight-6.40, -0.001>
          pigment{White}
          }
        object {
          text { ttf "crystal.ttf" "Cluster 2" fCenterRadius <0,0,0>}
          scale <0.15,0.15,1>
          translate < 2.8, fControlPanelHeight-6.60, -0.001>
          pigment{White}
          }
        object {
          text { ttf "crystal.ttf" "Power Complete" fCenterRadius <0,0,0>}
          scale <0.20,0.20,1>
          translate < 2.5, fControlPanelHeight-7.00, -0.001>
          pigment{White}
          }
        object {
          text { ttf "crystal.ttf" "Line Cord 1" fCenterRadius <0,0,0>}
          scale <0.15,0.15,1>
          translate < 2.8, fControlPanelHeight-7.20, -0.001>
          pigment{White}
          }
        object {
          text { ttf "crystal.ttf" "Line Cord 2" fCenterRadius <0,0,0>}
          scale <0.15,0.15,1>
          translate < 2.8, fControlPanelHeight-7.40, -0.001>
          pigment{White}
          }
        object {
          text { ttf "crystal.ttf" "Messages" fCenterRadius <0,0,0>}
          scale <0.20,0.20,1>
          translate < 2.5, fControlPanelHeight-7.80, -0.001>
          pigment{White}
          }
        object {
          text { ttf "crystal.ttf" "Cluster 1" fCenterRadius <0,0,0>}
          scale <0.15,0.15,1>
          translate < 2.8, fControlPanelHeight-8.00, -0.001>
          pigment{White}
          }
        object {
          text { ttf "crystal.ttf" "Cluster 2" fCenterRadius <0,0,0>}
          scale <0.15,0.15,1>
          translate < 2.8, fControlPanelHeight-8.20, -0.001>
          pigment{White}
          }
        }
      }
                                                                        //*                                     */
  #local oCenterPanel =
    object {
      union {
        object {                                                        //* Base Center Panel                   */
          difference {
            object {                                                    //* Box for Center Panel                */
              Round_Box(< 0, 0, 0>,< fCenterWidth, fCenterHeight, fCenterDepth>,fCenterRadius,true)
              }
            object {                                                    //* Remove Hole for Control Panel       */
              box{
                < -fCenterRadius, -fCenterRadius, -fCenterRadius>
                < fControlPanelWidth+fCenterRadius, fControlPanelHeight+fCenterRadius, fCenterDepth+fCenterRadius>
                }
              translate < fControlPanelXOffset, fControlPanelYOffset, 0>
              }
            }
          }
        object {                                                        //* Add Control Panel Frame             */
          oControlPanelFrame
          translate < fControlPanelXOffset, fControlPanelYOffset, 0>
          }
        object {
          oControlPanelFace
          translate < fControlPanelXOffset, fControlPanelYOffset, fControlPanelDepth>
          }
        object {
          ControlPanelDoor()
          translate < fControlPanelXOffset+fControlPanelWidth-fCenterRadius, fControlPanelYOffset, 0>
          }
        object {                                                        //* Total Storage Logo                  */
          oTotalStorage
          scale < fTotalScale, fTotalScale, 1 >
          translate < fTotalXOffset, fCenterHeight-fTotalYOffset, 0.00>
          pigment{White}
          }
        }
      }
 
  //*************************************************************************************************************/
  //* 2105 Rear Door Definition                                                                                 */
  //*************************************************************************************************************/
  #local oRearDoor =
    object {
      Round_Box(< 0, 0, 0>,< fRearWidth, fRearHeight, fRearDepth>,fRearRadius,true)
      }
 
  //*************************************************************************************************************/
  //* 2105 Side Panel Definition                                                                                */
  //*************************************************************************************************************/
  #local oSidePanel =
    object {
      Round_Box(< 0, 0, 0>,< fSideDepth, fSideHeight, fSideWidth>,fSideRadius,true)
      }
 
  #local fFootPadRadius   =  1.25;
  #local fFootPadHeight   =  0.5;
  #local fFootRadius      =  0.25;
  #local fFootHeight      =  1.50;
  #local oFoot =
    object {
      union {
        cylinder{<0,0,0><0,fFootPadHeight,0>,fFootPadRadius pigment{Black}}
        cylinder{<0,0,0><0,fFootHeight,0>,fFootRadius pigment{White*0.5}}
        }
      }
 
  //*************************************************************************************************************/
  //* 2105 Complete Assembly Definition                                                                         */
  //*************************************************************************************************************/
  #local o2105 =
    object {
      union {
        object {
          union {
            object { oFrame                }
            object { oTopCap      translate < 0, fESSHeight-fTopHeight, 0>}
            object { oFrontDoor   translate < 0, 0, 0>}
            object { oCenterPanel translate < fESSWidth-fFrontWidth-fCenterWidth, 0, 0>}
            object { oFrontDoor   rotate 180*z translate < fESSWidth, fFrontHeight, 0 >}
            object { oRearDoor    translate < 0, 0, fESSDepth-fRearDepth>}
            object { oRearDoor    translate < fESSWidth-fRearWidth, 0, fESSDepth-fRearDepth>}
            object { oSidePanel   translate < 0, 0, fFrontDepth+fSideGap>}
            object { oSidePanel   translate < fESSWidth-fSideDepth, 0, fFrontDepth+fSideGap>}
            }
          translate fFootHeight*y
          }
        object {oFoot translate <2,0,2>}  
        object {oFoot translate <fESSWidth-2,0,2>}  
        object {oFoot translate <2,0,fESSDepth-2>}  
        object {oFoot translate <fESSWidth-2,0,fESSDepth-2>}  
        }
      scale 1/12                                                        //* Change Inches to Feet               */
      texture { v2105Texture }
      }
  o2105
#end
 
//***************************************************************************************************************/
