//***************************************************************************************************************/
//* Persistence of Vision Ray Tracer Scene Description File                                                     */
//* File: 3174.inc                                                                                              */
//* Vers: 3.6                                                                                                   */
//* Desc: 3174 Control Unit                                                                                     */
//* Date: 11/19/2004                                                                                            */
//* Auth: D. E. LeMasters                                                                                       */
//***************************************************************************************************************/
#version 3.6;                                                           //*                                     */
#include "FloppyDrive.inc"
 
//***************************************************************************************************************/
//* IBM 3174 Network Processor                                                                                  */
//***************************************************************************************************************/
#macro IBM3174()
  //*************************************************************************************************************/
  //* Basic External Dimensions                                                                                 */
  //*************************************************************************************************************/
  #local t3174Texture     =  texture {
                        pigment{rgb <0.85,0.85,0.65>}                   //* Base Texture                        */
                        normal { bumps 0.04 scale 0.0005 }
                        finish { phong .5 }
                        }
  #local fHeight          = 20.50;                                      //* Overall Height                      */
  #local fWidth           = 27.50;                                      //* Overall Width                       */
  #local fDepth           = 16.75;                                      //* Overall Depth                       */
  #local fBaseHeight      =  2.75;                                      //* Base Height                         */
  #local fRadius          =  0.050;                                     //*                                     */
  #local fFrontWidth      = fWidth;                                     //*                                     */
  #local fFrontDepth      =  1.00;                                      //*                                     */
  #local fFrontHeight     = fHeight;                                    //*                                     */
  #local fRearWidth       = fWidth;                                     //*                                     */
  #local fRearDepth       =  1.00;                                      //*                                     */
  #local fSideWidth       = fDepth-((fFrontDepth+0.5)+(fRearDepth+0.5));//*                                     */
  #local fSideDepth       =  1.00; 
  
  #local fLegHeight       =  2.50;
  #local fLegRadius       =  0.75;                                      //*                                     */
 
  #local fControlPanelWidth = 9.0;
  #local fControlPanelHeight = 6.0;
  #local fControlPanelDepth = fFrontDepth+0.1;
  #local fControlPanelXOffset = 16.125;
  #local fControlPanelYOffset = 13.00;
 
  #local fControlPanelFaceAngle = 7;
  #local fControlPanelFaceZOffset = 0.25;
 
  #local fStatusWidth        = 2.375;
  #local fStatusHeight       = 0.625;
  #local fStatusDepth        = 0.125;
  #local fStatusXOffset      = 0.375;
  #local fStatusYOffset      = 4.125;
 
  #local fLEDWidth           = 0.375;
  #local fLEDHeight          = 0.125;
  #local fLEDDepth           = 0.125;
 
  #local fButtonWidth        = 0.625;
  #local fButtonHeight       = 0.250;
  #local fButtonDepth        = 0.0625;
  #local fButtonXOffset      = 0.375;
  #local fButtonYOffset      = 0.500;
  #local fButtonXSpace       = 0.8125;
  #local fButtonYSpace       = 0.8000;
 
  #local fKnobDepth          = 1/16;
  #local fKnobRadius         = 0.375;
 
  #local fFloppyPanelWidth   = 4.75;
  #local fFloppyPanelHeight  = 6.0;
  #local fFloppyPanelDepth   = 6.0;
  #local fFloppyPanelXOffset = 10.375;
  #local fFloppyPanelYOffset = 13.00;
  #local fFloppyPanelZOffset =  0.50;
  #local fFloppyPanelDivider = 1.00;
  #local fFloppyPanelFiller  = (fFloppyPanelWidth-(2*fFloppyDriveWidth+fFloppyPanelDivider))/2;
 
  #local fDrivePanelWidth    = 0.75;
  #local fDrivePanelHeight   = 6.0;
  #local fDrivePanelDepth    = 6.0;
  #local fDrivePanelXOffset  =   8.625;
  #local fDrivePanelYOffset  = 13.00;
  #local fDrivePanelZOffset  =  0.50;
 
  #local fSwitchPanelWidth   = 3.00;
  #local fSwitchPanelHeight  = 5.0;
  #local fSwitchPanelDepth   = 0.50;
  #local fSwitchPanelXOffset = 22.125;
  #local fSwitchPanelYOffset =  5.50;
 
  #local fSwitchKnobXOffset = 1.25;
  #local fSwitchKnobYOffset = 1.00;
  #local fSwitchLEDXOffset  = 0.250;
  #local fSwitchLEDYOffset  = 3.125;
  #local fSwitchToggleXOffset = 0.750;
  #local fSwitchToggleYOffset = 2.625;
  #local fSwitchToggleWidth   = 0.875;
  #local fSwitchToggleHeight  = 1.250;
  #local fSwitchToggleDepth   = 1.00;
  #local fSwitchToggleRadius  = fSwitchToggleHeight/4;
  #local fSwitchToggleAngle   = degrees(atan(2*fSwitchToggleRadius/(fSwitchToggleHeight/2)));
  #local fSwitchToggleSlope   = (fSwitchToggleHeight/2)/cos(radians(fSwitchToggleAngle))-fSwitchToggleRadius*1.2;
 
  #local fVentPanelWidth     = 5.75;
  #local fVentPanelHeight    = fHeight-3.0;
  #local fVentPanelDepth     = fFrontDepth+0.1;
  #local fVentPanelXOffset   =  1.250;
  #local fVentPanelYOffset   =    1.50;
  #local nVentSlats          = 45;
  #local fVentSlatHeight     = fVentPanelHeight/(2*nVentSlats);
  #local fVentSlatDepth      = 1/16;
  
  #local fLogoPanelWidth     = 1.0;
  #local fLogoPanelHeight    = 1.0;
  #local fLogoPanelDepth     = 1/16;
  #local fLogoPanelXOffset   =  8.625;
  #local fLogoPanelYOffset   =  9.500;

  #local fAddressPanelWidth  = 1.00;
  #local fAddressPanelHeight = 0.75;
  #local fAddressPanelDepth  = 1/16;
  #local fAddressPanelBar    = 1/16;
  #local fAddressPanelXOffset = 24.25;
  #local fAddressPanelYOffset =  4.25;

  #local oControlPanelHole   =
    object {
      box {< 0, 0, -0.10><fControlPanelWidth,fControlPanelHeight,fControlPanelDepth>}
      }
 
  #local oControlStatusHole =
    object {
      box{< 0, 0, -0.1>< fStatusWidth, fStatusHeight, fStatusDepth>}
      }
 
  #local oControlStatus =
    object {
      box{< 0, 0, 0>< fStatusWidth, fStatusHeight, fStatusDepth>}
      }
 
  #local oControlLEDHole =
    object {
      box{< -0.01, -0.01, -0.1>< fLEDWidth+0.01, fLEDHeight+0.01, fLEDDepth>}
      }
 
  #local oControlLED =
    object {
      box{< 0, 0, 0>< fLEDWidth, fLEDHeight, fLEDDepth>}
      translate -fLEDDepth/2*z
      }
 
  #local oControlButtonHole =
    object {
      box{< -0.02, -0.02, -0.1>< fButtonWidth+0.02, fButtonHeight+0.02, fButtonDepth+0.01>}
      }
 
  #local oControlButton =
    object {
      Round_Box(< 0, 0, -fButtonDepth>,< fButtonWidth, fButtonHeight, fButtonDepth>,fRadius,false)
      pigment{White*0.5}
      }
 
  #local oControlKnob =
    object {
      union {
        object {Round_Cylinder(< 0, 0, 0>,< 0, 0,-fKnobDepth>, fKnobRadius, fRadius/2, false)}
        object {Round_Box     (<-fKnobRadius/5,-(fKnobRadius-fRadius/2),-fKnobRadius>,<fKnobRadius/5, fKnobRadius/2,0>,fRadius/2,false)}
        object {cylinder{<0,0,-fKnobDepth><0,0,-(fKnobDepth+0.001)>,fKnobRadius/6 translate (fKnobRadius/2+fKnobRadius/5+fRadius/2)*y pigment{White}}}
        }
      rotate -60*z
      finish {diffuse 0.9}
      pigment {Black}
      }
 
  #local oControlStatusText =
    object {
      text { ttf "crystal.ttf" "Status" 0.125, <0,0,0>}
      scale 0.2
      pigment{White}
      }
 
  #local oControlDataText =
    object {
      union {
        text { ttf "crystal.ttf" "Data" 0.125, <0,0,0> translate 1.00*y}
        text { ttf "crystal.ttf" "Transfer" 0.125, <0,0,0>}
        }
      scale 0.125
      pigment{White}
      }
 
  #local oControlCheckText =
    object {
      union {
        text { ttf "crystal.ttf" "Check" 0.125, <0,0,0> translate 1.00*y}
        text { ttf "crystal.ttf" "Cond" 0.125, <0,0,0>}
        }
      scale 0.125
      pigment{White}
      }
 
  #local oControlChannelText =
    object {
      text { ttf "crystal.ttf" "Channel Interface" 0.125, <0,0,0>}
      scale 0.175
      pigment{White}
      }
 
  #local oControlOnlineText =
    object {
      text { ttf "crystal.ttf" "Online" 0.125, <0,0,0>}
      scale 0.125
      pigment{White}
      }
 
  #local oControlOfflineText =
    object {
      text { ttf "crystal.ttf" "Offline" 0.125, <0,0,0>}
      scale 0.125
      pigment{White}
      }
 
  #local oControl1Text =
    object {
      text { ttf "crystal.ttf" "1" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControl2Text =
    object {
      text { ttf "crystal.ttf" "2" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControl3Text =
    object {
      text { ttf "crystal.ttf" "3" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControl4Text =
    object {
      text { ttf "crystal.ttf" "4" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControl5Text =
    object {
      text { ttf "crystal.ttf" "5" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControl6Text =
    object {
      text { ttf "crystal.ttf" "6" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControl7Text =
    object {
      text { ttf "crystal.ttf" "7" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControl8Text =
    object {
      text { ttf "crystal.ttf" "8" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControl9Text =
    object {
      text { ttf "crystal.ttf" "9" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControl0Text =
    object {
      text { ttf "crystal.ttf" "0" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControlClearText =
    object {
      text { ttf "crystal.ttf" "Clear" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControlEnterText =
    object {
      text { ttf "crystal.ttf" "Enter" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControlAdvanceText =
    object {
      text { ttf "crystal.ttf" "Advance" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControlAlt2Text =
    object {
      text { ttf "crystal.ttf" "Alt 2" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControlAlt1Text =
    object {
      text { ttf "crystal.ttf" "Alt 1" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
  #local oControlIMLText =
    object {
      text { ttf "crystal.ttf" "IML" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
 
 #local oControlPanelFace =
    object {
      union {
        difference {
          box{< 0 , 0, 0>< fControlPanelWidth, fControlPanelHeight, 1/32> pigment{White*0.05}}
          object { oControlStatusHole translate <fStatusXOffset                ,fStatusYOffset                ,0>}
          object { oControlLEDHole    translate <fButtonXOffset+4*fButtonXSpace,fButtonYOffset+4.5*fButtonYSpace,0>}
          object { oControlLEDHole    translate <fButtonXOffset+6*fButtonXSpace,fButtonYOffset+4.5*fButtonYSpace,0>}
          object { oControlLEDHole    translate <fButtonXOffset+9.5*fButtonXSpace,fButtonYOffset+3.25*fButtonYSpace,0>}
          object { oControlButtonHole translate <fButtonXOffset                ,fButtonYOffset+3*fButtonYSpace,0>}
          object { oControlButtonHole translate <fButtonXOffset+1*fButtonXSpace,fButtonYOffset+3*fButtonYSpace,0>}
          object { oControlButtonHole translate <fButtonXOffset+2*fButtonXSpace,fButtonYOffset+3*fButtonYSpace,0>}
          object { oControlButtonHole translate <fButtonXOffset                ,fButtonYOffset+2*fButtonYSpace,0>}
          object { oControlButtonHole translate <fButtonXOffset+1*fButtonXSpace,fButtonYOffset+2*fButtonYSpace,0>}
          object { oControlButtonHole translate <fButtonXOffset+2*fButtonXSpace,fButtonYOffset+2*fButtonYSpace,0>}
          object { oControlButtonHole translate <fButtonXOffset                ,fButtonYOffset+1*fButtonYSpace,0>}
          object { oControlButtonHole translate <fButtonXOffset+1*fButtonXSpace,fButtonYOffset+1*fButtonYSpace,0>}
          object { oControlButtonHole translate <fButtonXOffset+2*fButtonXSpace,fButtonYOffset+1*fButtonYSpace,0>}
          object { oControlButtonHole translate <fButtonXOffset+1*fButtonXSpace,fButtonYOffset                ,0>}
          object { oControlButtonHole translate <fButtonXOffset+4*fButtonXSpace,fButtonYOffset+2*fButtonYSpace,0>}
          object { oControlButtonHole translate <fButtonXOffset+4*fButtonXSpace,fButtonYOffset                ,0>}
          object { oControlButtonHole translate <fButtonXOffset+6*fButtonXSpace,fButtonYOffset+2*fButtonYSpace,0>}
          object { oControlButtonHole translate <fButtonXOffset+6*fButtonXSpace,fButtonYOffset+1*fButtonYSpace,0>}
          object { oControlButtonHole translate <fButtonXOffset+6*fButtonXSpace,fButtonYOffset                ,0>}
          object { oControlButtonHole translate <fButtonXOffset+8*fButtonXSpace,fButtonYOffset                ,0>}
          }
        object { oControlStatusText  translate <fStatusXOffset, fStatusYOffset+fStatusHeight+0.0625, -0.002>}
        object { oControlStatus      translate <fStatusXOffset                ,fStatusYOffset                ,0> pigment{Red*0.05}}
        object { oControlDataText    translate <fButtonXOffset+4*fButtonXSpace,fButtonYOffset+4.5*fButtonYSpace+fLEDHeight+0.0625,-0.002>}
        object { oControlLED         translate <fButtonXOffset+4*fButtonXSpace,fButtonYOffset+4.5*fButtonYSpace,0> pigment{Green*0.1}}
        object { oControlCheckText   translate <fButtonXOffset+6*fButtonXSpace,fButtonYOffset+4.5*fButtonYSpace+fLEDHeight+0.0625,-0.002>}
        object { oControlLED         translate <fButtonXOffset+6*fButtonXSpace,fButtonYOffset+4.5*fButtonYSpace,0> pigment{Red*0.1}}
        object { oControlChannelText translate <fButtonXOffset+8*fButtonXSpace-fKnobRadius,fButtonYOffset+3.5*fButtonYSpace+fKnobRadius+0.125,-0.002>}
        object { oControlKnob        translate <fButtonXOffset+8*fButtonXSpace,fButtonYOffset+3.5*fButtonYSpace,0>}
        object { oControlOnlineText  translate <fButtonXOffset+8*fButtonXSpace+fKnobRadius+0.125,fButtonYOffset+3.5*fButtonYSpace+0.15,-0.002>}
        object { oControlOfflineText translate <fButtonXOffset+8*fButtonXSpace+fKnobRadius+0.125,fButtonYOffset+3.5*fButtonYSpace-0.15,-0.0021>}
        object { oControlLED         translate <fButtonXOffset+9.5*fButtonXSpace,fButtonYOffset+3.25*fButtonYSpace,0> pigment{Yellow*0.1}}
        object { oControl1Text       translate <fButtonXOffset                ,fButtonYOffset+3.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset                ,fButtonYOffset+3*fButtonYSpace,0>}
        object { oControl2Text       translate <fButtonXOffset+1*fButtonXSpace,fButtonYOffset+3.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset+1*fButtonXSpace,fButtonYOffset+3*fButtonYSpace,0>}
        object { oControl3Text       translate <fButtonXOffset+2*fButtonXSpace,fButtonYOffset+3.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset+2*fButtonXSpace,fButtonYOffset+3*fButtonYSpace,0>}
        object { oControl4Text       translate <fButtonXOffset                ,fButtonYOffset+2.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset                ,fButtonYOffset+2*fButtonYSpace,0>}
        object { oControl5Text       translate <fButtonXOffset+1*fButtonXSpace,fButtonYOffset+2.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset+1*fButtonXSpace,fButtonYOffset+2*fButtonYSpace,0>}
        object { oControl6Text       translate <fButtonXOffset+2*fButtonXSpace,fButtonYOffset+2.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset+2*fButtonXSpace,fButtonYOffset+2*fButtonYSpace,0>}
        object { oControl7Text       translate <fButtonXOffset                ,fButtonYOffset+1.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset                ,fButtonYOffset+1*fButtonYSpace,0>}
        object { oControl8Text       translate <fButtonXOffset+1*fButtonXSpace,fButtonYOffset+1.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset+1*fButtonXSpace,fButtonYOffset+1*fButtonYSpace,0>}
        object { oControl9Text       translate <fButtonXOffset+2*fButtonXSpace,fButtonYOffset+1.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset+2*fButtonXSpace,fButtonYOffset+1*fButtonYSpace,0>}
        object { oControl0Text       translate <fButtonXOffset+1*fButtonXSpace,fButtonYOffset+0.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset+1*fButtonXSpace,fButtonYOffset                ,0>}
        object { oControlClearText   translate <fButtonXOffset+4*fButtonXSpace,fButtonYOffset+2.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset+4*fButtonXSpace,fButtonYOffset+2*fButtonYSpace,0>}
        object { oControlEnterText   translate <fButtonXOffset+4*fButtonXSpace,fButtonYOffset+0.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset+4*fButtonXSpace,fButtonYOffset                ,0>}
        object { oControlAdvanceText translate <fButtonXOffset+6*fButtonXSpace,fButtonYOffset+2.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset+6*fButtonXSpace,fButtonYOffset+2*fButtonYSpace,0>}
        object { oControlAlt2Text    translate <fButtonXOffset+6*fButtonXSpace,fButtonYOffset+1.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset+6*fButtonXSpace,fButtonYOffset+1*fButtonYSpace,0>}
        object { oControlAlt1Text    translate <fButtonXOffset+6*fButtonXSpace,fButtonYOffset+0.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset+6*fButtonXSpace,fButtonYOffset                ,0>}
        object { oControlIMLText     translate <fButtonXOffset+8*fButtonXSpace,fButtonYOffset+0.4*fButtonYSpace,-0.002>}
        object { oControlButton      translate <fButtonXOffset+8*fButtonXSpace,fButtonYOffset                ,0>}
        }
      }
 
  #local oControlPanel =
    object {
      union {
        object { RoundBoxHole(fControlPanelWidth,fControlPanelHeight,fControlPanelDepth,fRadius)}
        box{< 0, 0,-fRadius><fControlPanelWidth,-1.4*fControlPanelDepth,fRadius> rotate -45*x translate < 0,fControlPanelHeight,fRadius>}
        object { oControlPanelFace rotate fControlPanelFaceAngle*x translate fControlPanelFaceZOffset*z }
        }
      }
 
  #local oFloppyPanelHole =
    object {
      box {< 0, 0, -0.10><fFloppyPanelWidth,fFloppyPanelHeight,fFloppyPanelDepth>}
      }
 
  #local oFloppyPanel =
    object {
      union {
        object { RoundBoxHole(fFloppyPanelWidth,fFloppyPanelHeight,fFloppyPanelDepth,fRadius) }
        box{< 0, 0,-fRadius><fFloppyPanelWidth,-fFloppyPanelZOffset/0.70,fRadius> rotate -45*x translate < 0,fFloppyPanelHeight,fRadius> }
        object {
          union {
            object { Round_Box(<0,0,0>,<fFloppyPanelFiller,fFloppyDriveHeight,2*fRadius>,fRadius,false)}
            object { FloppyDrive() translate <fFloppyPanelFiller,0,0> }
            object {
              union {
                object { text { ttf "crystal.ttf" "1" 0.125, <0,0,0>} scale 0.250 translate <0.1000,fFloppyDriveHeight/2,-0.01> pigment{White}}
                object { Round_Box(<0,0,0>,<fFloppyPanelDivider,fFloppyDriveHeight,2*fRadius>,fRadius,false) }
                object { text { ttf "crystal.ttf" "2" 0.125, <0,0,0>} scale 0.250 translate <0.8500,fFloppyDriveHeight/2,-0.01> pigment{White} }
                }
              translate <(fFloppyPanelFiller+fFloppyDriveWidth),0,0>
              }
            object { FloppyDrive() translate <fFloppyPanelFiller+fFloppyDriveWidth+fFloppyPanelDivider,0,0>}
            object { Round_Box(<0,0,0>,<fFloppyPanelFiller,fFloppyDriveHeight,2*fRadius>,fRadius,false) translate <fFloppyPanelFiller+2*fFloppyDriveWidth+fFloppyPanelDivider,0,0> }
            }
           translate fFloppyPanelZOffset*z
           pigment{White*0.10}
          }
        }
      }
 
  #local oDrivePanelHole =
    object {
      box {< 0, 0, -0.10><fDrivePanelWidth,fDrivePanelHeight,fFrontDepth+0.01>}
      }
 
  #local oDrivePanel =
    object {
      union {
        object { RoundBoxHole(fDrivePanelWidth,fDrivePanelHeight,fDrivePanelDepth,fRadius) }
        box{< 0, 0,-fRadius><fDrivePanelWidth,-0.7*fDrivePanelZOffset,fRadius> rotate -45*x translate < 0,fDrivePanelHeight,fRadius> }
        }
      }
 
  #local oLogoPanelHole =
    object {
      box {< -0.02, -0.02, -0.10><fLogoPanelWidth+0.02,fLogoPanelHeight+0.02,fLogoPanelDepth>}
      }
 
  #local oLogoModelText =
    object {
      text { ttf "crystal.ttf" "3174  11R" 0.125, <0,0,0> }
      scale 0.0750
      pigment{Black}
      }
      
  #local oLogoPanel =
    object {
      union {
        box {< 0, 0, 0><fLogoPanelWidth,fLogoPanelHeight,fLogoPanelDepth>} 
        object {IBMLogo(0.9*fLogoPanelWidth,0.4*fLogoPanelHeight,fLogoPanelDepth) pigment{Black} translate <0.05*fLogoPanelWidth,0.5*fLogoPanelHeight,+0.062>}
        object {oLogoModelText translate < 0.0625, 0.03125, -0.001>}
        }
      texture{T_Silver_1C}
//      pigment{Green}
      }
 
  #local oSwitchPanelHole =
    object {
      box {< 0, 0, -0.10><fSwitchPanelWidth,fSwitchPanelHeight,fFrontDepth+0.1>}
      }
 
  #local oSwitchToggleHole =
    object {
      box {< 0, 0, -0.10><fSwitchToggleWidth,fSwitchToggleHeight,fSwitchPanelDepth>}
      }
 
  #local oSwitchToggle =
    object {
      union {
        box{<0,0,-0.1><fSwitchToggleWidth,1/16,fSwitchToggleDepth>}
        box{<0,0,-0.1><fSwitchToggleWidth,1/16,fSwitchToggleDepth> translate (fSwitchToggleHeight-1/16)*y}
        box{<0,0,-0.1><1/16,fSwitchToggleHeight,fSwitchToggleDepth>}
        box{<0,0,-0.1><1/16,fSwitchToggleHeight,fSwitchToggleDepth> translate (fSwitchToggleWidth-1/16)*x}
        box{<0,0,0><fSwitchToggleWidth,-fSwitchToggleSlope,1/16> rotate -fSwitchToggleAngle*x translate <0,(fSwitchToggleHeight-1/16),-0.1>}
        box{<0,0,0><fSwitchToggleWidth, fSwitchToggleSlope,0> rotate  fSwitchToggleAngle*x translate <0,1/16,-0.1>}
 
        box{<3/32,fSwitchToggleHeight/2-1/16,-0.5><fSwitchToggleWidth-3/32,fSwitchToggleHeight/2+1/16,fSwitchToggleDepth>}
        cylinder{<3/32,fSwitchToggleHeight/2,2*fSwitchToggleRadius><fSwitchToggleWidth-3/32,fSwitchToggleHeight/2,2*fSwitchToggleRadius>,fSwitchToggleRadius}
        }
      pigment{White}
      }
 
  #local oSwitchPowerText =
    object {
      text { ttf "crystal.ttf" "Power" 0.125, <0,0,0> }
      scale 0.250
      pigment{White}
      }
 
  #local oSwitchStartText =
    object {
      text { ttf "crystal.ttf" "Start" 0.125, <0,0,0> }
      scale 0.250
      pigment{White}
      }
 
  #local oSwitchIText =
    object {
      text { ttf "crystal.ttf" "I" 0.125, <0,0,0> }
      scale 0.250
      pigment{White}
      }
 
  #local oSwitchOText =
    object {
      text { ttf "crystal.ttf" "O" 0.125, <0,0,0> }
      scale 0.250
      pigment{White}
      }
 
  #local oSwitchControlText =
    object {
      text { ttf "crystal.ttf" "Power Control" 0.125, <0,0,0> }
      scale 0.250
      pigment{White}
      }
 
  #local oSwitchLocalText =
    object {
      text { ttf "crystal.ttf" "Local" 0.125, <0,0,0> }
      scale 0.250
      pigment{White}
      }
 
  #local oSwitchRemoteText =
    object {
      text { ttf "crystal.ttf" "Remote" 0.125, <0,0,0> }
      scale 0.250
      pigment{White}
      }
 
  #local oSwitchPanelFace =
    object {
      union {
        object {
          difference {
            box{<0,0,0><fSwitchPanelWidth,fSwitchPanelHeight,0.01>}
            union {
              object {oControlLEDHole translate <fSwitchLEDXOffset-0.01,fSwitchLEDYOffset-0.01,0>}
              object {oSwitchToggleHole translate <fSwitchToggleXOffset-0.01,fSwitchToggleYOffset-0.01,0>}
              }
            }
          }
        object{oSwitchPowerText translate <fSwitchToggleXOffset+fSwitchToggleWidth+0.125,fSwitchToggleYOffset+fSwitchToggleHeight,-0.01>}
        object{oSwitchStartText translate <fSwitchToggleXOffset+fSwitchToggleWidth+0.250,fSwitchToggleYOffset+fSwitchToggleHeight-0.375,-0.01>}
        object{oSwitchIText translate <fSwitchToggleXOffset+fSwitchToggleWidth+0.250,fSwitchToggleYOffset+0.500,-0.01>}
        object{oSwitchOText translate <fSwitchToggleXOffset+fSwitchToggleWidth+0.250,fSwitchToggleYOffset+0.125,-0.01>}
        object{oSwitchControlText translate <fSwitchKnobXOffset+fKnobRadius,fSwitchKnobYOffset+fKnobRadius,-0.01>}
        object{oSwitchLocalText translate <fSwitchKnobXOffset+fKnobRadius+0.125,fSwitchKnobYOffset+fKnobRadius-0.250,-0.01>}
        object{oSwitchRemoteText translate <fSwitchKnobXOffset+fKnobRadius+0.125,fSwitchKnobYOffset-0.125,-0.01>}
        object{oSwitchToggle translate <fSwitchToggleXOffset,fSwitchToggleYOffset,0>}
        object{oControlKnob translate <fSwitchKnobXOffset,fSwitchKnobYOffset,0>}
        object{oControlLED  translate <fSwitchLEDXOffset,fSwitchLEDYOffset,-fLEDDepth/2> texture {pigment{Green} finish{ambient Green}}}
        }
      pigment{White*0.05}
      }
 
  #local oSwitchPanel =
    object {
      union {
        difference {
          object { RoundBoxHole(fSwitchPanelWidth,fSwitchPanelHeight,fSwitchPanelDepth+0.010,fRadius) }
          object {oSwitchToggleHole translate <fSwitchToggleXOffset-0.01,fSwitchToggleYOffset-0.01,fSwitchPanelDepth-0.1>}
          }
        box{< 0, 0,-fRadius><fSwitchPanelWidth,-1.4*fSwitchPanelDepth,fRadius> rotate -45*x translate < 0,fSwitchPanelHeight,fRadius> }
        object {oSwitchPanelFace translate (fSwitchPanelDepth-0.001)*z}
        }
      }
 
  #local oAddressPanelHole =
    object {
      box {< 0, 0, -0.10><fAddressPanelWidth,fAddressPanelHeight,fAddressPanelDepth>}
      }
      
  #local oAddressPanel =
    object {
      union {
        box {<-fAddressPanelBar/2,0,0><fAddressPanelBar/2,fAddressPanelHeight/3,fAddressPanelDepth> translate <(fAddressPanelWidth*0.25),fAddressPanelHeight*2/3,0>}
        box {<-fAddressPanelBar/2,0,0><fAddressPanelBar/2,fAddressPanelHeight/3,fAddressPanelDepth> translate <(fAddressPanelWidth*0.50),fAddressPanelHeight*2/3,0>}
        box {<-fAddressPanelBar/2,0,0><fAddressPanelBar/2,fAddressPanelHeight/3,fAddressPanelDepth> translate <(fAddressPanelWidth*0.75),fAddressPanelHeight*2/3,0>}
        box {< 0,-fAddressPanelBar/2,0><fAddressPanelWidth,fAddressPanelBar/2,fAddressPanelDepth> translate <0,fAddressPanelHeight*1/3,0>}
        box {< 0,-fAddressPanelBar/2,0><fAddressPanelWidth,fAddressPanelBar/2,fAddressPanelDepth> translate <0,fAddressPanelHeight*2/3,0>}
        }
      }
 
  #local oVentPanelHole =
    object {
      box {< 0, 0, -0.10><fVentPanelWidth,fVentPanelHeight,fVentPanelDepth>}
      }
 
  #local oVentSlat =
    object {
      union {
        box{<0,0,-fVentSlatDepth/2>< fVentPanelWidth,-fVentSlatHeight, fVentSlatDepth/2>}
        cylinder{< 0, 0, 0>< fVentPanelWidth, 0, 0>,fVentSlatDepth/2}
        box{<0,0,-fVentSlatDepth/2>< fVentPanelWidth, fVentSlatHeight, fVentSlatDepth/2> rotate 45*x}
        }
      translate fVentSlatHeight*y
      }
 
  #local oVent =
    object {
      union {
        #local n = 0;
        #while(n < nVentSlats)
          object {oVentSlat translate n*2*fVentSlatHeight*y}
          #local n = n + 1;
        #end
        }
      }
 
  #local oFront =
    object {
      union {
        difference {
          Round_Box(< 0, 0, 0>,<fFrontWidth,fFrontHeight,fFrontDepth>,fRadius,false)
          union {
            object {oControlPanelHole translate <fControlPanelXOffset,fControlPanelYOffset,0>}
            object {oFloppyPanelHole  translate <fFloppyPanelXOffset,fFloppyPanelYOffset,0>}
            object {oDrivePanelHole   translate <fDrivePanelXOffset,fDrivePanelYOffset,0>}
            object {oLogoPanelHole    translate <fLogoPanelXOffset,fLogoPanelYOffset,0>}
            object {oSwitchPanelHole  translate <fSwitchPanelXOffset,fSwitchPanelYOffset,0>}
            object {oAddressPanelHole translate <fAddressPanelXOffset,fAddressPanelYOffset,0>}
            object {oVentPanelHole    translate <fVentPanelXOffset,fVentPanelYOffset,0>}
            }
          }
        object { oControlPanel translate < fControlPanelXOffset, fControlPanelYOffset, 0>}
        object { oFloppyPanel  translate < fFloppyPanelXOffset, fFloppyPanelYOffset, 0>}
        object { oDrivePanel   translate < fDrivePanelXOffset, fDrivePanelYOffset, 0>}
        object { oLogoPanel    translate < fLogoPanelXOffset, fLogoPanelYOffset, 0>}
        object { oSwitchPanel  translate < fSwitchPanelXOffset, fSwitchPanelYOffset, 0>}
        object { oAddressPanel translate <fAddressPanelXOffset,fAddressPanelYOffset,0>}
        object { oVent translate <fVentPanelXOffset, fVentPanelYOffset, fVentSlatDepth/2>}
//            object {oAddressPanelHole translate <fAddressPanelXOffset,fAddressPanelYOffset,0> pigment{Red}}
        }
      }
 
  #local oMiddle =
    object {
      difference {
        object {Round_Box(< 0, 0, 0>,<fWidth,fHeight,fSideWidth>,fRadius,false)}
        box{<1,1,-0.1><fWidth-1,fHeight-1,fSideWidth+0.01>}
        }
      translate (fFrontDepth+0.5)*z
      }
 
  #local oRear =
    object {
      Round_Box(< 0, 0, 0>,<fWidth,fHeight,fRearDepth>,fRadius,false)
      translate (fDepth-fRearDepth)*z
      }
 
  #local oBase =
    object {
      box{< fSideDepth,-fBaseHeight,fFrontDepth><fWidth-fSideDepth,                 0,fDepth-fRearDepth>}
      pigment{Black}
      }
      
  #local oLegs =
    object {
      union {
        cylinder{<0,0,0><0,fLegHeight,0>,fLegRadius translate <2*fLegRadius,0,2*fLegRadius>}
        cylinder{<0,0,0><0,fLegHeight,0>,fLegRadius translate <fWidth-2*fLegRadius,0,2*fLegRadius>}
        cylinder{<0,0,0><0,fLegHeight,0>,fLegRadius translate <2*fLegRadius,0,fDepth-2*fLegRadius>}
        cylinder{<0,0,0><0,fLegHeight,0>,fLegRadius translate <fWidth-2*fLegRadius,0,fDepth-2*fLegRadius>}
        }
      pigment{Black}
      }
 
  #local oIBM3174 =                                                     //*                                     */
    object {
      union {
        object {
          union {
            object {oFront}
            object {oMiddle}
            object {oRear}
            }
          translate fLegHeight*y
          }
        object {oLegs}
//        object {oBase}
        }
      texture{t3174Texture}
      scale 1/12
    }
  oIBM3174
#end
