#include "BarCode.inc" 

#declare f3490Width  = 4.25;
#declare f3490Height = 1.0;
#declare f3490Depth  = 4.875;

#macro IBM3494TypeLabel()
  #local fWidth   = 0.65;
  #local fHeight  = 0.40;
  #local fDepth   = 0.005;
  #local fRadius  = 0.05;
  
  #local oBottomLine =
    object {
      box{<0,0,0><fWidth,0.025,0.0001>}
      pigment{Black}
      }
  
  #local oSideLine =
    object {
      box{<0,0,0><0.025,0.275,0.0001>}
      pigment{Black}
      }

  #local oTypeJ =
    object {
      text { ttf "arial.ttf" "J" 0.125, <0,0,0>}
      scale <0.375,0.375,0.1>
      rotate -90*z
      translate <0.10,0.20,0.00>
      pigment{Black}
      }

  
  #local oBaseLabel =
    object {
      union {
        box{<fRadius,0,0><fWidth-fRadius,fHeight,fDepth>}
        box{<0,fRadius,0><fWidth,fHeight-fRadius,fDepth>}
        cylinder{<fRadius,fRadius,0><fRadius,fRadius,fDepth>,fRadius}
        cylinder{<fWidth-fRadius,fRadius,0><fWidth-fRadius,fRadius,fDepth>,fRadius}
        cylinder{<fRadius,fHeight-fRadius,0><fRadius,fHeight-fRadius,fDepth>,fRadius}
        cylinder{<fWidth-fRadius,fHeight-fRadius,0><fWidth-fRadius,fHeight-fRadius,fDepth>,fRadius}
        }
      pigment{White*0.9}
      }
  
  #local oLabel =
    object {
      union {
        object {oBaseLabel}
        object {oBottomLine translate < 0.0, 0.125,-0.0001>}
        object {oSideLine   translate < 0.125, 0.125,-0.0001>}
        object {oSideLine   translate < 0.65-0.125, 0.125,-0.0001>}
        object {oTypeJ      translate < 0.125, 0.125,-0.0001>}
        object {BarCode("J") scale <0.4,0.15,0.0001> translate < 0.10, 0.00, -0.0001>}
        }
      translate -fDepth*z
      }
      
  oLabel
#end

#macro IBM3494VolumeLabel(sSerial)
  #local fWidth   = 3.15;
  #local fHeight  = 0.40;
  #local fDepth   = 0.005;
  #local fRadius  = 0.05;
  
  #local aoNumbers = array[10];
  #local n = 0;
  #while (n < 10)
    #local aoNumbers[n] =
      object {
        text { ttf "arial.ttf" str(n,1,0) 0.125, <0,0,0>}
        scale <0.375,0.375,0.1>
        rotate -90*z
        translate <0.10,0.20,0.00>
        pigment{Black}
        }
    #local n = n + 1;
  #end
  
  #local avColors = array[10];
  #local avColors[0] = pigment{Red};
  #local avColors[1] = pigment{Yellow};
  #local avColors[2] = pigment{Green};
  #local avColors[3] = pigment{Blue};
  #local avColors[4] = pigment{Magenta};
  #local avColors[5] = pigment{Cyan};
  #local avColors[6] = pigment{Orange};
  #local avColors[7] = pigment{Violet};
  #local avColors[8] = pigment{Brown};
  #local avColors[9] = pigment{Pink};
      
  #local oBottomLine =
    object {
      box{<0,0,0><fWidth,0.025,0.0001>}
      pigment{Black}
      }
  
  #local oBaseLabel =
    object {
      union {
        box{<fRadius,0,0><fWidth-fRadius,fHeight,fDepth>}
        box{<0,fRadius,0><fWidth,fHeight-fRadius,fDepth>}
        cylinder{<fRadius,fRadius,0><fRadius,fRadius,fDepth>,fRadius}
        cylinder{<fWidth-fRadius,fRadius,0><fWidth-fRadius,fRadius,fDepth>,fRadius}
        cylinder{<fRadius,fHeight-fRadius,0><fRadius,fHeight-fRadius,fDepth>,fRadius}
        cylinder{<fWidth-fRadius,fHeight-fRadius,0><fWidth-fRadius,fHeight-fRadius,fDepth>,fRadius}
        }
      pigment{White*0.9}
      }
      
  #local oSideLine =
    object {
      box{<0,0,0><0.025,0.275,0.0001>}
      pigment{Black}
      }

  #local oLabel =
    object {
      union {
        object {oBaseLabel}
        object {oBottomLine translate < 0.0, 0.125,-0.0001>}
        #local i = 0;
        #while (i < 6)
          object {oSideLine   translate < 0.075+i*0.5, 0.125,-0.0001>}
          #local n = asc(substr(sSerial,i+1,1))-asc("0");
          object {box{<0,0,0><0.5,0.275,0.0001> translate < 0.075+(5-i)*0.5, 0.125, -0.00005> texture{avColors[n]}}}
          object {aoNumbers[n] translate < 0.075+(5-i)*0.5, 0.15, -0.0001>}
          object {BarCode(substr(sSerial,i+1,1)) scale <0.4,0.15,0.0001> translate < 0.075+(5-i)*0.5+0.10, 0.00, -0.0001>}
          #local i = i + 1;
        #end
        object {oSideLine   translate < 3.15-0.075, 0.125,-0.0001>}
//        object {oTypeJ      translate < 0.125, 0.125,-0.0001>}
        }
      translate -fDepth*z
      }
      
  oLabel
#end

#macro IBM3490Cart(sSerial)     
  #local fCartWidth  = 4.25;
  #local fCartHeight = 1.0;
  #local fCartDepth  = 4.875;
  #local fCartRadius = 0.0625;
  #local fDZ         = 0.75;
  #local fDY         = 0.25;
  #local fAngle      = atan(fDY/fDZ);
  #local fAngleLen   = fDY/sin(fAngle)+2*fCartRadius;
  
  #local oCart =
    object {
      union {
        object {
          Round_Box(<0,fDY,0>,<fCartWidth,fCartHeight,fDZ+2*fCartRadius>,fCartRadius,false)
          pigment{White*0.1}
          }
        object {
          Round_Box(< 0.00, 0.00, fDZ>,<fCartWidth,fCartHeight,fCartDepth>,fCartRadius,false)
          pigment{White*0.1}
          }
        object {
          Round_Box(<0,0.00,0>,<fCartWidth,fCartHeight-0.5,fAngleLen>,fCartRadius,false)
          translate <0,-fCartRadius,-fCartRadius>
          rotate degrees(fAngle)*x
          translate <0, fCartRadius+fDY, fCartRadius>
          pigment{White*0.1}
          }
        object {
          IBM3494TypeLabel()
          translate <0.15,0.45,0>
          }
        object {
          IBM3494VolumeLabel(sSerial)
          translate <0.95,0.45,0>
          }
        }
      }
      
  oCart
#end  