#include "Vent.inc"
#include "BlueButton.inc"

#macro IBM3494Lock()
  #local oLock =
    object {
      union {
        difference {
          cone{<0,0,0>,fIBM3494LockBaseRadius,<0,0,fIBM3494LockDepth>,fIBM3494LockCapRadius}
          cylinder{<0,0,0><0,0,fIBM3494LockDepth+0.1>,fIBM3494LockCapRadius/2}
          }        
        object{
          Round_Box(<-1,-1,0>,<1,1,1>,0.2,false)
          scale <0.625*fIBM3494LockCapRadius/2,0.625*fIBM3494LockCapRadius/2,fIBM3494LockDepth>
          rotate 15*z
          }
        }
      }
  oLock
#end 

//***************************************************************************************************************/
//* IBM 3494 End Cover Definitions                                                                              */
//*      iType    :   0 -  Solid End Cover for Back Frame                                                       */
//*                   1 -  Left End Cover for Front Frame with Window                                           */
//*                   2 -  Right End Cover for Front Frame with Window                                          */ 
//***************************************************************************************************************/
#macro IBM3494EndCover(iType)
  #switch (iType)
  
    #case (0)                            //* Left/Right Solid Endcover for Back Frames
      #local oEndCover =
        object {
          Round_Box(<0,0,0>,<fIBM3494EndWidth,fIBM3494Height,fIBM3494Depth2>,fIBM3494Radius,false)
          texture{fIBM3494Texture2}     
          }
    #break
     
    #case (1)                            //* Left Endcover with Window for Front Frames
      #local oEndCover =
        object {
          union {
            difference {                 //* Create Hole for Window
              Round_Box(<0,0,0>,<fIBM3494EndWidth,fIBM3494Height,fIBM3494Depth1>,fIBM3494Radius,false)
              box{
                <-0.1,-fIBM3494Radius,-fIBM3494Radius>
                <fIBM3494EndWidth+0.1,fIBM3494WindowHeight+fIBM3494Radius,fIBM3494WindowDepth+fIBM3494Radius> 
                translate <0,fIBM3494WindowYOffset,fIBM3494WindowZOffset>
                }
              }      
            object {        
              union {
                cylinder{<0,-fIBM3494Radius,-fIBM3494Radius><0,fIBM3494WindowHeight+fIBM3494Radius,-fIBM3494Radius>,fIBM3494Radius}
                cylinder{<0,-fIBM3494Radius,fIBM3494WindowDepth+fIBM3494Radius><0,fIBM3494WindowHeight+fIBM3494Radius,fIBM3494WindowDepth+fIBM3494Radius>,fIBM3494Radius}
                cylinder{<0,-fIBM3494Radius,-fIBM3494Radius><0,-fIBM3494Radius,fIBM3494WindowDepth+fIBM3494Radius>,fIBM3494Radius}
                cylinder{<0,fIBM3494WindowHeight+fIBM3494Radius,-fIBM3494Radius><0,fIBM3494WindowHeight+fIBM3494Radius,fIBM3494WindowDepth+fIBM3494Radius>,fIBM3494Radius}
                }
              translate <fIBM3494Radius,fIBM3494WindowYOffset,fIBM3494WindowZOffset>
              }  
            box{                         //* Add Window Glass
              <0,-fIBM3494Radius,-fIBM3494Radius>
              <fIBM3494WindowWidth,fIBM3494WindowHeight+fIBM3494Radius,fIBM3494WindowDepth+fIBM3494Radius> 
              translate <fIBM3494WindowXOffset,fIBM3494WindowYOffset,fIBM3494WindowZOffset>
              texture {T_Glass1}
              }
            }
          texture{fIBM3494Texture1}     
          }
    #break
    
    #case (2)                            //* Left Endcover with Window for Front Frames
      #local oEndCover =
        object {
          union {
            difference {                 //* Create Hole for Window
              Round_Box(<0,0,0>,<fIBM3494EndWidth,fIBM3494Height,fIBM3494Depth1>,fIBM3494Radius,false)
              box{
                <-0.1,-fIBM3494Radius,-fIBM3494Radius>
                <fIBM3494EndWidth+0.1,fIBM3494WindowHeight+fIBM3494Radius,fIBM3494WindowDepth+fIBM3494Radius> 
                translate <0,fIBM3494WindowYOffset,fIBM3494WindowZOffset>
                }
              }      
            object {        
              union {
                cylinder{<0,-fIBM3494Radius,-fIBM3494Radius><0,fIBM3494WindowHeight+fIBM3494Radius,-fIBM3494Radius>,fIBM3494Radius}
                cylinder{<0,-fIBM3494Radius,fIBM3494WindowDepth+fIBM3494Radius><0,fIBM3494WindowHeight+fIBM3494Radius,fIBM3494WindowDepth+fIBM3494Radius>,fIBM3494Radius}
                cylinder{<0,-fIBM3494Radius,-fIBM3494Radius><0,-fIBM3494Radius,fIBM3494WindowDepth+fIBM3494Radius>,fIBM3494Radius}
                cylinder{<0,fIBM3494WindowHeight+fIBM3494Radius,-fIBM3494Radius><0,fIBM3494WindowHeight+fIBM3494Radius,fIBM3494WindowDepth+fIBM3494Radius>,fIBM3494Radius}
                }
              translate <fIBM3494EndWidth-fIBM3494Radius,fIBM3494WindowYOffset,fIBM3494WindowZOffset>
              }  
            box{                         //* Add Window Glass
              <0,-fIBM3494Radius,-fIBM3494Radius>
              <fIBM3494WindowWidth,fIBM3494WindowHeight+fIBM3494Radius,fIBM3494WindowDepth+fIBM3494Radius> 
              translate <fIBM3494EndWidth-fIBM3494WindowWidth-fIBM3494WindowXOffset,fIBM3494WindowYOffset,fIBM3494WindowZOffset>
              texture {T_Glass1}
              }
            }
          texture{fIBM3494Texture1}     
          }
    #break
  #end  
    
  oEndCover
#end

//***************************************************************************************************************/
//* IBM 3494 Door Definitions                                                                                   */
//***************************************************************************************************************/
#macro IBM3494Door(iDoorType)
  //*************************************************************************************************************/
  //* Define Front Logo                                                                                         */
  //*************************************************************************************************************/
  #local oLogoHole =
    object {
      union {
        cylinder{<0,0,-0.1><0,0,fLogoDepth>,fLogoHeight*0.5+0.02           translate <fLogoHeight*0.5,fLogoHeight*0.5,0>}
        box     {<-0.02,-0.02,-0.1><fLogoWidth-fLogoHeight+0.02,fLogoHeight+0.02,fLogoDepth> translate <fLogoHeight*0.5, 0, 0>            }
        cylinder{<0,0,-0.1><0,0,fLogoDepth>,fLogoHeight*0.5+0.02           translate <fLogoWidth-fLogoHeight*0.5,fLogoHeight*0.5,0>}
        }
      }
  #local o3494Text =    
    object {
      text { ttf "ariblk.ttf" "3494" 0.125, <0,0,0>}
      scale 0.325
      pigment{White}
      }
      
  #local oLogo =
    object {
      union {
        cylinder{<0,0,0><0,0,fLogoDepth>,fLogoHeight*0.5                translate <fLogoHeight*0.5,fLogoHeight*0.5,0>}
        box     {<0,0,0><fLogoWidth-fLogoHeight,fLogoHeight,fLogoDepth> translate <fLogoHeight*0.5, 0, 0>            }
        cylinder{<0,0,0><0,0,fLogoDepth>,fLogoHeight*0.5                translate <fLogoWidth-fLogoHeight*0.5,fLogoHeight*0.5,0>}
        object  { IBMLogo(fIBMWidth,fIBMHeight,fIBMDepth) rotate fIBMAngle*z translate <fIBMXOffset,fIBMYOffset,-fIBMDepth> pigment{White}}
        object  { o3494Text rotate fIBMAngle*z translate <f3494XOffset,f3494YOffset,-fIBMDepth>}
        }
//      translate -0.001*z  
      pigment{SkyBlue}
      }
      
  #local oDoorHandle =
    object {
      union {
        cylinder{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius><fIBM3494HandleWidth+fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius>,fIBM3494Radius}
        cylinder{<-fIBM3494Radius,fIBM3494HandleHeight+fIBM3494Radius,fIBM3494Radius><fIBM3494HandleWidth+fIBM3494Radius,fIBM3494HandleHeight+fIBM3494Radius,fIBM3494Radius>,fIBM3494Radius}
        cylinder{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius><-fIBM3494Radius,fIBM3494HandleHeight+fIBM3494Radius,fIBM3494Radius>,fIBM3494Radius}
        cylinder{<fIBM3494HandleWidth+fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius><fIBM3494HandleWidth+fIBM3494Radius,fIBM3494HandleHeight+fIBM3494Radius,fIBM3494Radius>,fIBM3494Radius}
        cylinder{<0,0,0><0,fIBM3494HandleHeight,0>,fIBM3494HandleWidth/2 clipped_by{plane{-z,0}} translate <fIBM3494HandleWidth/2,0,fIBM3494Radius>}
        cylinder{<0,0,0><0,fIBM3494HandleHeight,0>,fIBM3494HandleRadius translate <fIBM3494HandleWidth/2,0,2*fIBM3494HandleRadius> texture{fIBM3494Texture3}} 
        }
      } 
      
  #local oBasicFrontDoorTemplate =
    object {
      union {
        object {
          Round_Cylinder(<0,0,0>,<0,fIBM3494Hinge1Height,0>,fIBM3494DoorDepth/2,fIBM3494Radius,false)
          translate <fIBM3494DoorDepth/2,fIBM3494Hinge1YOffset,fIBM3494DoorDepth/2>
          }
        object {
          Round_Box(<fIBM3494DoorDepth/2-fIBM3494Radius,0,0><fIBM3494DoorDepth+2*fIBM3494Radius,fIBM3494Hinge1Height,fIBM3494DoorDepth>,fIBM3494Radius,false)
          translate <0,fIBM3494Hinge1YOffset,0>
          }
        object {
          Round_Cylinder(<0,fIBM3494Radius,0>,<0,-fIBM3494HingeHeight,0>,fIBM3494HingeRadius,fIBM3494Radius,false)
          translate <fIBM3494DoorDepth/2,fIBM3494Hinge1YOffset+0.5,fIBM3494DoorDepth/2>
          texture { fIBM3494Texture3 }
          }
        object {
          Round_Cylinder(<0,0,0>,<0,fIBM3494Hinge2Height,0>,fIBM3494DoorDepth/2,fIBM3494Radius,false)
          translate <fIBM3494DoorDepth/2,fIBM3494Hinge2YOffset,fIBM3494DoorDepth/2>
          }
        object {
          Round_Box(<fIBM3494DoorDepth/2-fIBM3494Radius,0,0><fIBM3494DoorDepth+2*fIBM3494Radius,fIBM3494Hinge2Height,fIBM3494DoorDepth>,fIBM3494Radius,false)
          translate <0,fIBM3494Hinge2YOffset,0>
          }
        object {
          Round_Cylinder(<0,fIBM3494Radius,0>,<0,-fIBM3494HingeHeight,0>,fIBM3494HingeRadius,fIBM3494Radius,false)
          translate <fIBM3494DoorDepth/2,fIBM3494Hinge2YOffset,fIBM3494DoorDepth/2>
          texture { fIBM3494Texture3 }
          }
        object {
          Round_Box(<fIBM3494DoorDepth,0,0><fIBM3494DoorWidth,fIBM3494Height,fIBM3494DoorDepth>,fIBM3494Radius,false)
          }
        }
      }
      
  #local oBasicFrontDoor =
    object {
      union {
        difference {
          object { oBasicFrontDoorTemplate }
          box{
            <0,0,-0.1><fIBM3494DoorVent4Width,fIBM3494DoorVent4Height,fIBM3494DoorDepth+0.1>
            translate <fIBM3494DoorVent4XOffset,fIBM3494DoorVent4YOffset,0>
            }
          box{
            <-fIBM3494Radius,-fIBM3494Radius,-0.1><fIBM3494HandleWidth+fIBM3494Radius,fIBM3494HandleHeight+fIBM3494Radius,fIBM3494DoorDepth+0.1>
            translate <fIBM3494HandleXOffset,fIBM3494HandleYOffset,0>
            }
          object {oLogoHole translate<fLogoXOffset,fLogoYOffset,0>}
          }
        object {
          Vent(fIBM3494DoorVent4Width,fIBM3494DoorVent4Height,fIBM3494Radius,fIBM3494DoorVent4nSlat)
          translate <fIBM3494DoorVent4XOffset,fIBM3494DoorVent4YOffset,0> 
          }
        object {
          oDoorHandle
          translate <fIBM3494HandleXOffset,fIBM3494HandleYOffset,0>
          }
        object {oLogo translate<fLogoXOffset,fLogoYOffset,0>}
        object {
          IBM3494Lock()
          rotate 180*y
          translate < fIBM3494LockXOffset+1, fIBM3494LockYOffset+4, 0>
          texture {fIBM3494Texture1}
          }
        }
      }
      
  #local oBasicBackDoorTemplate =
    object {
      union {
        object {
          Round_Cylinder(<0,0,0>,<0,fIBM3494Height,0>,fIBM3494DoorDepth/2,fIBM3494Radius,false)
          translate <fIBM3494DoorDepth/2,0,fIBM3494DoorDepth/2>
          }
        object {
          Round_Box(<-fIBM3494Radius,0,0>,<fIBM3494DoorWidth-fIBM3494DoorDepth/2,fIBM3494Height,fIBM3494DoorDepth>,fIBM3494Radius,false)
          translate <fIBM3494DoorDepth/2,0,0>
          }
        }
      }
      
  #local oBasicBackDoor = 
    object {
      union {                             
        difference {
          object { oBasicBackDoorTemplate }
          union {
            box{
              <0,0,-0.1><fIBM3494DoorVent2Width,fIBM3494DoorVent2Height,fIBM3494DoorDepth+0.1>
              translate <fIBM3494DoorVent2XOffset,fIBM3494DoorVent2YOffset,0>
              }
            box{
              <0,0,-0.1><fIBM3494DoorVent3Width,fIBM3494DoorVent3Height,fIBM3494DoorDepth+0.1>
              translate <fIBM3494DoorVent3XOffset,fIBM3494DoorVent3YOffset,0>
              }
            }
          }    
        object {
          Vent(fIBM3494DoorVent2Width,fIBM3494DoorVent2Height,fIBM3494Radius,fIBM3494DoorVent2nSlat)
          rotate 180*y
          translate <fIBM3494DoorVent2Width,0,fIBM3494DoorDepth>
          translate <fIBM3494DoorVent2XOffset,fIBM3494DoorVent2YOffset,0> 
          }
        object {
          Vent(fIBM3494DoorVent3Width,fIBM3494DoorVent3Height,fIBM3494Radius,fIBM3494DoorVent3nSlat)
          rotate 180*y
          translate <fIBM3494DoorVent3Width,0,fIBM3494DoorDepth>
          translate <fIBM3494DoorVent3XOffset,fIBM3494DoorVent3YOffset,0> 
          }
        object {
          IBM3494Lock()
          translate < fIBM3494LockXOffset, fIBM3494LockYOffset, fIBM3494DoorDepth>
          texture {fIBM3494Texture1}
          }
        }
      }
      
  #local oConvenienceHole =
    object {
      box{<-fIBM3494Radius,-fIBM3494Radius,-0.1><fIBM3494ConvenienceWidth+fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494DoorDepth+0.1>}
      }
      
  #local oConvenienceFrame =
    object {
      union {
        cylinder{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius><fIBM3494ConvenienceWidth+fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius>,fIBM3494Radius}
        cylinder{<-fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494Radius><fIBM3494ConvenienceWidth+fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494Radius>,fIBM3494Radius}
        cylinder{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius><-fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494Radius>,fIBM3494Radius}
        cylinder{<fIBM3494ConvenienceWidth+fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius><fIBM3494ConvenienceWidth+fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494Radius>,fIBM3494Radius}
        box{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius><fIBM3494ConvenienceWidth+fIBM3494Radius,0,fIBM3494ConvenienceDepth-fIBM3494Radius>}
        box{<-fIBM3494Radius,fIBM3494ConvenienceHeight,fIBM3494Radius><fIBM3494ConvenienceWidth+fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494ConvenienceDepth-fIBM3494Radius>}
        box{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius><0,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494ConvenienceDepth-fIBM3494Radius>}
        box{<fIBM3494ConvenienceWidth,-fIBM3494Radius,fIBM3494Radius><fIBM3494ConvenienceWidth+fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494ConvenienceDepth-fIBM3494Radius>}
        cylinder{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494ConvenienceDepth-fIBM3494Radius><fIBM3494ConvenienceWidth+fIBM3494Radius,-fIBM3494Radius,fIBM3494ConvenienceDepth-fIBM3494Radius>,fIBM3494Radius}
        cylinder{<-fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494ConvenienceDepth-fIBM3494Radius><fIBM3494ConvenienceWidth+fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494ConvenienceDepth-fIBM3494Radius>,fIBM3494Radius}
        cylinder{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494ConvenienceDepth-fIBM3494Radius><-fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494ConvenienceDepth-fIBM3494Radius>,fIBM3494Radius}
        cylinder{<fIBM3494ConvenienceWidth+fIBM3494Radius,-fIBM3494Radius,fIBM3494ConvenienceDepth-fIBM3494Radius><fIBM3494ConvenienceWidth+fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494ConvenienceDepth-fIBM3494Radius>,fIBM3494Radius}
        }
      }        
  
  #local oConvenienceCover =
    object {
      Round_Box(<0,0,0>,<fIBM3494ConvenienceWidth,fIBM3494ConvenienceHeight,fIBM3494ConvenienceDepth>,fIBM3494Radius,false)
      }
      
  #local oConvenienceCyl =
    object {
      difference {
        object {
          union {
            difference{
              cylinder{<0,0,0><0,fIBM3494ConvenienceCylHeight,0>,fIBM3494ConvenienceCylRadius}
              Round_Box(<-fIBM3494ConvenienceCylWindowWidth/2,1,-(fIBM3494ConvenienceCylRadius+0.1)>,<fIBM3494ConvenienceCylWindowWidth/2,fIBM3494ConvenienceCylWindowHeight+1,0>,fIBM3494ConvenienceCylWindowRadius,false)
              }
            cylinder{<0,0,0><0,fIBM3494ConvenienceCylHeight,0>,fIBM3494ConvenienceCylRadius-0.0001 texture{T_Glass1}}
            object {
              BlueButton(fIBM3494BlueButtonWidth,fIBM3494BlueButtonHeight,fIBM3494BlueButtonDepth,fIBM3494ConvenienceCylRadius+fIBM3494BlueButtonDepth,fIBM3494BlueButtonRadius)
              rotate -45*y
              pigment{SkyBlue}
              }    
            }
          }
        cylinder{<0,0,0><0,fIBM3494ConvenienceCylHeight,0>,fIBM3494ConvenienceCylRadius-fIBM3494Radius texture{T_Glass1}}
        }    
      clipped_by{plane{ z, -2}}
      pigment{White*0.5}
      }
            
  #local oConvenienceStationAssembly =
    object {
      union {
        object {      //* Left Side of Convenience Station
          union {
            box{<-fIBM3494Radius,-fIBM3494Radius,-fIBM3494Radius><fIBM3494ConvenienceLeftWidth,fIBM3494ConvenienceHeight+fIBM3494Radius,0> translate <-fIBM3494ConvenienceLeftWidth,0,0>}
            cylinder{<0,-fIBM3494Radius,0><0,fIBM3494ConvenienceHeight+fIBM3494Radius,0>,fIBM3494Radius} 
            object {
              difference {
                box{<0,-fIBM3494Radius,-fIBM3494Radius><fIBM3494ConvenienceLeftLength,fIBM3494ConvenienceHeight+fIBM3494Radius,0>}
                box{<0,-0.1,-0.1><fIBM3494BlueButtonDepth+1/8+0.1,fIBM3494BlueButtonHeight+1/8,fIBM3494Radius+0.1> translate<fIBM3494ConvenienceLeftLength-(fIBM3494BlueButtonDepth+1/8),0,0>}
                }
              rotate -45*y
              }
            }
          translate <fIBM3494ConvenienceLeftWidth,0,fIBM3494Radius>  
          }
        object {      //* Right Side of Convenience Station
          union {
            box{<0,-fIBM3494Radius,-fIBM3494Radius><fIBM3494ConvenienceRightWidth+fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,0>}
            cylinder{<0,-fIBM3494Radius,0><0,fIBM3494ConvenienceHeight+fIBM3494Radius,0>,fIBM3494Radius}
            object {
              difference {
                box{<0,-fIBM3494Radius,-fIBM3494Radius><-fIBM3494ConvenienceRightLength,fIBM3494ConvenienceHeight+fIBM3494Radius,0>}
                box{<0,-0.1,-0.1><-(fIBM3494BlueButtonDepth+1/8+0.1),fIBM3494BlueButtonHeight+1/8,fIBM3494Radius+0.1> translate<-(fIBM3494ConvenienceRightLength-(fIBM3494BlueButtonDepth+1/8)),0,0>}
                }
              rotate  45*y
              }
            }
          translate <fIBM3494ConvenienceWidth-fIBM3494ConvenienceRightWidth,0,fIBM3494Radius>  
          }
        object {     //* Bottom of Frame
          union {
            cylinder{<-fIBM3494Radius,-fIBM3494Radius,+fIBM3494Radius><fIBM3494ConvenienceWidth+fIBM3494Radius,-fIBM3494Radius,+fIBM3494Radius>,fIBM3494Radius}
            box{<-fIBM3494Radius,-fIBM3494Radius,+fIBM3494Radius><fIBM3494ConvenienceWidth+fIBM3494Radius,0,fIBM3494DoorDepth-fIBM3494ConvenienceDepth>}
            }
          }
        object {     //* Top of Frame
          union {
            cylinder{<-fIBM3494Radius,fIBM3494ConvenienceHeight,+fIBM3494Radius><fIBM3494ConvenienceWidth+fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,+fIBM3494Radius>,fIBM3494Radius}
            box{<-fIBM3494Radius,fIBM3494ConvenienceHeight,+fIBM3494Radius><fIBM3494ConvenienceWidth+fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494DoorDepth-fIBM3494ConvenienceDepth>}
            }
          }
        object {
          union {
            object {
              oConvenienceCyl
              }
            #declare fSeed = seed(1923);
            #local iTape = 0;
            #while (iTape < 10)
              #declare sSerial = str(30000+rand(fSeed)*10000,-6,0);
              object {
                IBM3490Cart(sSerial)
                translate <-2.125,iTape*1.250+1.250,-2>
                }
              #local iTape = iTape + 1;
            #end  
            }
          translate <fIBM3494ConvenienceCylXOffset,fIBM3494ConvenienceCylYOffset,fIBM3494ConvenienceCylZOffset>
          }
        }  
      }
      
  #local oConvenienceStation =
    object {
      union {
        difference {
          object {oConvenienceStationAssembly }
          object {
            Round_Box(<0,0,-0.1>,<fIBM3494ConveniencePanelWidth,fIBM3494ConveniencePanelHeight,fIBM3494Radius+0.1>,fIBM3494Radius,false)
            translate <fIBM3494ConveniencePanelXOffset,fIBM3494ConveniencePanelYOffset,0>
            }
          }
        object {
          IBM3494ConveniencePanel()  
          translate <fIBM3494ConveniencePanelXOffset,fIBM3494ConveniencePanelYOffset,fIBM3494Radius>
          }
        }
      translate <0,0,fIBM3494ConvenienceDepth>
      }
      
  #local oConveniencePower =
    object {
      union { 
        difference {
          box{<-fIBM3494Radius,-fIBM3494Radius,0>,<fIBM3494ConvenienceWidth+fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494Radius>}
          object {
            Round_Box(<0,0,-0.1>,<fIBM3494PowerPanelWidth,fIBM3494PowerPanelHeight,fIBM3494Radius+0.1>,fIBM3494Radius,false)
            translate <fIBM3494PowerPanelXOffset,fIBM3494PowerPanelYOffset,0>
            }
          }
        object {
          IBM3494PowerPanel()
          translate <fIBM3494PowerPanelXOffset,fIBM3494PowerPanelYOffset,fIBM3494Radius>
          }
        }  
      translate <0,0,fIBM3494ConvenienceDepth>  
      }
      
  #local oExtendedHole =
    object {
      box{<-fIBM3494Radius,-fIBM3494Radius,-0.1><fIBM3494ExtendedWidth+fIBM3494Radius,fIBM3494ExtendedHeight+fIBM3494Radius,fIBM3494DoorDepth+0.1>}
      }
      
  #local oExtendedFrame =
    object {
      union {
        cylinder{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius><fIBM3494ExtendedWidth+fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius>,fIBM3494Radius}
        cylinder{<-fIBM3494Radius,fIBM3494ExtendedHeight+fIBM3494Radius,fIBM3494Radius><fIBM3494ExtendedWidth+fIBM3494Radius,fIBM3494ExtendedHeight+fIBM3494Radius,fIBM3494Radius>,fIBM3494Radius}
        cylinder{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius><-fIBM3494Radius,fIBM3494ExtendedHeight+fIBM3494Radius,fIBM3494Radius>,fIBM3494Radius}
        cylinder{<fIBM3494ExtendedWidth+fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius><fIBM3494ExtendedWidth+fIBM3494Radius,fIBM3494ExtendedHeight+fIBM3494Radius,fIBM3494Radius>,fIBM3494Radius}
        box{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius><fIBM3494ExtendedWidth+fIBM3494Radius,0,fIBM3494ExtendedDepth-fIBM3494Radius>}
        box{<-fIBM3494Radius,fIBM3494ExtendedHeight,fIBM3494Radius><fIBM3494ExtendedWidth+fIBM3494Radius,fIBM3494ExtendedHeight+fIBM3494Radius,fIBM3494ExtendedDepth-fIBM3494Radius>}
        box{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494Radius><0,fIBM3494ExtendedHeight+fIBM3494Radius,fIBM3494ExtendedDepth-fIBM3494Radius>}
        box{<fIBM3494ExtendedWidth,-fIBM3494Radius,fIBM3494Radius><fIBM3494ExtendedWidth+fIBM3494Radius,fIBM3494ExtendedHeight+fIBM3494Radius,fIBM3494ExtendedDepth-fIBM3494Radius>}
        cylinder{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494ExtendedDepth-fIBM3494Radius><fIBM3494ExtendedWidth+fIBM3494Radius,-fIBM3494Radius,fIBM3494ExtendedDepth-fIBM3494Radius>,fIBM3494Radius}
        cylinder{<-fIBM3494Radius,fIBM3494ExtendedHeight+fIBM3494Radius,fIBM3494ExtendedDepth-fIBM3494Radius><fIBM3494ExtendedWidth+fIBM3494Radius,fIBM3494ExtendedHeight+fIBM3494Radius,fIBM3494ExtendedDepth-fIBM3494Radius>,fIBM3494Radius}
        cylinder{<-fIBM3494Radius,-fIBM3494Radius,fIBM3494ExtendedDepth-fIBM3494Radius><-fIBM3494Radius,fIBM3494ExtendedHeight+fIBM3494Radius,fIBM3494ExtendedDepth-fIBM3494Radius>,fIBM3494Radius}
        cylinder{<fIBM3494ExtendedWidth+fIBM3494Radius,-fIBM3494Radius,fIBM3494ConvenienceDepth-fIBM3494Radius><fIBM3494ExtendedWidth+fIBM3494Radius,fIBM3494ConvenienceHeight+fIBM3494Radius,fIBM3494ExtendedDepth-fIBM3494Radius>,fIBM3494Radius}
        }
      }        
  
  #local oExtendedCover =
    object {
      Round_Box(<0,0,0>,<fIBM3494ExtendedWidth,fIBM3494ExtendedHeight,fIBM3494ExtendedDepth>,fIBM3494Radius,false)
      }

  #local oExtendedCyl =
    object {
      difference {
        object {
          union {
            difference{
              cylinder{<0,0,0><0,fIBM3494ExtendedCylHeight,0>,fIBM3494ExtendedCylRadius}
              Round_Box(<-fIBM3494ExtendedCylWindowWidth/2,1,-(fIBM3494ExtendedCylRadius+0.1)>,<fIBM3494ExtendedCylWindowWidth/2,fIBM3494ExtendedCylWindowHeight+1,0>,fIBM3494ExtendedCylWindowRadius,false)
              }
            cylinder{<0,0,0><0,fIBM3494ExtendedCylHeight,0>,fIBM3494ExtendedCylRadius-0.0001 texture{T_Glass1}}
            object {
              BlueButton(fIBM3494BlueButtonWidth,fIBM3494BlueButtonHeight,fIBM3494BlueButtonDepth,fIBM3494ExtendedCylRadius+fIBM3494BlueButtonDepth,fIBM3494BlueButtonRadius)
              rotate -45*y
              pigment{SkyBlue}
              }    
            }
          }
        cylinder{<0,0,0><0,fIBM3494ExtendedCylHeight,0>,fIBM3494ExtendedCylRadius-fIBM3494Radius texture{T_Glass1}}
        }    
      clipped_by{plane{ z, -2}}
      pigment{White*0.5}
      }
            
  #local oExtendedStation =
    object {
      union {
        object {      //* Left Side of Extended Station
          union {
            box{<-fIBM3494Radius,-fIBM3494Radius,-fIBM3494Radius><fIBM3494ExtendedLeftWidth,fIBM3494ExtendedHeight+fIBM3494Radius,0> translate <-fIBM3494ExtendedLeftWidth,0,0>}
            cylinder{<0,-fIBM3494Radius,0><0,fIBM3494ExtendedHeight+fIBM3494Radius,0>,fIBM3494Radius} 
            object {
              difference {
                box{<0,-fIBM3494Radius,-fIBM3494Radius><fIBM3494ExtendedLeftLength,fIBM3494ExtendedHeight+fIBM3494Radius,0>}
                box{<0,-0.1,-0.1><fIBM3494BlueButtonDepth+1/8+0.1,fIBM3494BlueButtonHeight+1/8,fIBM3494Radius+0.1> translate<fIBM3494ExtendedLeftLength-(fIBM3494BlueButtonDepth+1/8),0,0>}
                }
              rotate -45*y
              }
            }
          translate <fIBM3494ExtendedLeftWidth,0,fIBM3494Radius>  
          }
        object {      //* Right Side of Extended Station
          union {
            box{<0,-fIBM3494Radius,-fIBM3494Radius><fIBM3494ExtendedRightWidth+fIBM3494Radius,fIBM3494ExtendedHeight+fIBM3494Radius,0>}
            cylinder{<0,-fIBM3494Radius,0><0,fIBM3494ExtendedHeight+fIBM3494Radius,0>,fIBM3494Radius}
            object {
              difference {
                box{<0,-fIBM3494Radius,-fIBM3494Radius><-fIBM3494ExtendedRightLength,fIBM3494ExtendedHeight+fIBM3494Radius,0>}
                box{<0,-0.1,-0.1><-(fIBM3494BlueButtonDepth+1/8+0.1),fIBM3494BlueButtonHeight+1/8,fIBM3494Radius+0.1> translate<-(fIBM3494ExtendedRightLength-(fIBM3494BlueButtonDepth+1/8)),0,0>}
                }
              rotate  45*y
              }
            }
          translate <fIBM3494ExtendedWidth-fIBM3494ExtendedRightWidth,0,fIBM3494Radius>  
          }
        object {     //* Bottom of Frame
          union {
            cylinder{<-fIBM3494Radius,-fIBM3494Radius,+fIBM3494Radius><fIBM3494ExtendedWidth+fIBM3494Radius,-fIBM3494Radius,+fIBM3494Radius>,fIBM3494Radius}
            box{<-fIBM3494Radius,-fIBM3494Radius,+fIBM3494Radius><fIBM3494ExtendedWidth+fIBM3494Radius,0,fIBM3494DoorDepth-fIBM3494ExtendedDepth>}
            }
          }
        object {     //* Top of Frame
          union {
            cylinder{<-fIBM3494Radius,fIBM3494ExtendedHeight,+fIBM3494Radius><fIBM3494ExtendedWidth+fIBM3494Radius,fIBM3494ExtendedHeight+fIBM3494Radius,+fIBM3494Radius>,fIBM3494Radius}
            box{<-fIBM3494Radius,fIBM3494ExtendedHeight,+fIBM3494Radius><fIBM3494ExtendedWidth+fIBM3494Radius,fIBM3494ExtendedHeight+fIBM3494Radius,fIBM3494DoorDepth-fIBM3494ExtendedDepth>}
            }
          }
        object {
          union {
            object {
              oExtendedCyl
              }
            #declare fSeed = seed(1921);
            #local iTape = 0;
            #while (iTape < 20)
              #declare sSerial = str(30000+rand(fSeed)*10000,-6,0);
              object {
                IBM3490Cart(sSerial)
                translate <-2.125,iTape*1.250+1.250,-2>
                }
              #local iTape = iTape + 1;
            #end
            }
          translate <fIBM3494ExtendedCylXOffset,fIBM3494ExtendedCylYOffset,fIBM3494ExtendedCylZOffset>
          }    
        }  
      translate <0,0,fIBM3494ExtendedDepth>
      }
      
  #local oDoor =
    object {
      #switch (iDoorType)
        #case (10)                             //* Basic Front Door
//          union {
            object { oBasicFrontDoor }
//            }
        #break
        #case (11)                             //* Basic Front Door with Convenience Cover
          union {
            object {
              difference {
                object { oBasicFrontDoor }
                object { oConvenienceHole translate<fIBM3494ConvenienceXOffset,fIBM3494ConvenienceYOffset,0>}
                }
              }
            object { oConvenienceFrame translate<fIBM3494ConvenienceXOffset,fIBM3494ConvenienceYOffset,0>}
            object { oConvenienceCover translate<fIBM3494ConvenienceXOffset,fIBM3494ConvenienceYOffset,0>}
            }
        #break    
        #case (12)                             //* Basic Front Door with Convenience Station
          union {
            object {
              difference {
                object { oBasicFrontDoor }
                object { oConvenienceHole translate<fIBM3494ConvenienceXOffset,fIBM3494ConvenienceYOffset,0>}
                object { oExtendedHole translate<fIBM3494ExtendedXOffset,fIBM3494ExtendedYOffset,0>}
                }
              }
            object { oConvenienceFrame translate<fIBM3494ConvenienceXOffset,fIBM3494ConvenienceYOffset,0>}
            object { oConvenienceStation translate<fIBM3494ConvenienceXOffset,fIBM3494ConvenienceYOffset,0>}
            object { oExtendedFrame translate<fIBM3494ExtendedXOffset,fIBM3494ExtendedYOffset,0>}
            object { oExtendedStation translate<fIBM3494ExtendedXOffset,fIBM3494ExtendedYOffset,0>}
            }
        #break
        #case (13)                             //* Basic Front Door with Convenience Power Panel
          union {
            object {
              difference {
                object { oBasicFrontDoor }
                object { oConvenienceHole translate<fIBM3494ConvenienceXOffset,fIBM3494ConvenienceYOffset,0>}
                object { oExtendedHole translate<fIBM3494ExtendedXOffset,fIBM3494ExtendedYOffset,0>}
                }
              }
            object { oConvenienceFrame translate<fIBM3494ConvenienceXOffset,fIBM3494ConvenienceYOffset,0>}
            object { oConveniencePower translate<fIBM3494ConvenienceXOffset,fIBM3494ConvenienceYOffset,0>}
            object { oExtendedFrame translate<fIBM3494ExtendedXOffset,fIBM3494ExtendedYOffset,0>}
            object { oExtendedCover translate<fIBM3494ExtendedXOffset,fIBM3494ExtendedYOffset,0>}
            }
        #break
        #case (20)                         //* Basic Back Door 
          union {                             
            difference {
              object { oBasicBackDoor }
//              union {
                box{
                  <0,0,-0.1><fIBM3494DoorVent1Width,fIBM3494DoorVent1Height,fIBM3494DoorDepth+0.1>
                  translate <fIBM3494DoorVent1XOffset,fIBM3494DoorVent1YOffset,0>
                  }
//                }
              }    
            object {
              Vent(fIBM3494DoorVent1Width,fIBM3494DoorVent1Height,fIBM3494Radius,fIBM3494DoorVent1nSlat)
              rotate 180*y
              translate <fIBM3494DoorVent1Width,0,fIBM3494DoorDepth>
              translate <fIBM3494DoorVent1XOffset,fIBM3494DoorVent1YOffset,0> 
              }
            }
        #break
        #case (21)                         //* Frame Manager Back Door 
          union {                             
            difference {
              object { oBasicBackDoor }
              object {
                box {
                  <-fIBM3494Radius,-fIBM3494Radius,-0.1><fIBM3494DoorPCInsetWidth+fIBM3494Radius,fIBM3494DoorPCInsetHeight+fIBM3494Radius,fIBM3494DoorDepth+0.1>
                  translate <fIBM3494DoorPCInsetXOffset,fIBM3494DoorPCInsetYOffset,0>
                  }
                }
              }    
            object {
              RoundBoxHole2(fIBM3494DoorPCInsetWidth,fIBM3494DoorPCInsetHeight,fIBM3494DoorPCInsetDepth,fIBM3494Radius)
              rotate 180*y
              translate <fIBM3494DoorPCInsetWidth,0,fIBM3494DoorDepth>
              translate <fIBM3494DoorPCInsetXOffset,fIBM3494DoorPCInsetYOffset,0>
              }
            }
        #break
      #end
      }
  oDoor    
#end

//***************************************************************************************************************/
//* IBM 3494 Frame Definitions                                                                                  */
//*     Parameters:                                                                                             */
//*         iFramePosition   :    0 - Middle Frame, No End Covers Needed                                        */
//*                               1 - First Frame, Add Left End Cover                                           */
//*                               2 - Last Frame, Add Right End Cover                                           */
//*         iBackFrameType   :    0 - No back Frame                                                             */
//*                               1 - Standard Back Frame                                                       */
//*                               2 - PC Insert Back Frame                                                      */
//*         iFrontFrameType  :    0 - Standard Front Frame                                                      */
//*                               1 - Convenience Station                                                       */           
//***************************************************************************************************************/
#macro IBM3494Frame(iFramePosition,iBackFrameType,iFrontFrameType)
  #local oFrame1 =               //* Front Frame
    object {
      union {
        box{<0,0,0><fIBM3494Width,1.0,fIBM3494Depth1+fIBM3494DepthGap>}
        box{<0,0,0><fIBM3494Width,1.0,fIBM3494Depth1+fIBM3494DepthGap> translate (fIBM3494Height-1)*y}
        box{<0,0,0><fIBM3494Width,fIBM3494Height,fIBM3494DepthGap> translate fIBM3494Depth1*z}
        }
      translate 0.25*y
      texture {fIBM3494Texture1}
      }         
  //*************************************************************************************************************/
  #local oFrame2 =               // Back Frame
    object {
      union {
        box{<0,0,0><fIBM3494Width,1.0,fIBM3494Depth2+fIBM3494DepthGap>}
        box{<0,0,0><fIBM3494Width,1.0,fIBM3494Depth2+fIBM3494DepthGap> translate (fIBM3494Height-1)*y}
        }
      translate 0.25*y
      texture {fIBM3494Texture2}
      }
      
  //*************************************************************************************************************/
                                                                        //*                                     */
  #local oFrame =                                                       //* Combined Frames                     */
    object {                                                            //*                                     */
      union {                                                           //*                                     */
        object {                                                        //* Front Frame                         */
          union {                                                       //*                                     */
            #if (iFramePosition = 1)                                    //* First Frame - Add Left End Cover    */
              object {IBM3494EndCover(1) translate <0,0,fIBM3494DoorDepth>}                                  
            #end  
            object { oFrame1 translate <fIBM3494EndWidth,0,fIBM3494DoorDepth>}
            #if (iFramePosition = 2)                                    //* Last Frame - Add Right End Cover    */
              object {IBM3494EndCover(2) translate <fIBM3494EndWidth+fIBM3494Width,0,fIBM3494DoorDepth>}                                  
            #end
            #switch (iFrontFrameType)
              #case (0)  
                object { IBM3494Door(10) }
              #break
              #case (1)  
                object { IBM3494Door(11) }
              #break
              #case (2)  
                object { IBM3494Door(12) }
              #break
              #case (3)  
                object { IBM3494Door(13) }
              #break
            #end
            }
          texture {fIBM3494Texture1}
          }
        #if (iBackFrameType < 1)
          object {
            Round_Box(<0,0,0>,<fIBM3494DoorWidth,fIBM3494Height,fIBM3494EndWidth>,fIBM3494Radius,false)
            translate <0,0,fIBM3494DoorDepth+fIBM3494Depth1>
            texture {fIBM3494Texture1}
            }
          object {IBM3494EndCover(0) translate <-                              fIBM3494EndWidth,0,fIBM3494DoorDepth+fIBM3494Depth1+fIBM3494DepthGap>}
          object {IBM3494EndCover(0) translate <fIBM3494EndWidth+fIBM3494Width+fIBM3494EndWidth,0,fIBM3494DoorDepth+fIBM3494Depth1+fIBM3494DepthGap>}
        #else    
          object {                                                        //* Back Frame
            union {                       
              #if (iFramePosition = 1)      //* First Frame - Add Left End Cover
                object {IBM3494EndCover(0)}                                  
              #end  
              object { oFrame2 translate <fIBM3494EndWidth,0,0>}
              #if (iFramePosition = 2)      //* Last Frame - Add Right End Cover
                object {IBM3494EndCover(0) translate <fIBM3494EndWidth+fIBM3494Width,0,0>}                                  
              #end
              #switch (iBackFrameType)
                #case (1)
                  object { IBM3494Door(20) translate <0,0,fIBM3494Depth2>}
                #break
                #case (2)  
                  object { IBM3494Door(21) translate <0,0,fIBM3494Depth2>}
                #break
              #end
              }
            translate <0,0,fIBM3494DoorDepth+fIBM3494Depth1+fIBM3494DepthGap>
            texture {fIBM3494Texture2}
            }
        #end
        }
      }
  
  oFrame
            
#end
