//***************************************************************************************************************/
//* Persistence of Vision Ray Tracer Scene Description File                                                     */
//* File: 9032.inc                                                                                              */
//* Vers: 3.6                                                                                                   */
//* Desc: 9032 Escon Director                                                                                   */
//* Date: 11/22/2004                                                                                            */
//* Auth: D. E. LeMasters                                                                                       */
//***************************************************************************************************************/
#version 3.6;                                                           //*                                     */
#include "IBMPS2.inc"                                                                        //*                                     */
//***************************************************************************************************************/
//* 9032 Macro Definition                                                                                       */
//***************************************************************************************************************/
#macro IBM9032(bPC)
  //*************************************************************************************************************/
  //* Basic External Dimensions                                                                                 */
  //*************************************************************************************************************/
  #local vTexture0        = pigment{Black};                             //* Base Texture                        */
  #local vTexture2        = texture{pigment{White*0.05} 
                            normal { bumps 0.04 scale 0.0005 }
                            finish { phong 0.5 }};                        //* Base Texture                        */
  #local vTexture1        = texture{pigment{White*0.50} 
                            normal { bumps 0.04 scale 0.0005 }
                            finish { phong 0.5 }};                        //* Base Texture                        */
  #local fWidth           = 26.00;                                      //* Overall Width                       */
  #local fHeight          = 47.00;                                      //* Overall Height                      */
  #local fDepth           = 26.00;                                      //* Overall Depth                       */ 
  #local fRadius          =  0.10;                                      //* Corner Radius                       */
  #local fGap             =  0.25;                                      //* Gap between panels                  */
  //*************************************************************************************************************/
  //* Side Panel Definitions                                                                                    */
  //*************************************************************************************************************/
  #local fSideWidth       = fDepth;
  #local fSideHeight      = fHeight;
  #local fSideDepth       = 1.00;
  //*************************************************************************************************************/
  //* Rear Panel Definitions                                                                                    */
  //*************************************************************************************************************/
  #local fRearWidth       = fWidth - 2*(fSideDepth+fGap);
  #local fRearHeight      = fHeight;
  #local fRearDepth       = 1.00;
  //*************************************************************************************************************/
  //* Front Panel Definitions                                                                                   */
  //*************************************************************************************************************/
  #local fFrontWidth      = fWidth - 2*(fSideDepth+fGap);
  #local fFrontHeight     = fHeight;
  #local fFrontDepth      = 1.00;
  #local fLEDWidth        = 0.375;
  #local fLEDHeight       = 0.125;
  #local fLEDDepth        = 0.125;
  //*************************************************************************************************************/
  //* Front Panel Definitions (Switch Panel)                                                                    */
  //*************************************************************************************************************/
  #local fSwitchWidth     =  2.25;
  #local fSwitchHeight    =  3.50;
  #local fSwitchDepth     =  1.00;
  #local fSwitchXOffset   =  1.75;
  #local fSwitchYOffset   = 41.00;
  #local fToggleRadius    =  0.75;
  #local fToggleWidth     =  0.75;
  #local fToggleCorner    =  0.05;
  #local fToggle1XOffset  = fSwitchWidth/2-fToggleWidth-0.025;
  #local fToggle2XOffset  = fSwitchWidth/2+             0.025;
  #local fToggleYOffset   = fSwitchHeight/2-fToggleRadius;
  //*************************************************************************************************************/
  //* Front Panel Definitions (Control Panel)                                                                   */
  //*************************************************************************************************************/
  #local fControlWidth     =  6.875;
  #local fControlHeight    =  3.50;
  #local fControlDepth     =  1.00;
  #local fControlXOffset   =  5.875;
  #local fControlYOffset   = 41.00;
  #local fLineWidth        =  1/32;  
  #local fPowerXOffset     = 0.750;
  #local fPowerYOffset     = 2.125;
  #local fSystemXOffset    = 0.750;
  #local fSystemYOffset    = 1.000;
  #local fStatusWidth      = 2.500;
  #local fStatusHeight     = 0.375;
  #local fStatusDepth      = 0.125;
  #local fStatusXOffset    = 2.375;
  #local fStatusYOffset    = 1.750;
  #local fButtonWidth      = 0.375;
  #local fButtonHeight     = 0.125;
  #local fButtonDepth      = 0.125;
  #local fButtonRadius     = 0.0125;
  #local fAdvanceXOffset   = 2.375;
  #local fEntryXOffset     = 3.125;
  #local fDetailXOffset    = 3.875;
  #local fClearXOffset     = 4.625;
  #local fIMLXOffset       = 6.000;
  #local fAdvanceYOffset   = 1.000;
  #local fEntryYOffset     = 1.000;
  #local fDetailYOffset    = 1.000;
  #local fClearYOffset     = 1.000;
  #local fIMLYOffset       = 2.125;
  //*************************************************************************************************************/
  //* Front Panel Definitions (Logo)                                                                            */
  //*************************************************************************************************************/ 
  #local fLogoWidth        =  2.125;
  #local fLogoHeight       =  1.375;
  #local fLogoDepth        =  0.0625;
  #local fLogoXOffset      = fFrontWidth -4.125;
  #local fLogoYOffset      = fFrontHeight-4.375;
  #local fIBMWidth         =  1.3;
  #local fIBMHeight        =  0.5;
  #local fIBMDepth         = 1/16;
  #local fIBMAngle         = 30;
  #local fIBMXOffset       =  0.45;
  #local fIBMYOffset       =  0.225;
  #local f9032XOffset      =  1.45;
  #local f9032YOffset      =  0.50;
  //*************************************************************************************************************/
  //* Front Panel Definitions (Latch)                                                                           */
  //*************************************************************************************************************/ 
  #local fLatchDepth       =  0.0625;
  #local fLatchRadius      =  0.375;
  #local fLatchCorner      =  0.050;
  #local fLatchBorder      =  0.125;
  #local fLatch1XOffset    = fFrontWidth-1.5;
  #local fLatch1YOffset    = 10.00;
  #local fLatch2XOffset    = fFrontWidth-1.5;
  #local fLatch2YOffset    = 37.00;  
  #local fKeyHoleRadius    = 1/8;
  #local fKeyHoleDepth     = 1/8;
  //*************************************************************************************************************/
  //* Front Panel Definitions (Vent Panel)                                                                      */
  //*************************************************************************************************************/
  #local fVentWidth        =  5.75;
  #local fVentHeight       = 12.00;
  #local fVentDepth        =  1.00;
  #local fVentThickness    =  1/32;
  #local nVentStrips       = 16;
  #local fVentAngle        =  30;
  #local fVent1XOffset     =  1.75;
  #local fVent1YOffset     =  2.50;
  #local fVent2XOffset     =  8.25;
  #local fVent2YOffset     =  2.50;
  #local fVent3XOffset     = 14.75;
  #local fVent3YOffset     =  2.50;
  //*************************************************************************************************************/
  //* Top Panel Definitions                                                                                     */
  //*************************************************************************************************************/
  #local fTopWidth        = fWidth - 2*(fSideDepth+fGap);
  #local fTopHeight       = 1.00;
  #local fTopDepth        = fDepth - ((fFrontDepth+fGap) + (fRearDepth+fGap));
  //*************************************************************************************************************/
  //* Frame Definitions                                                                                         */
  //*************************************************************************************************************/
  #local fFrameWidth      = fWidth - 2*fSideDepth;
  #local fFrameHeight     = fHeight - fTopHeight;
  #local fFrameDepth      = fDepth - (fFrontDepth + fRearDepth);
  //*************************************************************************************************************/
  //* Define Side Panel                                                                                         */
  //*************************************************************************************************************/
  #local oFrame =
    object {
      Round_Box(< 0, 0, 0>,< fFrameDepth, fFrameHeight, fFrameWidth>, fRadius, true)
      }
  //*************************************************************************************************************/
  //* Define Side Panel                                                                                         */
  //*************************************************************************************************************/
  #local oSidePanel =
    object {
      Round_Box(< 0, 0, 0>,< fSideDepth, fSideHeight, fSideWidth>, fRadius, true)
      }
  //*************************************************************************************************************/
  //* Define Rear Panel                                                                                         */
  //*************************************************************************************************************/
  #local oRearPanel =
    object {
      Round_Box(< 0, 0, 0>,< fRearWidth, fRearHeight, fRearDepth>, fRadius, true)
      }
  //*************************************************************************************************************/
  //* Define Top Panel                                                                                         */
  //*************************************************************************************************************/
  #local oTopPanel =
    object {
      Round_Box(< 0, 0, 0>,< fTopWidth, fTopHeight, fTopDepth>, fRadius, true)
      }
      
  //*************************************************************************************************************/
  //* Define FrontPanel Toggle Switch                                                                           */
  //*************************************************************************************************************/
  #local oHalfToggle =
    object {
      union {
        intersection {
          object { Round_Cylinder(< 0, 0, 0>,< fToggleWidth, 0, 0>, fToggleRadius, fToggleCorner, true) }
          box{< -0.01, -(fToggleRadius+0.01), 0>< fToggleWidth+0.01, +(fToggleRadius+0.01), (fToggleRadius+0.01)>}
          }
        box{ < fToggleCorner,-(fToggleRadius-fToggleCorner),0>< fToggleWidth-fToggleCorner, (fToggleRadius-fToggleCorner), -fToggleCorner>}
        cylinder{< fToggleCorner, -(fToggleRadius-fToggleCorner), 0>< fToggleCorner, +(fToggleRadius-fToggleCorner), 0>,fToggleCorner}  
        cylinder{< fToggleWidth-fToggleCorner, -(fToggleRadius-fToggleCorner), 0>< fToggleWidth-fToggleCorner, +(fToggleRadius-fToggleCorner), 0>,fToggleCorner}
        cylinder{< fToggleCorner,-(fToggleRadius-fToggleCorner),0><fToggleWidth-fToggleCorner,-(fToggleRadius-fToggleCorner),0>,fToggleCorner}
        cylinder{< fToggleCorner, (fToggleRadius-fToggleCorner),0><fToggleWidth-fToggleCorner, (fToggleRadius-fToggleCorner),0>,fToggleCorner}
        sphere{<fToggleCorner,-(fToggleRadius-fToggleCorner), 0>,fToggleCorner}  
        sphere{<fToggleWidth-fToggleCorner,-(fToggleRadius-fToggleCorner), 0>,fToggleCorner}  
        sphere{<fToggleCorner, (fToggleRadius-fToggleCorner), 0>,fToggleCorner}  
        sphere{<fToggleWidth-fToggleCorner, (fToggleRadius-fToggleCorner), 0>,fToggleCorner}  
        }
      }
      
  #local oToggleTextI =
    object {
      text { ttf "ariblk.ttf" "I" 0.125, <0,0,0>}
      scale 0.25
      pigment{Black}
      }
  #local vToggleTextIMin = min_extent(oToggleTextI);
  #local vToggleTextIMax = max_extent(oToggleTextI);
  #local fToggleTextIWidth  = vToggleTextIMax.x - vToggleTextIMin.x;
  #local fToggleTextIHeight = vToggleTextIMax.y - vToggleTextIMin.y;
      
  #local oToggleTextO =
    object {
      text { ttf "ariblk.ttf" "O" 0.125, <0,0,0>}
      scale 0.25
      pigment{Black}
      }
  #local vToggleTextOMin = min_extent(oToggleTextO);
  #local vToggleTextOMax = max_extent(oToggleTextO);
  #local fToggleTextOWidth  = vToggleTextOMax.x - vToggleTextOMin.x;
  #local fToggleTextOHeight = vToggleTextOMax.y - vToggleTextOMin.y;
      
  #local oToggle =
    object {
      union {
        object {
          union {
            object { oHalfToggle }
            object { oToggleTextI translate <(fToggleWidth-fToggleTextIWidth)/2, (fToggleRadius-fToggleTextIHeight)/2,-(fToggleCorner+0.001)> }
            } 
          rotate -15*x 
          }
        object {
          union {
            object {oHalfToggle}
            object { oToggleTextO translate <(fToggleWidth-fToggleTextOWidth)/2,-fToggleRadius+(fToggleRadius-fToggleTextOHeight)/2,-(fToggleCorner+0.001)> }
            } 
          rotate  15*x 
          }
        }  
      rotate  15*x
      translate fToggleRadius*y
      pigment{White}
      }

  //*************************************************************************************************************/
  //* Define Front Switch Panel Poer On/Off text)                                                               */
  //*************************************************************************************************************/
  #local oToggleTextOn =
    object {
      text { ttf "crystal.ttf" "Power On" 0.125, <0,0,0>}
      scale 0.25
      pigment{White}
      }
  #local vToggleTextOnMin = min_extent(oToggleTextOn);
  #local vToggleTextOnMax = max_extent(oToggleTextOn);
  #local fToggleTextOnWidth  = vToggleTextOnMax.x - vToggleTextOnMin.x;
  #local fToggleTextOnHeight = vToggleTextOnMax.y - vToggleTextOnMin.y;
  #local fToggleTextOnXOffset = (fSwitchWidth-fToggleTextOnWidth)/2;
  #local fToggleTextOnYOffset = fToggleYOffset+2*fToggleRadius+0.125;
  
  #local oToggleTextOff =
    object {
      text { ttf "crystal.ttf" "Power Off" 0.125, <0,0,0>}
      scale 0.25
      pigment{White}
      }
  #local vToggleTextOffMin = min_extent(oToggleTextOff);
  #local vToggleTextOffMax = max_extent(oToggleTextOff);
  #local fToggleTextOffWidth  = vToggleTextOffMax.x - vToggleTextOffMin.x;
  #local fToggleTextOffHeight = vToggleTextOffMax.y - vToggleTextOffMin.y;
  #local fToggleTextOffXOffset = (fSwitchWidth-fToggleTextOffWidth)/2;
  #local fToggleTextOffYOffset = fToggleYOffset-0.125-fToggleTextOffHeight;
  
  //*************************************************************************************************************/
  //* Define Front Switch Panel                                                                                 */
  //*************************************************************************************************************/
  #local oSwitchPanel = 
    object {
      union {
        box{< 0, 0, -0.001>< fSwitchWidth, fSwitchHeight, 0> pigment{Black}}
        difference {
          box{< 0, 0, -0.002>< fSwitchWidth, fSwitchHeight, 0>}
          union {
            object {box{< 0, 0, -0.003>< fToggleWidth, 2*fToggleRadius, fSwitchDepth+0.1>} translate <fToggle1XOffset, fToggleYOffset,0>}
            object {box{< 0, 0, -0.003>< fToggleWidth, 2*fToggleRadius, fSwitchDepth+0.1>} translate <fToggle2XOffset, fToggleYOffset,0>}
            }
          }
        object {oToggleTextOn  translate <fToggleTextOnXOffset ,fToggleTextOnYOffset ,-0.003> }
        object {oToggleTextOff translate <fToggleTextOffXOffset,fToggleTextOffYOffset,-0.003> }
        object {oToggle translate <fToggle1XOffset, fToggleYOffset,0>}   
        object {oToggle translate <fToggle2XOffset, fToggleYOffset,0>}   
        }
      texture{vTexture2}
      }
  //*************************************************************************************************************/
  //* Define Front Control Status Display                                                                       */
  //*************************************************************************************************************/
  #local oStatusHole =
    object {
      box{< -0.010, -0.010, -0.1>,< fStatusWidth+0.010, fStatusHeight+0.010, fStatusDepth>}
      }
      
  #local oStatus =
    object {
      box{< 0, 0, 0>,< fStatusWidth, fStatusHeight, fStatusDepth>}
      pigment{color < 0.7, 1.0, 0.7>}
      }
      
  #local oStatusText =
    object {
      text { ttf "crystal.ttf" "Status" 0.125, <0,0,0>}
      scale 0.25
      pigment{White}
      }
      
  #local vStatusTextMin     = min_extent(oStatusText);
  #local vStatusTextMax     = max_extent(oStatusText);
  #local fStatusTextWidth   = vStatusTextMax.x - vStatusTextMin.x;
  #local fStatusTextHeight  = vStatusTextMax.y - vStatusTextMin.y;
  #local fStatusTextXOffset = fStatusXOffset+(fStatusWidth-fStatusTextWidth)/2;
  #local fStatusTextYOffset = fStatusYOffset+fStatusHeight+0.125;
  
  //*************************************************************************************************************/
  //* Define Front Control Panel LED Lights                                                                     */
  //*************************************************************************************************************/
  #local oLEDHole =
    object {
      box{< -0.01, -0.01, -0.1>< fLEDWidth+0.01, fLEDHeight+0.01, fLEDDepth>}
      }
      
  #local oLED =
    object {
      box{< 0, 0, 0>< fLEDWidth, fLEDHeight, fLEDDepth>}
      }
      
  #local oPowerText =
    object {
      text { ttf "crystal.ttf" "Power" 0.125, <0,0,0>}
      scale 0.25
      pigment{White}
      }
  #local vPowerTextMin     = min_extent(oPowerText);
  #local vPowerTextMax     = max_extent(oPowerText);
  #local fPowerTextWidth   = vPowerTextMax.x - vPowerTextMin.x;
  #local fPowerTextHeight  = vPowerTextMax.y - vPowerTextMin.y;
  #local fPowerTextXOffset = fPowerXOffset+(fLEDWidth-fPowerTextWidth)/2;
  #local fPowerTextYOffset = fPowerYOffset+fLEDHeight+0.125;
  
  #local oErrorText =
    object {
      text { ttf "crystal.ttf" "Error" 0.125, <0,0,0>}
      scale 0.25
      pigment{White}
      }
  #local vErrorTextMin     = min_extent(oErrorText);
  #local vErrorTextMax     = max_extent(oErrorText);
  #local fErrorTextWidth   = vErrorTextMax.x - vErrorTextMin.x;
  #local fErrorTextHeight  = vErrorTextMax.y - vErrorTextMin.y;
  #local fErrorTextXOffset = fSystemXOffset+(fLEDWidth-fErrorTextWidth)/2;
  #local fErrorTextYOffset = fSystemYOffset+fLEDHeight+0.125;
  
  #local oSystemText =
    object {
      text { ttf "crystal.ttf" "System" 0.125, <0,0,0>}
      scale 0.25
      pigment{White}
      }
  #local vSystemTextMin     = min_extent(oSystemText);
  #local vSystemTextMax     = max_extent(oSystemText);
  #local fSystemTextWidth   = vSystemTextMax.x - vSystemTextMin.x;
  #local fSystemTextHeight  = vSystemTextMax.y - vSystemTextMin.y;
  #local fSystemTextXOffset = fSystemXOffset+(fLEDWidth-fSystemTextWidth)/2;
  #local fSystemTextYOffset = fErrorTextYOffset+fErrorTextHeight+0.125;
  
  //*************************************************************************************************************/
  //* Define Front Control Panel Buttons                                                                        */
  //*************************************************************************************************************/
  #local oButtonHole =
    object {
      box{< -0.020, -0.020, -0.1>,< fButtonWidth+0.020, fButtonHeight+0.020, fButtonDepth>}
      }
      
  #local oButton =
    object {
      Round_Box(< 0, 0, 0>,< fButtonWidth, fButtonHeight, fButtonDepth>, fButtonRadius, true)
      pigment{White}
      }
      
  #local oAdvanceText =
    object {
      text { ttf "crystal.ttf" "Advance" 0.125, <0,0,0>}
      scale 0.150
      pigment{White}
      }
  #local vAdvanceTextMin     = min_extent(oAdvanceText);
  #local vAdvanceTextMax     = max_extent(oAdvanceText);
  #local fAdvanceTextWidth   = vAdvanceTextMax.x - vAdvanceTextMin.x;
  #local fAdvanceTextHeight  = vAdvanceTextMax.y - vAdvanceTextMin.y;
  #local fAdvanceTextXOffset = fAdvanceXOffset+(fButtonWidth-fAdvanceTextWidth)/2;
  #local fAdvanceTextYOffset = fAdvanceYOffset+fLEDHeight+0.0625;
  
  #local oEntryText =
    object {
      text { ttf "crystal.ttf" "Entry" 0.125, <0,0,0>}
      scale 0.150
      pigment{White}
      }
  #local vEntryTextMin     = min_extent(oEntryText);
  #local vEntryTextMax     = max_extent(oEntryText);
  #local fEntryTextWidth   = vEntryTextMax.x - vEntryTextMin.x;
  #local fEntryTextHeight  = vEntryTextMax.y - vEntryTextMin.y;
  #local fEntryTextXOffset = fEntryXOffset+(fButtonWidth-fEntryTextWidth)/2;
  #local fEntryTextYOffset = fEntryYOffset+fLEDHeight+0.0625;
  
  #local oDetailText =
    object {
      text { ttf "crystal.ttf" "Detail" 0.125, <0,0,0>}
      scale 0.150
      pigment{White}
      }
  #local vDetailTextMin     = min_extent(oDetailText);
  #local vDetailTextMax     = max_extent(oDetailText);
  #local fDetailTextWidth   = vDetailTextMax.x - vDetailTextMin.x;
  #local fDetailTextHeight  = vDetailTextMax.y - vDetailTextMin.y;
  #local fDetailTextXOffset = fDetailXOffset+(fButtonWidth-fDetailTextWidth)/2;
  #local fDetailTextYOffset = fDetailYOffset+fLEDHeight+0.0625;
  
  #local oClearText =
    object {
      text { ttf "crystal.ttf" "Clear" 0.125, <0,0,0>}
      scale 0.150
      pigment{White}
      }
  #local vClearTextMin     = min_extent(oClearText);
  #local vClearTextMax     = max_extent(oClearText);
  #local fClearTextWidth   = vClearTextMax.x - vClearTextMin.x;
  #local fClearTextHeight  = vClearTextMax.y - vClearTextMin.y;
  #local fClearTextXOffset = fClearXOffset+(fButtonWidth-fClearTextWidth)/2;
  #local fClearTextYOffset = fClearYOffset+fLEDHeight+0.0625;
  
  #local oIMLText =
    object {
      text { ttf "crystal.ttf" "IML" 0.125, <0,0,0>}
      scale 0.250
      pigment{White}
      }
  #local vIMLTextMin     = min_extent(oIMLText);
  #local vIMLTextMax     = max_extent(oIMLText);
  #local fIMLTextWidth   = vIMLTextMax.x - vIMLTextMin.x;
  #local fIMLTextHeight  = vIMLTextMax.y - vIMLTextMin.y;
  #local fIMLTextXOffset = fIMLXOffset+(fButtonWidth-fIMLTextWidth)/2;
  #local fIMLTextYOffset = fIMLYOffset+fLEDHeight+0.125;
  
  //*************************************************************************************************************/
  //* Define Front Control Panel LED Lights                                                                     */
  //*************************************************************************************************************/
  #local oLEDHole =
    object {
      box{< -0.01, -0.01, -0.1>< fLEDWidth+0.01, fLEDHeight+0.01, fLEDDepth>}
      }
      
  #local oLED =
    object {
      box{< 0, 0, 0>< fLEDWidth, fLEDHeight, fLEDDepth>}
      }
      
  //*************************************************************************************************************/
  //* Define Front Control Panel Box & Arrow Lines                                                              */
  //*************************************************************************************************************/ 
  #local fBoxWidth   = (fClearXOffset+fButtonWidth+0.125) - (fEntryXOffset-0.125);
  #local fBoxHeight  = (fEntryTextYOffset+fEntryTextHeight+0.250) - (fEntryYOffset-0.250);
  #local fBoxXOffset = fEntryXOffset-0.125;
  #local fBoxYOffset = fEntryYOffset-0.250; 
  #local oBox =
    object {
      union {
        box {< 0,0, 0.1>< fBoxWidth ,fLineWidth           , 0>}
        box {< 0,0, 0.1>< fLineWidth,fBoxHeight, 0>}
        box {< 0,fBoxHeight-fLineWidth, 0.1>< fBoxWidth,fBoxHeight, 0>}
        box {< fBoxWidth-fLineWidth,0, 0.1>< fBoxWidth,fBoxHeight, 0>} 
        box {< fBoxWidth,(fBoxHeight-fLineWidth)/2,0.1><fBoxWidth+0.250,(fBoxHeight+fLineWidth)/2,0>}
        box {< fBoxWidth+0.250-fLineWidth,(fBoxHeight-fLineWidth)/2,0.1><fBoxWidth+0.250,(fStatusYOffset-fBoxYOffset)+(fStatusHeight/4+fLineWidth/2),0>}
        box {< (fStatusXOffset-fBoxXOffset)+fStatusWidth+0.250,(fStatusYOffset-fBoxYOffset)+fStatusHeight/4-fLineWidth/2,0.1><fBoxWidth+0.250,(fStatusYOffset-fBoxYOffset)+fStatusHeight/4+fLineWidth/2,0>}
        prism{ 
          0, -0.1, 4, < 0, 0>, < 0.250, 0.0625>, < 0.250,-0.0625>, < 0, 0> 
          rotate -90*x
          translate <(fStatusXOffset-fBoxXOffset)+fStatusWidth,(fStatusYOffset-fBoxYOffset)+fStatusHeight/4, 0>
          }
        }
      pigment{White}
      }
      
   #local oLine =
     object {        
       union {
         box{<0,(fButtonHeight-fLineWidth)/2,0.1><-0.500,(fButtonHeight+fLineWidth)/2,0>}
         box{<-0.500,(fButtonHeight-fLineWidth)/2,0.1><-0.500+fLineWidth,(fStatusYOffset-fAdvanceYOffset)+fStatusHeight*0.75,0>}
         box{<-0.500,(fStatusYOffset-fAdvanceYOffset)+fStatusHeight*0.75-fLineWidth/2,0.1><(fStatusXOffset-fAdvanceXOffset)-0.250,(fStatusYOffset-fAdvanceYOffset)+fStatusHeight*0.75+fLineWidth/2,0>}
         prism{ 
           0, -0.1, 4, < 0, 0>, <-0.250, 0.0625>, <-0.250,-0.0625>, < 0, 0> 
           rotate -90*x
           translate <(fStatusXOffset-fAdvanceXOffset),(fStatusYOffset-fAdvanceYOffset)+fStatusHeight*0.75, 0>
           }
         }
       pigment{White}
       }   
      
  //*************************************************************************************************************/
  //* Define Front Control Panel                                                                                */
  //*************************************************************************************************************/
  #local oControlPanel = 
    object {
      union {
        box{< 0, 0, -0.001>< fControlWidth, fControlHeight, 0> pigment{Black}}
        difference {
          box{< 0, 0, -0.002>< fControlWidth, fControlHeight, 0>}
          union {
            object {oStatusHole translate <fStatusXOffset , fStatusYOffset , 0>}
            object {oLEDHole    translate <fPowerXOffset  , fPowerYOffset  , 0>}
            object {oLEDHole    translate <fSystemXOffset , fSystemYOffset , 0>}
            object {oButtonHole translate <fAdvanceXOffset, fAdvanceYOffset, 0>}
            object {oButtonHole translate <fEntryXOffset  , fEntryYOffset  , 0>}
            object {oButtonHole translate <fDetailXOffset , fDetailYOffset , 0>}
            object {oButtonHole translate <fClearXOffset  , fClearYOffset  , 0>}
            object {oButtonHole translate <fIMLXOffset    , fIMLYOffset    , 0>}
            }
          }
        object {oStatusText  translate <fStatusTextXOffset , fStatusTextYOffset ,-0.003                       >}
        object {oStatus      translate <fStatusXOffset     , fStatusYOffset     ,-0.003                       >}
        object {oPowerText   translate <fPowerTextXOffset  , fPowerTextYOffset  ,-0.003                       >}
        object {oLED         translate <fPowerXOffset      , fPowerYOffset      ,-0.003                       > pigment{Green*1.1} finish{ambient Green}}   
        object {oSystemText  translate <fSystemTextXOffset , fSystemTextYOffset ,-0.003                       >}
        object {oErrorText   translate <fErrorTextXOffset  , fErrorTextYOffset  ,-0.003                       >}
        object {oLED         translate <fSystemXOffset     , fSystemYOffset     ,-0.003                       > pigment{Red*0.1}}   
        object {oAdvanceText translate <fAdvanceTextXOffset, fAdvanceTextYOffset,-0.003                       >}
        object {oButton      translate <fAdvanceXOffset    , fAdvanceYOffset    ,-(fButtonDepth-fButtonRadius)>}   
        object {oEntryText   translate <fEntryTextXOffset  , fEntryTextYOffset  ,-0.003                       >}
        object {oButton      translate <fEntryXOffset      , fEntryYOffset      ,-(fButtonDepth-fButtonRadius)>}   
        object {oDetailText  translate <fDetailTextXOffset , fDetailTextYOffset ,-0.003                       >}
        object {oButton      translate <fDetailXOffset     , fDetailYOffset     ,-(fButtonDepth-fButtonRadius)>}   
        object {oClearText   translate <fClearTextXOffset  , fClearTextYOffset  ,-0.003                       >}
        object {oButton      translate <fClearXOffset      , fClearYOffset      ,-(fButtonDepth-fButtonRadius)>}   
        object {oIMLText     translate <fIMLTextXOffset    , fIMLTextYOffset    ,-0.003                       >}
        object {oButton      translate <fIMLXOffset        , fIMLYOffset        ,-(fButtonDepth-fButtonRadius)>}   
        object {oLine        translate <fAdvanceXOffset    , fAdvanceYOffset    ,-0.003                       >}
        object {oBox         translate <fBoxXOffset        , fBoxYOffset        ,-0.003                       >}
        }
      texture{vTexture2}
      }
      
  //*************************************************************************************************************/
  //* Define Front Logo                                                                                         */
  //*************************************************************************************************************/
  #local oLogoHole =
    object {
      union {
        cylinder{<0,0,-0.1><0,0,fLogoDepth>,fLogoHeight*0.5+0.02           translate <fLogoHeight*0.5,fLogoHeight*0.5,0>}
        box     {<-0.02,-0.02,-0.1><fLogoWidth-fLogoHeight+0.02,fLogoHeight+0.02,fLogoDepth> translate <fLogoHeight*0.5, 0, 0>            }
        cylinder{<0,0,-0.1><0,0,fLogoDepth>,fLogoHeight*0.5+0.02           translate <fLogoWidth-fLogoHeight*0.5,fLogoHeight*0.5,0>}
        }
      }
  #local o9032Text =    
    object {
      text { ttf "ariblk.ttf" "9032" 0.125, <0,0,0>}
      scale 0.25
      pigment{White}
      }
      
  #local oLogo =
    object {
      union {
        cylinder{<0,0,0><0,0,fLogoDepth>,fLogoHeight*0.5                translate <fLogoHeight*0.5,fLogoHeight*0.5,0>}
        box     {<0,0,0><fLogoWidth-fLogoHeight,fLogoHeight,fLogoDepth> translate <fLogoHeight*0.5, 0, 0>            }
        cylinder{<0,0,0><0,0,fLogoDepth>,fLogoHeight*0.5                translate <fLogoWidth-fLogoHeight*0.5,fLogoHeight*0.5,0>}
        object  { IBMLogo(fIBMWidth,fIBMHeight,fIBMDepth) rotate fIBMAngle*z translate <fIBMXOffset,fIBMYOffset,-fIBMDepth> pigment{White}}
        object  { o9032Text rotate fIBMAngle*z translate <f9032XOffset,f9032YOffset,-fIBMDepth>}
        }
//      translate -0.001*z  
      pigment{Black}
      }
      
  //*************************************************************************************************************/
  //* Define Front Panel Latch (Key Hole)                                                                       */
  //*************************************************************************************************************/
  #local vKeyHole      = array[6];
  #local vKeyHole[0]   = < 0, 0, fKeyHoleRadius>;
  #local vKeyHole[1]   = vrotate(vKeyHole[0], 60*y);
  #local vKeyHole[2]   = vrotate(vKeyHole[0],120*y);
  #local vKeyHole[3]   = vrotate(vKeyHole[0],180*y);
  #local vKeyHole[4]   = vrotate(vKeyHole[0],240*y);
  #local vKeyHole[5]   = vrotate(vKeyHole[0],300*y); 
  #local oKeyHole =
    object {
      prism {
        -0.1  fKeyHoleDepth/2,
        7,
        <vKeyHole[0].x, vKeyHole[0].z>,
        <vKeyHole[1].x, vKeyHole[1].z>,
        <vKeyHole[2].x, vKeyHole[2].z>,
        <vKeyHole[3].x, vKeyHole[3].z>,
        <vKeyHole[4].x, vKeyHole[4].z>,
        <vKeyHole[5].x, vKeyHole[5].z>,
        <vKeyHole[0].x, vKeyHole[0].z> 
        }
      rotate 90*x
      }  
  //*************************************************************************************************************/
  //* Define Front Panel Latch                                                                                  */
  //*************************************************************************************************************/
  #local oLatch =
    object {
      union {
        difference {
          Round_Cylinder(<0,0,-fLatchDepth>,<0,0,fLatchDepth>,fLatchRadius,fLatchCorner,true)
          cylinder{<0,0,-(fLatchDepth+0.1)><0,0,fLatchDepth-0.001>,fLatchRadius-fLatchBorder pigment{Black}}
          }
        difference { 
          cylinder{<0,0,-fLatchDepth><0,0,fLatchDepth>,fLatchRadius-fLatchBorder-0.010}
          object { oKeyHole }
          }
        }
      texture {vTexture2} 
      }
  //*************************************************************************************************************/
  //* Define Front Panel Vent Strip                                                                             */
  //*************************************************************************************************************/
  #local fVentStripHeight = fVentHeight/nVentStrips;
  #local oVentStrip =
    object {
      union {
        box{<0,0,-fVentThickness/2>< fVentWidth, fVentStripHeight/3,fVentThickness/2>}
        cylinder{<0,fVentStripHeight/3,0><fVentWidth,fVentStripHeight/3,0>,fVentThickness/2}
        box{<0,0,-fVentThickness/2>< fVentWidth,fVentStripHeight*2/3,fVentThickness/2> rotate  fVentAngle*x translate fVentStripHeight/3*y}
        }
      translate fVentThickness/2*z
      }
  //*************************************************************************************************************/
  //* Define Front Panel Vent                                                                                   */
  //*************************************************************************************************************/
  #local oVent =
    object {
      union {
        #local n = 0;
        #while ( n < nVentStrips)
          object {oVentStrip translate n*fVentStripHeight*y}
          #local n = n + 1;
        #end
        }
      }
  //*************************************************************************************************************/
  //* Define Front Panel                                                                                         */
  //*************************************************************************************************************/
  #local oFrontPanel =
    object {
      union {
        difference {
          object {Round_Box(< 0, 0, 0>,< fFrontWidth, fFrontHeight, fFrontDepth>, fRadius, true)}
          object {box{<0,0,-0.1><fSwitchWidth,fSwitchHeight,fSwitchDepth+.1>} translate <fSwitchXOffset,fSwitchYOffset,0>}
          object {box{<0,0,-0.1><fControlWidth,fControlHeight,fControlDepth+.1>} translate <fControlXOffset,fControlYOffset,0>}
          object {oLogoHole translate <fLogoXOffset, fLogoYOffset,0>}
          object {box{<0,0,-0.1><fVentWidth,fVentHeight,fVentDepth+.1>} translate <fVent1XOffset,fVent1YOffset,0>}
          object {box{<0,0,-0.1><fVentWidth,fVentHeight,fVentDepth+.1>} translate <fVent2XOffset,fVent2YOffset,0>}
          object {box{<0,0,-0.1><fVentWidth,fVentHeight,fVentDepth+.1>} translate <fVent3XOffset,fVent3YOffset,0>}
          }                                             
        object {
          union {  
            object {RoundBoxHole(fSwitchWidth,fSwitchHeight,fSwitchDepth,fRadius)}
            object {oSwitchPanel translate fSwitchDepth*z}
            }
          translate <fSwitchXOffset,fSwitchYOffset,0>
          }
        object {
          union {  
            object {RoundBoxHole(fControlWidth,fControlHeight,fControlDepth,fRadius)}
            object {oControlPanel translate fControlDepth*z}
            }
          translate <fControlXOffset,fControlYOffset,0>
          }
        object {oLogo  translate <fLogoXOffset, fLogoYOffset,0>}
        object {oLatch translate <fLatch1XOffset, fLatch1YOffset, -fLatchDepth>}
        object {oLatch translate <fLatch2XOffset, fLatch2YOffset, -fLatchDepth>}
        object {oVent  translate <fVent1XOffset,fVent1YOffset,0>}
        object {oVent  translate <fVent2XOffset,fVent2YOffset,0>}
        object {oVent  translate <fVent3XOffset,fVent3YOffset,0>}
        }
      }
  
  #local oIBMPS2 =
    object {                                     
      union {                                    
        object {                                 
          oIBMKeyboard                           
          }                                      
        object {                                 
          IBMPS2(rgb <0.85,0.85,0.65>)           
          translate 0.75*z                       
          }                                      
        object {                                 
          PCMonitor("IBM9032")              
          translate 0.75*z                       
          translate 4.5/12*y                     
          }                                      
        }                                        
      texture {                                  
        pigment{rgb <0.85,0.85,0.65>}            
        normal { bumps 0.04 scale 0.0005 }       
        finish { phong .5 }                      
        }                                        
      }
  
//          #local fBookShelfOffset = 0.0;
//        #local fBookWidth       = 1.0;
  #local oIBMBook =
    object {
      IBMBook(1.25,"Maintenance Information for","the IBM 9032 Model 3 Director","SY27-3601-04")
      rotate -90*x 
      rotate -30*y
      translate <0.75,0,0.75>
      }
                                              
  //*************************************************************************************************************/
  //* Define Complete 9032                                                                                      */
  //*************************************************************************************************************/
  #local oIBM9032 =
    object {       
      union {
        object {oFrame       translate < fSideDepth, 0, fFrontDepth>                                              }
        object {oRearPanel   translate < fSideDepth+fGap, 0, fDepth-fRearDepth>                 texture{vTexture1}}
        object {oSidePanel                                                                      texture{vTexture2}}
        object {oSidePanel   translate < fWidth-fSideDepth, 0, 0>                               texture{vTexture2}}
        object {oFrontPanel  translate < fSideDepth+fGap, 0, 0>                                 texture{vTexture1}}
        object {oTopPanel    translate < fSideDepth+fGap, fHeight-fTopHeight, fFrontDepth+fGap> texture{vTexture1}}
        #if (bPC)
          object {oIBMPS2    scale 12 translate < 7/12,fHeight,2/12>}
        #else
          object {oIBMBook   scale 12 translate < 2/12,fHeight,3/12>}
        #end
        }
      scale 1/12
      texture{vTexture0}
      }
  //*************************************************************************************************************/
  //* Define Complete 9032                                                                                      */
  //*************************************************************************************************************/
  oIBM9032     

#end
//***************************************************************************************************************/
  