//***************************************************************************************************************/
//* Persistence of Vision Ray Tracer Scene Description File                                                     */
//* File: 9037.inc                                                                                              */
//* Vers: 3.6                                                                                                   */
//* Desc: 9037 Sysplex Timer                                                                                    */
//* Date: 11/23/2004                                                                                            */
//* Auth: D. E. LeMasters                                                                                       */
//***************************************************************************************************************/
#version 3.6;                                                           //*                                     */
#include "AlphaMatrix.inc"                                                                        //*                                     */
//***************************************************************************************************************/
//* 9037 Macro Definition                                                                                       */
//***************************************************************************************************************/
#macro IBM9037(sStatusLine1,sStatusLine2)
  //*************************************************************************************************************/
  //* Basic External Dimensions                                                                                 */
  //*************************************************************************************************************/
  #local vTexture0        = pigment{Black};                             //* Base Texture                        */
  #local vTexture2        = texture{pigment{White*0.05} 
                            normal { bumps 0.04 scale 0.0005 }
                            finish { phong 0.5 }};                        //* Base Texture                        */
  #local vTexture1        = texture{pigment{White*0.50} 
                            normal { bumps 0.04 scale 0.0005 }
                            finish { phong 0.5 }};                        //* Base Texture                        */
  #local fWidth           = 18.00;                                      //* Overall Width                       */
  #local fHeight          =  8.75;                                      //* Overall Height                      */
  #local fDepth           = 18.00;                                      //* Overall Depth                       */
  #local fRadius          =  0.10;                                      //* Corner Radius                       */
  #local fGap             =  0.25;                                      //* Gap between panels                  */
  //*************************************************************************************************************/
  //* Leg Definitions                                                                                           */
  //*************************************************************************************************************/
  #local fLegHeight     = 1.25;
  #local fLegRadius     = 0.75;
  //*************************************************************************************************************/
  //* Front Panel Definitions                                                                                   */
  //*************************************************************************************************************/
  #local fFrontWidth      = fWidth;
  #local fFrontHeight     = fHeight;
  #local fFrontDepth      = 0.50;
  #local fFrontRadius     = fRadius;
  #local fLEDWidth        = 0.375;
  #local fLEDHeight       = 0.125;
  #local fLEDDepth        = 0.125;
  //*************************************************************************************************************/
  //* Front Panel Definitions (Logo)                                                                            */
  //*************************************************************************************************************/
  #local fLogoWidth        =  1.500;
  #local fLogoHeight       =  1.000;
  #local fLogoDepth        =  0.0625;
  #local fLogoXOffset      =  1.75;
  #local fLogoYOffset      =  6.75;
  #local fIBMWidth         =  0.875;
  #local fIBMHeight        =  0.375;
  #local fIBMDepth         = 1/16;
  #local fIBMAngle         = 30;
  #local fIBMXOffset       =  0.350;
  #local fIBMYOffset       =  0.150;
  #local f9037XOffset      =  1.000;
  #local f9037YOffset      =  0.250;
  //*************************************************************************************************************/
  //* Front Panel Definitions (Latch)                                                                           */
  //*************************************************************************************************************/
  #local fLatchDepth       =  0.0625;
  #local fLatchRadius      =  0.375;
  #local fLatchCorner      =  0.050;
  #local fLatchBorder      =  0.125;
  #local fLatch1XOffset    = fFrontWidth/2;
  #local fLatch1YOffset    = fFrontHeight-1.25;
  #local fKeyHoleRadius    = 1/8;
  #local fKeyHoleDepth     = 1/8;
  //*************************************************************************************************************/
  //* Front Panel Definitions (Control Panel)                                                                   */
  //*************************************************************************************************************/
  #local fControlWidth     =  3.500;
  #local fControlHeight    =  3.500;
  #local fControlDepth     =  0.500;
  #local fControlXOffset   = 13.250;
  #local fControlYOffset   =  4.000;
  #local fLineWidth        =   1/32;
  #local fPowerXOffset     = 1.200;
  #local fPowerYOffset     = 0.650;
  #local fSystemXOffset    = 2.000;
  #local fSystemYOffset    = 0.650;
  #local fStatusWidth      = 2.500;
  #local fStatusHeight     = 0.375;
  #local fStatusDepth      = 0.03125;
  #local fStatusXOffset    = 0.400;
  #local fStatusYOffset    = 2.250;
  #local fButtonWidth      = 0.375;
  #local fButtonHeight     = 0.125;
  #local fButtonDepth      = 0.125;
  #local fButtonRadius     = 0.0125;
  #local fAdvanceXOffset   = 0.350;
  #local fEntryXOffset     = 1.200;
  #local fDetailXOffset    = 2.000;
  #local fClearXOffset     = 2.600;
  #local fIMLXOffset       = 0.350;
  #local fAdvanceYOffset   = 1.500;
  #local fEntryYOffset     = 1.500;
  #local fDetailYOffset    = 1.500;
  #local fClearYOffset     = 1.500;
  #local fIMLYOffset       = 0.6500;
  #local fToggleRadius     = 0.3750;
  #local fToggleWidth      = 0.3750;
  #local fToggleCorner     = 0.050;
  #local fToggleXOffset    = 2.750;
  #local fToggleYOffset    = 0.375;
  //*************************************************************************************************************/
  //* Front Panel Definitions  (Vents)                                                                          */
  //*************************************************************************************************************/
  #local fVentWidth       =  5.00;
  #local fVentHeight      =  4.50;
  #local fVentDepth        =  1.00;
  #local fVentThickness    =  1/32;
  #local nVentStrips       =  6;
  #local fVentAngle        =  30;
  #local fVent1XOffset     =  1.50;
  #local fVent1YOffset     =  1.50;
  #local fVent2XOffset     =  6.75;
  #local fVent2YOffset     =  1.50;
  //*************************************************************************************************************/
  //* Rear Panel Definitions                                                                                    */
  //*************************************************************************************************************/
  #local fRearWidth       = fWidth;
  #local fRearHeight      = fHeight;
  #local fRearDepth       = fDepth-fGap-fFrontDepth;
  #local fRearRadius      = fRadius;
  //*************************************************************************************************************/
  //* Define Front Logo                                                                                         */
  //*************************************************************************************************************/
  #local oLogoHole =
    object {
      union {
        cylinder{<0,0,-0.1><0,0,fLogoDepth>,fLogoHeight*0.5+0.02           translate <fLogoHeight*0.5,fLogoHeight*0.5,0>}
        box     {<-0.02,-0.02,-0.1><fLogoWidth-fLogoHeight+0.02,fLogoHeight+0.02,fLogoDepth> translate <fLogoHeight*0.5, 0, 0>            }
        cylinder{<0,0,-0.1><0,0,fLogoDepth>,fLogoHeight*0.5+0.02           translate <fLogoWidth-fLogoHeight*0.5,fLogoHeight*0.5,0>}
        }
      }
  #local o9037Text =
    object {
      text { ttf "ariblk.ttf" "9037" 0.125, <0,0,0>}
      scale 3/16
      pigment{White}
      }
 
  #local oLogo =
    object {
      union {
        cylinder{<0,0,0><0,0,fLogoDepth>,fLogoHeight*0.5                translate <fLogoHeight*0.5,fLogoHeight*0.5,0>}
        box     {<0,0,0><fLogoWidth-fLogoHeight,fLogoHeight,fLogoDepth> translate <fLogoHeight*0.5, 0, 0>            }
        cylinder{<0,0,0><0,0,fLogoDepth>,fLogoHeight*0.5                translate <fLogoWidth-fLogoHeight*0.5,fLogoHeight*0.5,0>}
        object  { IBMLogo(fIBMWidth,fIBMHeight,fIBMDepth) rotate fIBMAngle*z translate <fIBMXOffset,fIBMYOffset,-fIBMDepth> pigment{White}}
        object  { o9037Text rotate fIBMAngle*z translate <f9037XOffset,f9037YOffset,-fIBMDepth>}
        }
//      translate -0.001*z
      pigment{Black}
      }
 
  //*************************************************************************************************************/
  //* Define Front Control Status Display                                                                       */
  //*************************************************************************************************************/
  #local oStatusHole =
    object {
      box{< -0.010, -0.010, -0.1>,< fStatusWidth+0.010, fStatusHeight+0.010, 3*fStatusDepth>}
      }
 
  #local oStatus =
    object {
      union {
        object {
          union {
            object {
              box{< 0, 0, 0>,< fStatusWidth, fStatusHeight, fStatusDepth>}
              pigment{color < 0.7, 1.0, 0.7>}
              }
            #local is = 0;
            #while ( is < strlen(sStatusLine1))
              object {
                AlphaMatrix(substr(sStatusLine1,is+1,1))
                scale <fStatusWidth/16,fStatusHeight/2,1>
                translate < is*fStatusWidth/16, fStatusHeight/2, -0.001>
                }
              #local is = is + 1;
            #end    
            #local is = 0;
            #while ( is < strlen(sStatusLine2))
              object {
                AlphaMatrix(substr(sStatusLine2,is+1,1))
                scale <fStatusWidth/16,fStatusHeight/2,1>
                translate < is*fStatusWidth/16, 0, -0.001>
                }
              #local is = is + 1;
            #end    
            }
          }
        }
      }
 
  #local oStatusText =
    object {
      text { ttf "crystal.ttf" "Status" 0.125, <0,0,0>}
      scale 0.25
      pigment{White}
      }
 
  #local vStatusTextMin     = min_extent(oStatusText);
  #local vStatusTextMax     = max_extent(oStatusText);
  #local fStatusTextWidth   = vStatusTextMax.x - vStatusTextMin.x;
  #local fStatusTextHeight  = vStatusTextMax.y - vStatusTextMin.y;
  #local fStatusTextXOffset = fStatusXOffset+(fStatusWidth-fStatusTextWidth)/2;
  #local fStatusTextYOffset = fStatusYOffset+fStatusHeight+0.125;
 
  //*************************************************************************************************************/
  //* Define Front Control Panel LED Lights                                                                     */
  //*************************************************************************************************************/
  #local oLEDHole =
    object {
      box{< -0.01, -0.01, -0.1>< fLEDWidth+0.01, fLEDHeight+0.01, fLEDDepth>}
      }
 
  #local oLED =
    object {
      box{< 0, 0, 0>< fLEDWidth, fLEDHeight, fLEDDepth>}
      }
 
  #local oPowerText =
    object {
      text { ttf "crystal.ttf" "Power" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
  #local vPowerTextMin     = min_extent(oPowerText);
  #local vPowerTextMax     = max_extent(oPowerText);
  #local fPowerTextWidth   = vPowerTextMax.x - vPowerTextMin.x;
  #local fPowerTextHeight  = vPowerTextMax.y - vPowerTextMin.y;
  #local fPowerTextXOffset = fPowerXOffset+(fLEDWidth-fPowerTextWidth)/2;
  #local fPowerTextYOffset = fPowerYOffset+fLEDHeight+0.125;
 
  #local oErrorText =
    object {
      text { ttf "crystal.ttf" "Error" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
  #local vErrorTextMin     = min_extent(oErrorText);
  #local vErrorTextMax     = max_extent(oErrorText);
  #local fErrorTextWidth   = vErrorTextMax.x - vErrorTextMin.x;
  #local fErrorTextHeight  = vErrorTextMax.y - vErrorTextMin.y;
  #local fErrorTextXOffset = fSystemXOffset+(fLEDWidth-fErrorTextWidth)/2;
  #local fErrorTextYOffset = fSystemYOffset+fLEDHeight+0.125;
 
  #local oSystemText =
    object {
      text { ttf "crystal.ttf" "System" 0.125, <0,0,0>}
      scale 0.15
      pigment{White}
      }
  #local vSystemTextMin     = min_extent(oSystemText);
  #local vSystemTextMax     = max_extent(oSystemText);
  #local fSystemTextWidth   = vSystemTextMax.x - vSystemTextMin.x;
  #local fSystemTextHeight  = vSystemTextMax.y - vSystemTextMin.y;
  #local fSystemTextXOffset = fSystemXOffset+(fLEDWidth-fSystemTextWidth)/2;
  #local fSystemTextYOffset = fErrorTextYOffset+fErrorTextHeight+0.0625;
 
  //*************************************************************************************************************/
  //* Define Front Control Panel Buttons                                                                        */
  //*************************************************************************************************************/
  #local oButtonHole =
    object {
      box{< -0.020, -0.020, -0.1>,< fButtonWidth+0.020, fButtonHeight+0.020, fButtonDepth>}
      }
 
  #local oButton =
    object {
      Round_Box(< 0, 0, 0>,< fButtonWidth, fButtonHeight, fButtonDepth>, fButtonRadius, true)
      pigment{White}
      }
 
  #local oAdvanceText =
    object {
      text { ttf "crystal.ttf" "Advance" 0.125, <0,0,0>}
      scale 0.150
      pigment{White}
      }
  #local vAdvanceTextMin     = min_extent(oAdvanceText);
  #local vAdvanceTextMax     = max_extent(oAdvanceText);
  #local fAdvanceTextWidth   = vAdvanceTextMax.x - vAdvanceTextMin.x;
  #local fAdvanceTextHeight  = vAdvanceTextMax.y - vAdvanceTextMin.y;
  #local fAdvanceTextXOffset = fAdvanceXOffset+(fButtonWidth-fAdvanceTextWidth)/2;
  #local fAdvanceTextYOffset = fAdvanceYOffset+fLEDHeight+0.0625;
 
  #local oEntryText =
    object {
      text { ttf "crystal.ttf" "Entry" 0.125, <0,0,0>}
      scale 0.150
      pigment{White}
      }
  #local vEntryTextMin     = min_extent(oEntryText);
  #local vEntryTextMax     = max_extent(oEntryText);
  #local fEntryTextWidth   = vEntryTextMax.x - vEntryTextMin.x;
  #local fEntryTextHeight  = vEntryTextMax.y - vEntryTextMin.y;
  #local fEntryTextXOffset = fEntryXOffset+(fButtonWidth-fEntryTextWidth)/2;
  #local fEntryTextYOffset = fEntryYOffset+fLEDHeight+0.0625;
 
  #local oDetailText =
    object {
      text { ttf "crystal.ttf" "Detail" 0.125, <0,0,0>}
      scale 0.150
      pigment{White}
      }
  #local vDetailTextMin     = min_extent(oDetailText);
  #local vDetailTextMax     = max_extent(oDetailText);
  #local fDetailTextWidth   = vDetailTextMax.x - vDetailTextMin.x;
  #local fDetailTextHeight  = vDetailTextMax.y - vDetailTextMin.y;
  #local fDetailTextXOffset = fDetailXOffset+(fButtonWidth-fDetailTextWidth)/2;
  #local fDetailTextYOffset = fDetailYOffset+fLEDHeight+0.0625;
 
  #local oClearText =
    object {
      text { ttf "crystal.ttf" "Clear" 0.125, <0,0,0>}
      scale 0.150
      pigment{White}
      }
  #local vClearTextMin     = min_extent(oClearText);
  #local vClearTextMax     = max_extent(oClearText);
  #local fClearTextWidth   = vClearTextMax.x - vClearTextMin.x;
  #local fClearTextHeight  = vClearTextMax.y - vClearTextMin.y;
  #local fClearTextXOffset = fClearXOffset+(fButtonWidth-fClearTextWidth)/2;
  #local fClearTextYOffset = fClearYOffset+fLEDHeight+0.0625;
 
  #local oIMLText =
    object {
      text { ttf "crystal.ttf" "IML" 0.125, <0,0,0>}
      scale 0.150
      pigment{White}
      }
  #local vIMLTextMin     = min_extent(oIMLText);
  #local vIMLTextMax     = max_extent(oIMLText);
  #local fIMLTextWidth   = vIMLTextMax.x - vIMLTextMin.x;
  #local fIMLTextHeight  = vIMLTextMax.y - vIMLTextMin.y;
  #local fIMLTextXOffset = fIMLXOffset+(fButtonWidth-fIMLTextWidth)/2;
  #local fIMLTextYOffset = fIMLYOffset+fLEDHeight+0.125;
 
  //*************************************************************************************************************/
  //* Define Front Control Panel LED Lights                                                                     */
  //*************************************************************************************************************/
  #local oLEDHole =
    object {
      box{< -0.01, -0.01, -0.1>< fLEDWidth+0.01, fLEDHeight+0.01, fLEDDepth>}
      }
 
  #local oLED =
    object {
      box{< 0, 0, 0>< fLEDWidth, fLEDHeight, fLEDDepth>}
      }
 
  //*************************************************************************************************************/
  //* Define Front Control Panel Box & Arrow Lines                                                              */
  //*************************************************************************************************************/
  #local fBoxWidth   = (fClearXOffset+fButtonWidth+0.125) - (fEntryXOffset-0.125);
  #local fBoxHeight  = (fEntryTextYOffset+fEntryTextHeight+0.125) - (fEntryYOffset-0.125);
  #local fBoxXOffset = fEntryXOffset-0.125;
  #local fBoxYOffset = fEntryYOffset-0.125;
  #local oBox =
    object {
      union {
        box {< 0,0, 0.1>< fBoxWidth ,fLineWidth           , 0>}
        box {< 0,0, 0.1>< fLineWidth,fBoxHeight, 0>}
        box {< 0,fBoxHeight-fLineWidth, 0.1>< fBoxWidth,fBoxHeight, 0>}
        box {< fBoxWidth-fLineWidth,0, 0.1>< fBoxWidth,fBoxHeight, 0>}
        box {< fBoxWidth,(fBoxHeight-fLineWidth)/2,0.1><fBoxWidth+0.125,(fBoxHeight+fLineWidth)/2,0>}
        box {< fBoxWidth+0.125-fLineWidth,(fBoxHeight-fLineWidth)/2,0.1><fBoxWidth+0.125,(fStatusYOffset-fBoxYOffset)+(fStatusHeight/4+fLineWidth/2),0>}
        box {< (fStatusXOffset-fBoxXOffset)+fStatusWidth+0.125,(fStatusYOffset-fBoxYOffset)+fStatusHeight/4-fLineWidth/2,0.1><fBoxWidth+0.125,(fStatusYOffset-fBoxYOffset)+fStatusHeight/4+fLineWidth/2,0>}
        prism{
          0, -0.1, 4, < 0, 0>, < 0.125, 0.0625>, < 0.125,-0.0625>, < 0, 0>
          rotate -90*x
          translate <(fStatusXOffset-fBoxXOffset)+fStatusWidth,(fStatusYOffset-fBoxYOffset)+fStatusHeight/4, 0>
          }
        }
      pigment{White}
      }
 
   #local oLine =
     object {
       union {
         box{<0,(fButtonHeight-fLineWidth)/2,0.1><-0.125,(fButtonHeight+fLineWidth)/2,0>}
         box{<-0.125,(fButtonHeight-fLineWidth)/2,0.1><-0.125+fLineWidth,(fStatusYOffset-fAdvanceYOffset)+fStatusHeight*0.75,0>}
         box{<-0.125,(fStatusYOffset-fAdvanceYOffset)+fStatusHeight*0.75-fLineWidth/2,0.1><(fStatusXOffset-fAdvanceXOffset)-0.125,(fStatusYOffset-fAdvanceYOffset)+fStatusHeight*0.75+fLineWidth/2,0>}
         prism{
           0, -0.1, 4, < 0, 0>, <-0.125, 0.0625>, <-0.125,-0.0625>, < 0, 0>
           rotate -90*x
           translate <(fStatusXOffset-fAdvanceXOffset),(fStatusYOffset-fAdvanceYOffset)+fStatusHeight*0.75, 0>
           }
         }
       pigment{White}
       }
 
  //*************************************************************************************************************/
  //* Define FrontPanel Toggle Switch                                                                           */
  //*************************************************************************************************************/
  #local oHalfToggle =
    object {
      union {
        intersection {
          object { Round_Cylinder(< 0, 0, 0>,< fToggleWidth, 0, 0>, fToggleRadius, fToggleCorner, true) }
          box{< -0.01, -(fToggleRadius+0.01), 0>< fToggleWidth+0.01, +(fToggleRadius+0.01), (fToggleRadius+0.01)>}
          }
        box{ < fToggleCorner,-(fToggleRadius-fToggleCorner),0>< fToggleWidth-fToggleCorner, (fToggleRadius-fToggleCorner), -fToggleCorner>}
        cylinder{< fToggleCorner, -(fToggleRadius-fToggleCorner), 0>< fToggleCorner, +(fToggleRadius-fToggleCorner), 0>,fToggleCorner}
        cylinder{< fToggleWidth-fToggleCorner, -(fToggleRadius-fToggleCorner), 0>< fToggleWidth-fToggleCorner, +(fToggleRadius-fToggleCorner), 0>,fToggleCorner}
        cylinder{< fToggleCorner,-(fToggleRadius-fToggleCorner),0><fToggleWidth-fToggleCorner,-(fToggleRadius-fToggleCorner),0>,fToggleCorner}
        cylinder{< fToggleCorner, (fToggleRadius-fToggleCorner),0><fToggleWidth-fToggleCorner, (fToggleRadius-fToggleCorner),0>,fToggleCorner}
        sphere{<fToggleCorner,-(fToggleRadius-fToggleCorner), 0>,fToggleCorner}
        sphere{<fToggleWidth-fToggleCorner,-(fToggleRadius-fToggleCorner), 0>,fToggleCorner}
        sphere{<fToggleCorner, (fToggleRadius-fToggleCorner), 0>,fToggleCorner}
        sphere{<fToggleWidth-fToggleCorner, (fToggleRadius-fToggleCorner), 0>,fToggleCorner}
        }
      }
 
  #local oToggleTextI =
    object {
      text { ttf "ariblk.ttf" "I" 0.125, <0,0,0>}
      scale 0.125
      pigment{Black}
      }
  #local vToggleTextIMin = min_extent(oToggleTextI);
  #local vToggleTextIMax = max_extent(oToggleTextI);
  #local fToggleTextIWidth  = vToggleTextIMax.x - vToggleTextIMin.x;
  #local fToggleTextIHeight = vToggleTextIMax.y - vToggleTextIMin.y;
 
  #local oToggleTextO =
    object {
      text { ttf "ariblk.ttf" "O" 0.125, <0,0,0>}
      scale 0.125
      pigment{Black}
      }
  #local vToggleTextOMin = min_extent(oToggleTextO);
  #local vToggleTextOMax = max_extent(oToggleTextO);
  #local fToggleTextOWidth  = vToggleTextOMax.x - vToggleTextOMin.x;
  #local fToggleTextOHeight = vToggleTextOMax.y - vToggleTextOMin.y;
 
  #local oToggle =
    object {
      union {
        object {
          union {
            object { oHalfToggle }
            object { oToggleTextI translate <(fToggleWidth-fToggleTextIWidth)/2, (fToggleRadius-fToggleTextIHeight)/2,-(fToggleCorner+0.001)> }
            }
          rotate -15*x
          }
        object {
          union {
            object {oHalfToggle}
            object { oToggleTextO translate <(fToggleWidth-fToggleTextOWidth)/2,-fToggleRadius+(fToggleRadius-fToggleTextOHeight)/2,-(fToggleCorner+0.001)> }
            }
          rotate  15*x
          }
        }
      rotate  15*x
      translate fToggleRadius*y
      pigment{White}
      }
 
  //*************************************************************************************************************/
  //* Define Front Control Panel                                                                                */
  //*************************************************************************************************************/
  #local oControlPanel =
    object {
      union {
        difference {
          box{< 0, 0, -0.001>< fControlWidth, fControlHeight, 0> pigment{Black}}
          object {oStatusHole translate <fStatusXOffset , fStatusYOffset , 0>}
          }
        difference {
          box{< 0, 0, -0.002>< fControlWidth, fControlHeight, 0>}
          union {
            object {oStatusHole translate <fStatusXOffset , fStatusYOffset , 0>}
            object {oLEDHole    translate <fPowerXOffset  , fPowerYOffset  , 0>}
            object {oLEDHole    translate <fSystemXOffset , fSystemYOffset , 0>}
            object {oButtonHole translate <fAdvanceXOffset, fAdvanceYOffset, 0>}
            object {oButtonHole translate <fEntryXOffset  , fEntryYOffset  , 0>}
            object {oButtonHole translate <fDetailXOffset , fDetailYOffset , 0>}
            object {oButtonHole translate <fClearXOffset  , fClearYOffset  , 0>}
            object {oButtonHole translate <fIMLXOffset    , fIMLYOffset    , 0>}
            object {box{< 0, 0, -0.003>< fToggleWidth, 2*fToggleRadius, fControlDepth+0.1>} translate <fToggleXOffset, fToggleYOffset,0>}
            }
          }
        object {oStatusText  translate <fStatusTextXOffset , fStatusTextYOffset ,-0.003                       >}
        object {oStatus      translate <fStatusXOffset     , fStatusYOffset     ,-0.003                       >}
        object {oPowerText   translate <fPowerTextXOffset  , fPowerTextYOffset  ,-0.003                       >}
        object {oLED         translate <fPowerXOffset      , fPowerYOffset      ,-0.003                       > pigment{Green*1.1} finish{ambient Green}}
        object {oSystemText  translate <fSystemTextXOffset , fSystemTextYOffset ,-0.003                       >}
        object {oErrorText   translate <fErrorTextXOffset  , fErrorTextYOffset  ,-0.003                       >}
        object {oLED         translate <fSystemXOffset     , fSystemYOffset     ,-0.003                       > pigment{Red*0.1}}
        object {oAdvanceText translate <fAdvanceTextXOffset, fAdvanceTextYOffset,-0.003                       >}
        object {oButton      translate <fAdvanceXOffset    , fAdvanceYOffset    ,-(fButtonDepth-fButtonRadius)>}
        object {oEntryText   translate <fEntryTextXOffset  , fEntryTextYOffset  ,-0.003                       >}
        object {oButton      translate <fEntryXOffset      , fEntryYOffset      ,-(fButtonDepth-fButtonRadius)>}
        object {oDetailText  translate <fDetailTextXOffset , fDetailTextYOffset ,-0.003                       >}
        object {oButton      translate <fDetailXOffset     , fDetailYOffset     ,-(fButtonDepth-fButtonRadius)>}
        object {oClearText   translate <fClearTextXOffset  , fClearTextYOffset  ,-0.003                       >}
        object {oButton      translate <fClearXOffset      , fClearYOffset      ,-(fButtonDepth-fButtonRadius)>}
        object {oIMLText     translate <fIMLTextXOffset    , fIMLTextYOffset    ,-0.003                       >}
        object {oButton      translate <fIMLXOffset        , fIMLYOffset        ,-(fButtonDepth-fButtonRadius)>}
        object {oLine        translate <fAdvanceXOffset    , fAdvanceYOffset    ,-0.003                       >}
        object {oBox         translate <fBoxXOffset        , fBoxYOffset        ,-0.003                       >}
        object {oToggle      translate <fToggleXOffset, fToggleYOffset,0>}
        }
      texture{vTexture2}
      }
 
  //*************************************************************************************************************/
  //* Define Front Panel Latch (Key Hole)                                                                       */
  //*************************************************************************************************************/
  #local vKeyHole      = array[6];
  #local vKeyHole[0]   = < 0, 0, fKeyHoleRadius>;
  #local vKeyHole[1]   = vrotate(vKeyHole[0], 60*y);
  #local vKeyHole[2]   = vrotate(vKeyHole[0],120*y);
  #local vKeyHole[3]   = vrotate(vKeyHole[0],180*y);
  #local vKeyHole[4]   = vrotate(vKeyHole[0],240*y);
  #local vKeyHole[5]   = vrotate(vKeyHole[0],300*y);
  #local oKeyHole =
    object {
      prism {
        -0.1  fKeyHoleDepth/2,
        7,
        <vKeyHole[0].x, vKeyHole[0].z>,
        <vKeyHole[1].x, vKeyHole[1].z>,
        <vKeyHole[2].x, vKeyHole[2].z>,
        <vKeyHole[3].x, vKeyHole[3].z>,
        <vKeyHole[4].x, vKeyHole[4].z>,
        <vKeyHole[5].x, vKeyHole[5].z>,
        <vKeyHole[0].x, vKeyHole[0].z>
        }
      rotate 90*x
      }
  //*************************************************************************************************************/
  //* Define Front Panel Latch                                                                                  */
  //*************************************************************************************************************/
  #local oLatch =
    object {
      union {
        difference {
          Round_Cylinder(<0,0,-fLatchDepth>,<0,0,fLatchDepth>,fLatchRadius,fLatchCorner,true)
          cylinder{<0,0,-(fLatchDepth+0.1)><0,0,fLatchDepth-0.001>,fLatchRadius-fLatchBorder pigment{Black}}
          }
        difference {
          cylinder{<0,0,-fLatchDepth><0,0,fLatchDepth>,fLatchRadius-fLatchBorder-0.010}
          object { oKeyHole }
          }
        }
      texture {vTexture2}
      }
  //*************************************************************************************************************/
  //* Front Panel Definitions                                                                                   */
  //*************************************************************************************************************/
  #local oFront =
    object {
      union {
        difference {
          object {Round_Box(< 0, 0, 0>,< fFrontWidth, fFrontHeight, fFrontDepth>, fRadius, true)}
          object {box{<0,0,-0.1><fControlWidth,fControlHeight,fControlDepth+.1>} translate <fControlXOffset,fControlYOffset,0>}
          object {oLogoHole translate <fLogoXOffset, fLogoYOffset,0>}
          object {box{<0,0,-0.1><fVentWidth,fVentHeight,fVentDepth+.1>} translate <fVent1XOffset,fVent1YOffset,0>}
          object {box{<0,0,-0.1><fVentWidth,fVentHeight,fVentDepth+.1>} translate <fVent2XOffset,fVent2YOffset,0>}
          }
        object {
          union {
            object {RoundBoxHole(fControlWidth,fControlHeight,fControlDepth,fRadius)}
            object {oControlPanel translate fControlDepth*z}
            }
          translate <fControlXOffset,fControlYOffset,0>
          }
        object {oLogo  translate <fLogoXOffset, fLogoYOffset,0>}
        object {oLatch translate <fLatch1XOffset, fLatch1YOffset, -fLatchDepth>}
        object {Vent(fVentWidth,fVentHeight,fVentThickness,nVentStrips) translate <fVent1XOffset,fVent1YOffset,0>}
        object {Vent(fVentWidth,fVentHeight,fVentThickness,nVentStrips) translate <fVent2XOffset,fVent2YOffset,0>}
        }
      texture{vTexture1}
      }
  //*************************************************************************************************************/
  //* Rear Panel Definitions                                                                                    */
  //*************************************************************************************************************/
  #local oRear =
    object {
      Round_Box(<0,0,0>,<fRearWidth,fRearHeight,fRearDepth>,fRearRadius,true)
      texture{vTexture1}
      }
  //*************************************************************************************************************/
  //* Leg Definition                                                                                            */
  //*************************************************************************************************************/
  #local oLeg =
    object {
      Round_Cylinder(<0,0,0>,<0,fLegHeight,0>,fLegRadius,fRadius,true)
      texture{vTexture0}
      }
  //*************************************************************************************************************/
  //* Basic External Dimensions                                                                                 */
  //*************************************************************************************************************/
  #local oIBM9037 =
    object {
      union {
        object {
          union {
            box{<0.5,0.5,0.5><fWidth-0.5,fHeight-0.5,fDepth-0.5> texture{vTexture0}}  //* Frame                       */
            object {oFront}
            object {oRear translate (fFrontDepth+fGap)*z}
            }
          translate fLegHeight*y
          }
        object { oLeg translate < 2       , 0, 2       >}
        object { oLeg translate < fWidth-2, 0, 2       >}
        object { oLeg translate < 2       , 0, fDepth-2>}
        object { oLeg translate < fWidth-2, 0, fDepth-2>}
        }
      texture{vTexture2}
      scale 1/12
      }
  oIBM9037
#end                                                                    //*                                     */
//***************************************************************************************************************/
