#include "PushButton.inc"
#include "IBMLogo.inc"

//***************************************************************************************************************/
//* Persistence of Vision Ray Tracer Scene Description File                                                     */
//* File: IBMPC.pov                                                                                             */
//* Vers: 3.6                                                                                                   */
//* Desc: Data Center Scene                                                                                     */
//* Date: 12/16/2004                                                                                            */
//* Auth: D. E. LeMasters                                                                                       */
//***************************************************************************************************************/
                                                                        //*                                     */
#macro IBMPC()
  #local fWidth           = 7.50;
  #local fHeight          = 15.00;
  #local fDepth           = 14.75;
  #local fRadius          = 0.125;
  #local fThickness       = 0.0625;
  #local tTexture         = pigment{White*0.1}; 
  
  #local fFrontWidth      = fWidth;
  #local fFrontHeight     = fHeight+1.125;
  #local fFrontDepth      = 0.250;
  #local fFrontRadius     = 0.0625;
  #local tFrontTexture    = pigment{White*0.05}
  
  #local fUpperPanelWidth = 6.25;
  #local fUpperPanelHeight = 14.00;
  #local fUpperPanelDepth  = fFrontDepth;
  #local fUpperPanelRadius = fFrontRadius;
  #local fUpperPanelYOffset = 2.125;
  #local fUpperPanelRightWidth = fFrontWidth-fUpperPanelWidth;
  #local fUpperPanelRightHeight = 5.5;
  
  #local fSwitchWidth  = fFrontWidth-fUpperPanelWidth;
  #local fSwitchHeight = 2.500;
  #local fSwitchDepth  = fFrontDepth;
  #local fSwitchXOffset = fWidth-fSwitchWidth;
  #local fSwitchYOffset = 8.25;
  #local tSwitchTexture = pigment{White*0.005}
                                
  #local fBorderWidth       = 3/16;
  #local fBorderLeftHeight  = 2.125;
  #local fBorderRightHeight = 8.375;
  #local fBorderInsetHeight = 4.375;
  #local fLowerPanelDepth   = 0.875;
  #local fLowerPanelHeight = 2.125;
  #local fLowerPanelRadius = fRadius/2;
  #local tLowerPanelTexture  = pigment{White*0.1}; 
  
  #local fLowerPanelYOffset = fLowerPanelHeight+4.5;
  #local fRightPanelWidth   = 0.5;
  #local fRightPanelHeigth  = 4.5;
  
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* Case Definition                                                                                           */
  //*************************************************************************************************************/
  #local oCase =
    object {
      difference {
        object {Round_Box(<0,0,0>,<fWidth,fHeight,fDepth>,fRadius,false)}
        object {Round_Box(<fThickness,fThickness,-fThickness>,<fWidth-fThickness,fHeight-fThickness,1.0-fFrontDepth>,fRadius/2,false)}
        }
      texture{tTexture}
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* Lower Panel Case Border Definition                                                                        */
  //*************************************************************************************************************/
  #local oLowerPanelBorder =
    object {
      union {
        object {                                                        //* Left Outer Border                   */
          Round_Box(<0,0,0>,<fBorderWidth,fLowerPanelHeight,fFrontDepth>,fFrontRadius,false)
          }
        object {                                                        //* Bottom Outer Border                 */
          Round_Box(<0,0,0>,<fWidth,fBorderWidth,fFrontDepth>,fFrontRadius,false)
          }
        object {                                                        //* Right Outer Border                  */
          union {                                                       //* Shear Top to Match Switch           */
            object {
              Round_Box(<0,0,0>,<-fBorderWidth,fBorderRightHeight-1,fFrontDepth>,fFrontRadius,false)
              }
            object {
              Round_Box(<0,fBorderRightHeight-2,0>,<-fBorderWidth,fBorderRightHeight,fFrontDepth>,fFrontRadius,false)
              Shear_Trans(x+y,y,z)
              }
            }
          translate (fWidth)*x
          }
        object {                                                        //* Left Inner Border                   */
          Round_Box(<0,0,0>,<fBorderWidth-fThickness,fLowerPanelHeight,2>,fFrontRadius,false)
          translate <fThickness,0,fFrontDepth/2>
          }
        }
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* Lower Panel Case Border Definition                                                                        */
  //*************************************************************************************************************/
  #local fLowerPanelAngle1 = degrees(atan(fLowerPanelDepth/(fBorderLeftHeight-fBorderWidth-2*fLowerPanelRadius)));
  #local fLowerPanelAngle2 = degrees(atan(fLowerPanelDepth/(fUpperPanelRightWidth-fBorderWidth)));
  #local oLowerPanel =
    object {
      union {
        object {oLowerPanelBorder}                                      //* Lower case Border                   */
        object {                                                        //* Lower Case Bottom Wedge             */      
          box{<fThickness,0,-fLowerPanelRadius>,<fWidth-fThickness,fLowerPanelHeight*2,fLowerPanelRadius>}
          rotate fLowerPanelAngle1*x
          translate <0,(fBorderWidth-fLowerPanelRadius),fLowerPanelRadius> 
          }
        object{                                                         //* Lower Right Wedge with Cap          */
          union {
            box{<0,fThickness,-fLowerPanelRadius><-2*fLowerPanelDepth,fLowerPanelHeight,fLowerPanelRadius>}
            cylinder{<0,fLowerPanelHeight,0><-2*fLowerPanelDepth,fLowerPanelHeight,0>,fLowerPanelRadius}
            box{<0,fLowerPanelHeight,0><-2*fLowerPanelDepth,fLowerPanelHeight+fLowerPanelRadius,fLowerPanelDepth>}
            }
          rotate fLowerPanelAngle2*y
          clipped_by{plane{ x,0}}
          translate <fWidth-(fBorderWidth-fLowerPanelRadius),0,fLowerPanelRadius>
          }
       object {                                                         //* Lower Right Border Inset           */
          union {
            object {
              union {
                box{<0,0,-fLowerPanelRadius><-fLowerPanelDepth,fLowerPanelYOffset-2,fLowerPanelRadius>} 
                cylinder{<0,0,0><0,fLowerPanelYOffset-2,0>,fLowerPanelRadius}
                }
              rotate (90-fLowerPanelAngle2)*y
              translate -0.5*x
              }
            box{<0,0,-fLowerPanelRadius><-0.5,fLowerPanelYOffset-2,fLowerPanelRadius>}
            }
          rotate fLowerPanelAngle2*y
          translate <fWidth-(fBorderWidth-fLowerPanelRadius),fLowerPanelHeight-fLowerPanelRadius,fLowerPanelRadius>
          }
        object{                                                         //* Upper Right Border                 */
          union {
            object {
              union {
                box{<0,0,0><-2*fLowerPanelDepth,fLowerPanelRadius,fLowerPanelDepth>}
                cylinder{<0,fLowerPanelRadius,0><-2*fLowerPanelDepth,fLowerPanelRadius,0>,fLowerPanelRadius}
                }
              rotate fLowerPanelAngle2*y
              clipped_by{plane{ x,0}}
              }
            object { 
              box{<0,fLowerPanelRadius,-fLowerPanelRadius><-2*fLowerPanelDepth,(fBorderRightHeight-fBorderWidth)-(fBorderInsetHeight+fBorderLeftHeight),fLowerPanelRadius>}
              rotate fLowerPanelAngle2*y
              Shear_Trans(x+y,y,z)
              clipped_by{plane{-y,0 translate fLowerPanelRadius*y}}
              }
            }
          translate <fWidth-(fBorderWidth-fLowerPanelRadius),fBorderLeftHeight+fBorderInsetHeight,fLowerPanelRadius>
          }
        }
      texture{tLowerPanelTexture}  
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* Switch Panel Definition                                                                                   */
  //*************************************************************************************************************/ 
  #local oPowerLight =
    object {
      union {
        difference {
          cylinder {<0,0,0><0,0,-0.0001>,5/64}
          cylinder {<0,0,0.01><0,0,-0.1>,4/64}
          object {
            Wedge(90)
            rotate -45*y
            rotate -90*x
            }
          }
        box{<-1/64,0,0><1/64,6/64,0.0001>}  
        }
      pigment{Green}
      }                                          
      
  #local oDiskLight =
    object {
      union {
        object {
          difference {
            cylinder {<0,0,0><0,0,-0.0001>,5/64}
            cylinder {<0,0,0.01><0,0,-0.1>,4/64}
            }
          scale <1,0.5,1>
          }
        object {
          box{<-5/64,0,0><-4/64,-3/16,0.0001>}
          }
        object {
          box{< 5/64,0,0>< 4/64,-3/16,0.0001>}
          }
        object {
          difference {
            cylinder {<0,0,0><0,0,-0.0001>,5/64}
            cylinder {<0,0,0.01><0,0,-0.1>,4/64}
            }
          clipped_by{plane{ y,0}}  
          scale <1,0.5,1>
          translate -3/16*y
          }
        }  
      pigment{Green*0.1}
      }    
 
  #local oSwitch =
   object {
     union {
       object {
         difference {
           object {
             union {
               object {
                 Round_Box(<0,0,0>,<-fSwitchWidth,fSwitchHeight,fSwitchDepth>,fFrontRadius,false)
                 }
               object {
                 Round_Box(<-fThickness,0,0>,<-fSwitchWidth,fSwitchHeight,fLowerPanelDepth>,fFrontRadius,false)
                 }
               }
             Shear_Trans(x+y,y,z)
             }
           object {
             cylinder{<0,0,-0.1><0,0,+0.1>,9/32}
             translate <-fSwitchWidth/2,1.25,0>
             }
           }  
         }
       object {
         PushButton(9/32,1/64,2,0.5)
         rotate -90*x
         translate <-fSwitchWidth/2,1.25,0.5>
         pigment{White*0.3}
         }
       object {
         oPowerLight
         translate <-fSwitchWidth/2,0.5,0>
         }  
       object {
         oDiskLight
         translate <-fSwitchWidth/2,0.0,0>
         }  
       }
     texture{tSwitchTexture}
     }
 
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* Upper Panel Definition                                                                                    */
  //*************************************************************************************************************/
  #local oNetVistaText = 
    object {
      text { ttf "timrom.ttf" "NetVista" 0.125, <0,0,0>}
      }
      
  #local oUpperPanelBase =
    object {
      difference {
        union {
          object{Round_Box(<0,0,0>,<fUpperPanelWidth,fUpperPanelHeight,fUpperPanelDepth>,fUpperPanelRadius,false)}
          object{Round_Box(<fThickness,0,0>,<fUpperPanelWidth,fHeight-fBorderLeftHeight-fThickness,fLowerPanelDepth+fLowerPanelRadius+1>,fUpperPanelRadius,false)}
          object{
            Round_Box(<-(fUpperPanelRightWidth+1),0,0>,<0,(fHeight)-(fBorderRightHeight+fSwitchHeight),fUpperPanelDepth>,fUpperPanelRadius,false) 
            Shear_Trans(x+y,y,z)
            translate <fWidth,fBorderRightHeight+fSwitchHeight-fBorderLeftHeight,0>
            }
          object{
            Round_Box(<-(fUpperPanelRightWidth+1),0,0>,<0,(fUpperPanelHeight+fBorderLeftHeight)-(fSwitchHeight+fBorderRightHeight),fUpperPanelDepth>,fUpperPanelRadius,false) 
            translate <fWidth,fBorderRightHeight+fSwitchHeight-fBorderLeftHeight,0>
            }
          }
        union {
          box{<0,0,-0.1><5.875,1.75,fFrontDepth+0.1> translate <0.5,fUpperPanelHeight-3.625,0>}
          box{<0,0,-0.1><5.875,1.75,fFrontDepth+0.1> translate <0.5,fUpperPanelHeight-5.375,0>}
          box{<0,0,-0.1><4.000,1.00,fFrontDepth+0.1> translate <0.5,fUpperPanelHeight-6.375,0>}
          box{<0,0,-0.1><4.000,1.50,fFrontDepth+0.1> translate <0.5,fUpperPanelHeight-7.875,0>}
          object{
            oNetVistaText
            scale (1.125/max_extent(oNetVistaText).x)         
            rotate  90*z
            translate <6.125,0.675,-0.001> 
            pigment{Violet}
            }
          }  
        }
      }
  
  #local oCDDrive =
    object {
      union {
        union {
          difference {
            object {
              Round_Box(<0,0,0>,<5.875,0.625,fFrontDepth>,fUpperPanelRadius,false)
              }
            object {
              box{<4.875-1/64,0.250-1/64,-0.1><5.375+1/64,0.4375+1/64,0.1>}
              }
            }
          object {
            Round_Box(<4.875,0.250,-0.125>,<5.375,0.4375,0.5>,0.0625,false)
            }  
          object {
            box{<3.75,0.250,-0.001>,<4.125,0.375,0.5>}
            pigment{Green*0.1}
            }  
          }  
        object {
          Round_Box(<0,1.75-0.125,0>,<5.875,1.75,fFrontDepth>,fUpperPanelRadius,false)
          }
        object {
          Round_Box(<0,0,0>,<0.5,1.75,fFrontDepth>,fUpperPanelRadius,false)
          }
        object {
          Round_Box(<0,0,0>,<-0.5,1.75,fFrontDepth>,fUpperPanelRadius,false)
          translate 5.875*x
          }
        object {
          Round_Box(<0.5,0.625,0>,<5.875-0.5,1.625,fFrontDepth>,fUpperPanelRadius,false)
          }
        }
      }
      
  #local oFloppyDrive =
    object {
      union {
        object {
          Round_Box(<-fFrontRadius,-fFrontRadius,0>,<fFrontRadius,1.5+fFrontRadius,fFrontDepth>,fFrontRadius,false)
          }
        object {
          Round_Box(<-fFrontRadius,-fFrontRadius,0>,<fFrontRadius,1.5+fFrontRadius,fFrontDepth>,fFrontRadius,false)
          translate 4*x
          }
        object {
          Round_Box(<-fFrontRadius,1.5-7/16,0>,<4+fFrontRadius,1.5+fFrontRadius,fFrontDepth>,fFrontRadius,false)
          }
        object {
          union {
            difference {
              object {
                Round_Box(<-fFrontRadius,-fFrontRadius,0>,<4+fFrontRadius,12/16,fFrontDepth>,fFrontRadius,false)
                }
              object {
                sphere{<0,0,0>,0.75 scale < 1, 1/3, 2/3> translate <2,13/16,0>}
                }
              object {
                box{<0,0,-0.1><1,1/8,fFrontDepth+0.1> translate <2.875,0.5,0>}
                }
              object {
                sphere{<0,0,0>,1/16 translate <1,0.5,0>}
                }
              }
            object {
              difference {
                union {
                  box{<0,0,0><15/16,3/32,fFrontDepth>}
                  cylinder{<0,0,0><15/16,0,0>,3/64 translate 3/64*y}
                  }
                cylinder{<15/32,-0.1,0><15/32,0.25,0>,1.25 translate -1.25*z}
                }  
              translate <2.875+1/32,0.5+1/64,-1/8>
              pigment{Violet}
              }
            object {
              sphere{<0,0,0>,3/64 translate <1,0.5,1/32>}
              pigment{Green*0.1}
              }  
            }
          }
        }
      }
      
  #local oUpperPanel =
    object {
      union {
        object {oUpperPanelBase}
        object {IBMLogo(1.125,7/16,1/16) translate <0.375,fUpperPanelHeight-0.875,-1/64> pigment{White}}
        object {oCDDrive translate <0.5+fUpperPanelRadius/2,fUpperPanelHeight-3.625+fUpperPanelRadius/2,0>}
        object {Round_Box(<0,0,0>,<5.875                  ,1.75                  ,fFrontDepth>,fUpperPanelRadius,false) translate <0.5,fUpperPanelHeight-5.375,0>}
        object {
          union {
            difference {
              object {Round_Box(<0,0,0>,<4.000,1.00,fFrontDepth>,fUpperPanelRadius,false)}
              union {
                box{<0,0,-0.1><1,0.25,fFrontDepth+0.1> translate <0.375,0.25,0>}
                box{<0,0,-0.1><1,0.25,fFrontDepth+0.1> translate <1.500,0.25,0>}
                box{<0,0,-0.1><1,0.25,fFrontDepth+0.1> translate <2.675,0.25,0>}
                }
              }
            union {
              box{<0,0,0><1,0.25, 0.1> rotate 45*x translate <0.375,0.25,0>}
              box{<0,0,0><1,0.25, 0.1> rotate 45*x translate <1.500,0.25,0>}
              box{<0,0,0><1,0.25, 0.1> rotate 45*x translate <2.675,0.25,0>}
              }    
            }
           translate <0.5,fUpperPanelHeight-6.375,0>  
          }    
        object {oFloppyDrive translate <0.5,fUpperPanelHeight-7.875,0>}   
        }
      }
      
 #local oFrontPanel =
    object {
      union {
        object {oLowerPanel} 
        object {oSwitch translate <fWidth,fBorderRightHeight,0>}
        object {oUpperPanel translate fBorderLeftHeight*y} 
        }
      texture{tFrontTexture}
      }
      
  #local oIBMPC =
    object {
      union {
        object {oCase translate fFrontDepth*z}
        object {oFrontPanel} 
        }
      scale 1/12
      }
      
  oIBMPC
  
#end