#include "MTXKeys.inc"

#macro MTXKeyboard()
  #local fWidth   = 20.00;
  #local fDepth   =  8.00;
  #local fRadius1 =  0.875/2;
  #local fRadius2 =  1.625/2;
  #local fEdge    =  0.0625;
  #local fDelta   =  fDepth-(fRadius1+fRadius2);
  #local fAngle   =  asin((fRadius2-fRadius1)/fDelta);
  #local fLength  =  fDelta*cos(fAngle);
  
  #local fPFWidth = 18.500;
  #local fPFHeight = 1.500;
  #local fPFDepth  = 2.750;
  #local fPFXOffset = (fWidth-fPFWidth)/2;
  
  #local fPFHoleWidth = 9.0625;
  #local fPFHoleHeight = fRadius1;
  #local fPFHoleDepth = 1.625;           
  #local fPFHoleXOffset = 2.375;
  #local fPFHoleYOffset = fPFHeight-(fPFHoleHeight-fEdge);
  #local fPFHoleZOffset = fPFDepth-(fPFHoleDepth+0.625);

  #local fPFKeyXOffset = (fPFHoleWidth-12*fMTXKeyBaseWidth)/2;  
  #local fPFKeyZOffset = (fPFHoleDepth- 2*fMTXKeyBaseDepth)/2;  

  #local fKeyHole1Width   = 1.5;
  #local fKeyHole1Height  = fRadius2;
  #local fKeyHole1Depth   = 3.875;           
  #local fKeyHole1XOffset = 0.325;
  #local fKeyHole1YOffset = fRadius1/2;;
  #local fKeyHole1ZOffset = 0.875-fRadius1;

  #local fKeyHole2Width   = 11.25;
  #local fKeyHole2Height  = fRadius2;
  #local fKeyHole2Depth   = 3.875;           
  #local fKeyHole2XOffset = 2.25;
  #local fKeyHole2YOffset = fRadius1/2;;
  #local fKeyHole2ZOffset = 0.875-fRadius1;

  #local fKeyHole3Width    =  2.25;
  #local fKeyHole3bWidth   =  0.8125;
  #local fKeyHole3Height   = fRadius2;
  #local fKeyHole3Depth    =  3.875;           
  #local fKeyHole3aDepth   =  1.625;           
  #local fKeyHole3cDepth   =  0.875;           
  #local fKeyHole3XOffset  = 13.875;
  #local fKeyHole3bXOffset = 0.75;
  #local fKeyHole3YOffset  = fRadius1/2;;
  #local fKeyHole3ZOffset  = 0.875-fRadius1;
  #local fKeyHole3aZOffset = 2.25;
  #local fKeyHole3cZOffset = 0.75;

  #local fKeyHole4Width   =  3.125;
  #local fKeyHole4Height  = fRadius2;
  #local fKeyHole4Depth   = 3.875;           
  #local fKeyHole4XOffset = 16.375;
  #local fKeyHole4YOffset = fRadius1/2;;
  #local fKeyHole4ZOffset = 0.875-fRadius1;

  #local oBodyBase =
    object {
      union {
        object {
          Round_Cylinder(<0,0,0>,<fWidth,0,0>,fRadius1,fEdge,false)
          }
        object {
          Round_Cylinder(<0,0,0>,<fWidth,0,0>,fRadius2,fEdge,false)
          translate <0,0,fDelta>
          }
        object {
          Round_Box(<0,-fEdge,-fEdge>,<fWidth,fRadius2,fLength+fEdge>,fEdge,false)
          translate <0,fRadius1-fRadius2,0>
          rotate -degrees(fAngle)*x
          }
        object {
          Round_Box(<0,-fEdge,-fEdge>,<fWidth,-fRadius2,fLength+fEdge>,fEdge,false)
          translate <0,fRadius2-fRadius1,0>
          rotate  degrees(fAngle)*x
          }
        }
      }

  #local oPFHole =
    object {
      Round_Box(<0,0,0><fPFHoleWidth,fPFHoleHeight,fPFHoleDepth>,fEdge,false)
      }
      
  #local oKeyHole1 =
    object {
      Round_Box(<0,0,0><fKeyHole1Width,fKeyHole1Height,fKeyHole1Depth>,fEdge,false)
      }
      
  #local oKeyHole2 =
    object {
      Round_Box(<0,0,0><fKeyHole2Width,fKeyHole2Height,fKeyHole2Depth>,fEdge,false)
      }
      
  #local oKeyHole3 =
    object {
      union {
        object {
          Round_Box(<0,0,0><fKeyHole3Width,fKeyHole3Height,fKeyHole3aDepth>,fEdge,false)
          translate <0,0,fKeyHole3aZOffset> 
          }
        object {
          Round_Box(<0,0,0><fKeyHole3bWidth,fKeyHole3Height,fKeyHole3Depth>,fEdge,false)
          translate <fKeyHole3bXOffset,0,0>
          }
        object {
          Round_Box(<0,0,0><fKeyHole3Width,fKeyHole3Height,fKeyHole3cDepth>,fEdge,false)
          translate <0,0,fKeyHole3cZOffset> 
          }
        }
      }
      
  #local oKeyHole4 =
    object {
      Round_Box(<0,0,0><fKeyHole4Width,fKeyHole4Height,fKeyHole4Depth>,fEdge,false)
      }
      
  #local oPFBase =
    object {
      union {
        difference {
          object {
            Round_Box(<0,0,0><fPFWidth,fPFHeight,fPFDepth>,fEdge,false)
            }
          object {
            oPFHole
            translate <fPFHoleXOffset,fPFHoleYOffset,fPFHoleZOffset>
            }
          }
        object { PFKeys translate <fPFHoleXOffset+fPFKeyXOffset-fMTXKeyBaseWidth/2,fPFHeight-fMTXKeyBaseHeight/2,fPFHoleZOffset+fPFKeyZOffset>}
        }
      translate <0,-fEdge,-fPFDepth>
      }
      
  #local oKeyboard =
    object {
      union {
        difference {
          object { oBodyBase }
          union {
            object { oKeyHole1 translate <fKeyHole1XOffset,fKeyHole1YOffset,fKeyHole1ZOffset>}
            object { oKeyHole2 translate <fKeyHole2XOffset,fKeyHole2YOffset,fKeyHole2ZOffset>}
            object { oKeyHole3 translate <fKeyHole3XOffset,fKeyHole3YOffset,fKeyHole3ZOffset>}
            object { oKeyHole4 translate <fKeyHole4XOffset,fKeyHole4YOffset,fKeyHole4ZOffset>}
            }
          }
        object { oPFBase  rotate -14*x translate <fPFXOffset, 0, fDepth-fRadius1> }
        object { oKeys1 rotate -degrees(fAngle)*x translate <fKeyHole1XOffset+1/32,fKeyHole1YOffset,fKeyHole1ZOffset+1/32>}
        object {  Keys  rotate -degrees(fAngle)*x translate <fKeyHole2XOffset+1/32,fKeyHole2YOffset,fKeyHole2ZOffset+1/32>}
        object {  Keys3 rotate -degrees(fAngle)*x translate <fKeyHole3XOffset+1/32,fKeyHole3YOffset,fKeyHole3ZOffset+1/32>}
        object {  Keys4 rotate -degrees(fAngle)*x translate <fKeyHole4XOffset+1/32,fKeyHole4YOffset,fKeyHole4ZOffset+1/32>}
        }
      texture{vMTXLightKeyTexture}      
      rotate -degrees(fAngle)*x
      translate <0,fRadius1,fRadius1>
      scale 1/12
      }
      
  oKeyboard
  
#end