#declare mn_width  = 15.70;
#declare mn_height = 12.80;
#declare mn_depth  =  1.50;
#declare mn_depth_back   = 1.00;
#declare mn_frame_depth  = 0.25;
#declare mn_radius_outer = 0.10;
#declare mn_radius_inner = 0.20;
#declare mn_color = color rgb<0.1,0.1,0.1>;
#declare mn_texture = texture{pigment{White*0.05} 
                      normal { bumps 0.04 scale 0.0005 }
                      finish { phong 0.5 }
                      }

#include "mn_back.inc" 
#include "StickyPad.inc"

#macro Monitor(sImage)
//********************************************************************/
//* Text and Images on monitor frame                                 */
//********************************************************************/
  #local mn_view_sonic =
    object {
      text {
        ttf             
        "times.ttf",    
        "ViewSonic",    
        0.1,            
        0               
        }
      scale 0.25
      pigment{White}
      }  

#local mn_vp181b =
  text {
    ttf             
    "timesi.ttf",   
    "VP181b",       
    0.1,            
    0               
    }
    
#local mn_birds = 
  object {
    box{0,1}
    pigment{image_map{gif "Keyboard/birds" transmit 13,1}}
    scale <0.6,0.3,0.1>
    }
     
     
//********************************************************************/
//* Button Controls on front of monitor                              */
//********************************************************************/
#local mn_dimple =
  object {
    sphere { 0,0.75 scale <0.6,0.30,0.35> translate -0.175*z }
    }     
     
#local mn_dimples =
  object {
    union {
      object {mn_dimple}
      object {mn_dimple translate -0.6*x}
      object {mn_dimple translate -1.2*x}
      object {mn_dimple translate  0.6*x}
      object {mn_dimple translate  1.2*x}
      cylinder{-1.2*x, 1.2*x, 0.1 translate -0.15*z}
      }
    }
    
#local mn_button =
  object {
    Round_Box(<-0.20,-0.05,-0.10>,< 0.20, 0.05, 0.20>,0.005,false)
    }
    
#local mn_buttons =
  object {
    union {
      object { mn_button translate -1.2*x }
      object { mn_button translate -0.6*x }
      object { mn_button }
      object { mn_button translate  0.6*x }
      object { mn_button translate  1.2*x }
      }
    }
    
#local mn_power_light =
  object {
    box {0,0.05}
    translate 0.9*x
    translate -0.05*z
    pigment{Green}
    }

//********************************************************************/
//* Front Frame                                                      */
//********************************************************************/
#local mn_base_frame =
  object {
    intersection {
      union {
        difference {
          Round_Box(<0,0,0>,<mn_width,mn_height,mn_depth>,mn_radius_outer,false)
          box{<0,0,-0.1><mn_width-1,mn_height-1,0.2> translate <0.5,0.5,0>}
          }
        cylinder{0,(mn_width -1)*x,mn_radius_inner translate<0.5,0.5,mn_radius_inner>}
        cylinder{0,(mn_width -1)*x,mn_radius_inner translate<0.5,mn_height-0.5,mn_radius_inner>}
        cylinder{0,(mn_height-1)*y,mn_radius_inner translate<0.5,0.5,mn_radius_inner>}
        cylinder{0,(mn_height-1)*y,mn_radius_inner translate<mn_width-0.5,0.5,mn_radius_inner>}
        object {mn_view_sonic translate <0.75,0.25,-0.01>}
        object {mn_vp181b     scale 0.25 translate -0.01*z translate (mn_width-1.5)*x translate (mn_height-0.45)*y pigment{White}}
        object {mn_birds  translate <0.75,mn_height-0.5, -0.001> }
        }    
      box {<-0.2,-0.2,-0.2><mn_width+0.2,mn_height+0.2,mn_frame_depth>}
      }  
    }
    
//********************************************************************/
//* LCD Monitor                                                      */
//********************************************************************/
#local mn_LCD =
  object {
    box{0,1 
    pigment{image_map{jpeg concat("Keyboard/",sImage)}} 
    scale <mn_width-(1+2*mn_radius_inner),mn_height-(1+2*mn_radius_inner),0.1>
    translate <0.6+mn_radius_inner,0.6+mn_radius_inner,mn_radius_inner-0.01> }
    scale (mn_width-0.2)/mn_width
    }


#local mn_base =
  object {
    union {
      difference {
        object {mn_base_frame}
        object {mn_dimples translate (mn_width/2)*x translate 0.300*y}
        }    
      object {mn_LCD}
      object {mn_buttons translate (mn_width/2)*x translate 0.300*y}
      object {mn_power_light translate (mn_width/2)*x translate 0.250*y}
      object {mn_back() translate  mn_depth*z}
      object {StickyPad() scale 12 rotate -5*z translate <12,-2.5,0>} 
      }  
    }
     
#local oPedestalLeg =
  object {
    union {
      object {Round_Cylinder(<0,0,0>,<0,0.375,0>,0.750,0.05,false)}
      object {Round_Box(<-0.750,0,0>,<0.750,0.375,7.5>,0.05,false) rotate -10*y}
      object {Round_Box(<-0.750,0,0>,<0.750,0.375,7.5>,0.05,false) rotate  10*y}
      }
    }

#local oPedestalBase =
  object {
    union {
      object { Round_Cylinder(<0,0,0>,<0,0.375,0>,3,0.05,false) }
      object { Round_Cylinder(<0,0,0>,<0,0.375,0>,4,0.05,false) translate 2*z }
      object { Round_Box(<-2,0,-1><2,12,1>,0.25,false)}
      }
    }
     
#local oPedestal =
  object {
    union {
      object { oPedestalLeg translate -10*z rotate -60*y }
      object { oPedestalLeg translate -10*z rotate  60*y }
      object { oPedestalBase }
      }
    translate mn_width/2*x
    }

#local oMonitor =    
  object {
    union {
      object {mn_base  rotate  7.5*x translate 4*y}
      object {oPedestal translate 6*z}
      }
    texture{mn_texture}
    scale 1/12
    }
     
     
  oMonitor
#end