#macro Pentel()
  #local fEndCapWidth = 0.625;
  #local fEndCapRadius = 5/32;
  #local fEndCapEdgeRadius = 1/64;
  #local fEndCapXOffset = 4.875;
  #local tEndCapTexture = texture {
                          pigment{Blue}
                          finish {reflection 0.25 phong 0.3 phong_size 60}
                          }
 
  #local fEraserWidth = 0.125;
  #local fEraserRadius = 7/64;
  #local fEraserXOffset = 4.75;
  #local tEraserTexture = texture {
                          pigment{LightBlue}
                          finish {reflection 0.05 phong 0.3 phong_size 60}
                          }
 
  #local fCaseWidth = 3.00;
  #local fCaseRadius = 5/32;
  #local fCaseXOffset = 1.75;
  #local tCaseTexture = texture {
                        pigment{Black}
                        finish {reflection 0.0625 phong 0.3 phong_size 60}
                        }
 
  #local fRibWidth = 0.875;
  #local nRibs = 25;
  #local fRibThickness = fRibWidth/nRibs;
  #local fRibRadius = fRibThickness/2;
  #local fRibXOffset = 0.875;
 
  #local fConeBaseWidth = 0.125;
  #local fConeWidth = 0.625;
  #local fConeRadius = 1/32;
  #local nConeRibs = 24;
  #local fConeXOffset = 0.125;
  #local tConeTexture = tEndCapTexture;
 
  #local fTipWidth = 0.125;
  #local fTipRadius = 3/128;
  #local fTipXOffset = 0;
  #local tTipTexture = T_Chrome_5E;
 
  #local fLeadWidth = 1/16;
  #local fLeadRadius = 0.35/25.4;
  #local fLeadXOffset = -fLeadWidth;
  #local tLeadTexture = texture{
                        pigment{Gray10}
                        finish {reflection 0.05 phong 0.3 phong_size 60}
                        }
 
  #local fClipBandThickness = 1/64;
  #local fClipBandWidth = 7/32;
  #local fClipHeight = 3/32;
  #local fClipDepth = 5/32;
  #local fClipThickness = 1/64;
  #local fClipLength = 1.125;
  #local fClipRadius = 1/32;
  #local fClipXOffset   = 4.50;
  #local tClipTexture = T_Chrome_3C;
 
  #local oEndCap =
    object {
      Round_Cylinder(<0,0,0>,<fEndCapWidth,0,0>,fEndCapRadius,fEndCapEdgeRadius,false)
      texture{tEndCapTexture}
      }
 
  #local oEraser =
    object {
      cylinder {<0,0,0><fEraserWidth,0,0>,fEraserRadius}
      texture{tEraserTexture}
      }
 
  #local oCase =
    object {
      cylinder {<0,0,0><fCaseWidth,0,0>,fCaseRadius}
      texture{tCaseTexture}
      }
 
  #local oRib =
    object {
      union {
        #local n = 0;
        #while(n < nRibs)
          object {
            torus{fCaseRadius-fRibRadius,fRibRadius}
            rotate 90*z
            translate (fRibRadius+n*fRibThickness)*x
            }
          #local n = n + 1;
        #end
        }
      texture{tCaseTexture}
      }
 
  #local oCone =
    object {
      union {
        cone{<0,0,0>,fConeRadius,<fConeWidth,0,0>,fCaseRadius}
        cylinder{<0,0,0>,<fConeBaseWidth,0,0>,fCaseRadius translate fConeWidth*x}
        }
      texture{tConeTexture}
      }
 
  #local oTip =
    object {
      cylinder{<0,0,0><fTipWidth,0,0>,fTipRadius}
      texture{tTipTexture}
      }
 
  #local oLead =
    object {
      cylinder{<0,0,0><fLeadWidth,0,0>,fLeadRadius}
      texture{tLeadTexture}
      }
 
  #local oClip =
    object {
      union {
        cylinder{<0,0,0><fClipBandWidth,0,0>,fCaseRadius+fClipBandThickness}
        box{<0,0,-fClipDepth/2><fClipThickness,fCaseRadius+fClipHeight-fClipRadius,fClipDepth/2>}
        object {
          intersection {
            difference{
              cylinder{<0,0,-fClipDepth/2><0,0,fClipDepth/2>,fClipRadius}
              cylinder{<0,0,-fClipDepth/2-0.1><0,0,fClipDepth/2+0.1>,fClipRadius-fClipThickness}
              }
            object {Wedge(90) rotate -90*x}
            }
          translate <-(fClipRadius-fClipThickness),fCaseRadius+fClipHeight-fClipRadius,0>
          }
        box{<0,0,-fClipDepth/2><-fClipLength,-fClipThickness,fClipDepth/2> translate <-(fClipRadius-fClipThickness),fCaseRadius+fClipHeight,0>}
        object {
          intersection {
            difference{
              cylinder{<0,0,-fClipDepth/2><0,0,fClipDepth/2>,fClipRadius}
              cylinder{<0,0,-fClipDepth/2-0.1><0,0,fClipDepth/2+0.1>,fClipRadius-fClipThickness}
              }
            object {Wedge(90) rotate -90*x rotate 90*z}
            }
          translate <-(fClipRadius-fClipThickness)-fClipLength,fCaseRadius+fClipHeight-fClipRadius,0>
          }
        object {
          intersection {
            difference{
              cylinder{<0,0,-fClipDepth/2><0,0,fClipDepth/2>,fClipHeight-fClipRadius}
              cylinder{<0,0,-fClipDepth/2-0.1><0,0,fClipDepth/2+0.1>,fClipHeight-fClipRadius-fClipThickness}
              }
            object {Wedge(180) rotate -90*x rotate -90*z}
            }
          translate <-(fClipRadius-fClipThickness)-fClipLength-fClipRadius+(fClipHeight-fClipRadius),fCaseRadius+fClipHeight-fClipRadius,0>
          }
        }
      texture{tClipTexture}
      }
 
  #local oPentel =
    object {
      union {
        object {oEndCap translate fEndCapXOffset*x}
        object {oEraser translate fEraserXOffset*x}
        object {oCase   translate fCaseXOffset*x}
        object {oRib    translate fRibXOffset*x}
        object {oCone   translate fConeXOffset*x}
        object {oTip    translate fTipXOffset*x}
        object {oLead   translate fLeadXOffset*x}
        object {oClip   translate fClipXOffset*x}
        }
      translate fCaseRadius*y
      scale 1/12
      }
  oPentel
#end
