#macro Puller()
  #local fHandleDepth = 0.875;
  #local fHandleHeight = 0.5;
  #local fHandleRadius  = fHandleHeight/2; 
  #local fHandleCurve = 1.00;
  #local fHandleCenter = fHandleCurve-fHandleHeight/2;
  #local tHandleTexture = T_Chrome_1A;
  #local fCupRadius = 3.625;
  #local fCupHeight = 1.00;
  #local fCupXOffset = 2.75;
  #local fCupBaseHeight = 0.25;
  #local fCupBaseRadius = 0.75;
  #local tCupTexture = pigment{Black};
  #local fValveHeight = 0.375;
  #local fValveRadius = 0.50;
  #local fValveStemHeight = 1.0;
  #local fValveStemRadius = 0.0625;
  #local tValveTexture = T_Chrome_5E;
  #local fValveStemCapHeight = 0.125;
  #local fValveStemCapRadius = 0.125;
  #local fValveStemCapDiagonal = 2*fValveStemCapRadius/sqrt(3);
  #local fTriggerHeight = 0.125;
  #local fTriggerDepth  = 0.375;
  #local fTriggerRadius = 0.5;
  #local fTriggerAngle = 75;
  
  #local oStraight =
    object {
      union {
        cylinder{<0,0, fHandleDepth/2-fHandleRadius><1,0, fHandleDepth/2-fHandleRadius>,fHandleRadius}
        cylinder{<0,0,-fHandleDepth/2+fHandleRadius><1,0,-fHandleDepth/2+fHandleRadius>,fHandleRadius}
        box{<0,-fHandleHeight/2,-fHandleDepth/2+fHandleRadius><1,fHandleHeight/2,fHandleDepth/2-fHandleRadius>}
        }
      }
      
  #local oCurve =
    object {
      intersection {
        object {Wedge(45)}
        union {
          torus{fHandleCurve-fHandleRadius,fHandleRadius translate -(fHandleDepth/2-fHandleRadius)*y}
          torus{fHandleCurve-fHandleRadius,fHandleRadius translate  (fHandleDepth/2-fHandleRadius)*y}
          difference {
            cylinder{<0,-fHandleDepth/2+fHandleRadius,0><0,fHandleDepth/2-fHandleRadius,0>,fHandleCurve}
            cylinder{<0,-fHandleDepth/2+fHandleRadius-0.1,0><0,fHandleDepth/2-fHandleRadius+0.1,0>,fHandleCurve-fHandleHeight}         
            }
          }
        }
      rotate -90*x
      }
      
  #local oHandleSegment1 =
    object {
      union {
        object {oStraight scale 4*x translate -fHandleCenter*y}
        object {oCurve rotate 180*z}
        }
      rotate 45*z
      }
      
  #local oHandleSegment2 =
    object {
      union {
        object {oHandleSegment1 translate <2,fHandleCenter,0>}
        object {oStraight scale 2*x}
        }
      } 
      
  #local oHandleSegment3 =
    object {
      union {
        object {oHandleSegment2 translate -fHandleCenter*y}
        object {oCurve rotate 180*z}
        }
      rotate 45*z
      } 
      
  #local oHandleSegment4 =
    object {
      union {
        object {oHandleSegment3 translate <0.25,fHandleCenter,0>}
        object {oStraight scale 0.25*x}
        }
      }
      
  #local oHandleSegment5 =
    object {
      union {
        object {oHandleSegment4 translate -fHandleCenter*y}
        object {oCurve rotate 180*z}
        }
      rotate 45*z
      }
      
  #local oHandleSegment6 =
    object {
      union {
        object {oHandleSegment5 translate <1,fHandleCenter,0>}
        object {oStraight scale 1*x}
        }
      }
      
  #local oHandleSegment7 =
    object {
      union {
        object {oHandleSegment6 translate -fHandleCenter*y}
        object {oCurve rotate 180*z}
        }
      rotate 45*z
      } 
      
  #local oHandleSegment8 =
    object {
      union {
        object {oHandleSegment7 translate<4,fHandleCenter,0>}
        object {oStraight scale 4*x}
        }
      translate -0.5*x
      }
      
  #local oCup =
    object {
      union {
        sphere{<0,0,0>,fCupRadius translate (fCupHeight-fCupRadius)*y clipped_by{plane{-y,0}}}
        cylinder{<0,0,0><0,fCupHeight+fCupBaseHeight,0>,fCupBaseRadius}
        }
      texture{tCupTexture}
      }
  
  #local oValveStemCap =
    object {
      union {
        prism{
          linear_spline
          0,fValveStemCapHeight,
          7,
          < fValveStemCapDiagonal/2, fValveStemCapRadius>,
          < fValveStemCapDiagonal  ,0>,
          < fValveStemCapDiagonal/2,-fValveStemCapRadius>,
          <-fValveStemCapDiagonal/2,-fValveStemCapRadius>,
          <-fValveStemCapDiagonal  ,0>,
          <-fValveStemCapDiagonal/2, fValveStemCapRadius>,
          < fValveStemCapDiagonal/2, fValveStemCapRadius>
          }
        object {
          sphere{<0,0,0>,fValveStemCapRadius}
          clipped_by{plane{-y,0}}
          translate fValveStemCapHeight*y
          }
        }
      }
      
  #local oValve =
    object {
      union {
        object {
          Round_Cylinder(<0,-fHandleRadius,0>,<0,fHandleHeight+fHandleRadius,0>,fCupBaseRadius,fHandleRadius,false)
          texture{tHandleTexture}
          }
        object {
          cylinder{<0,0,0><0,fValveHeight,0>,fValveRadius}
          translate (fHandleHeight+fHandleRadius)*y
          }
        object {
          cylinder{<0,0,0><0,fValveStemHeight,0>,fValveStemRadius}
          translate (fHandleHeight+fHandleRadius+fValveHeight)*y
          texture{tHandleTexture}
          }
        object {
          oValveStemCap 
          translate (fHandleHeight+fHandleRadius+fValveHeight+fValveStemHeight)*y
          texture{tHandleTexture}
          }
        }  
      texture{tValveTexture}
      }
      
  #local oCupAssembly =
    object {
      union {
        object {oCup}
        object {oValve translate (fCupHeight+fCupBaseHeight)*y}
        }
      }
      
  #local oTriggerCurve =
    object {
      intersection {
        object {Wedge(fTriggerAngle)}
        difference {
          cylinder{<0,-fTriggerDepth/2,0><0,fTriggerDepth/2,0>,fTriggerRadius+fTriggerHeight/2} 
          cylinder{<0,-fTriggerDepth/2-0.1,0><0,fTriggerDepth/2+0.1,0>,fTriggerRadius-fTriggerHeight/2} 
          }
        }
      rotate -90*x
      }           
      
  #local oTriggerStraight =
    object {
      box{<0,-fTriggerHeight/2,-fTriggerDepth/2><1, fTriggerHeight/2, fTriggerDepth/2>}
      }
      
  #local oTriggerSegment1 =
    object {
      union {
        object {oTriggerStraight scale 3*x}
        object {oTriggerCurve rotate  fTriggerAngle*z translate -fTriggerRadius*y}
        }                                                              
      translate fTriggerRadius*y
      rotate -fTriggerAngle*z
      }          
      
  #local oTriggerSegment2 =
    object {
      union {
        object {oTriggerSegment1 translate -2*fTriggerRadius*y}
        object {oTriggerCurve rotate 180*z}
        }
      rotate fTriggerAngle*z
      }
      
  #local oTriggerSegment3 =
    object {
      union {
        object {oTriggerSegment2 translate <0.5,fTriggerRadius,0>}
        object {oTriggerStraight scale 0.5*x}
        }
      }
      
  #local oTriggerSegment4 =
    object {
      difference {
        object {oTriggerSegment3 translate -0.25*x}
        object {cylinder{<0,-fTriggerHeight/2-0.1,0><0,fTriggerHeight/2+0.1,0>,fValveStemRadius+1/32}}
        }
      translate -fCupXOffset*x
      }
      
  #local oTrigger =
    object {
      union {
        object {oTriggerSegment4}
        object {oTriggerSegment4 rotate 180*y}
        }
      texture{tHandleTexture}
      }      
              
          
  #local oHandle =
    object {
      union {
        object {
          union {
            object {oHandleSegment8}
            object {oHandleSegment8 rotate 180*y}
            object {oTrigger translate (fHandleRadius+fValveHeight+fValveStemHeight)*y}
            }
          translate (fCupHeight+fCupBaseHeight+fHandleRadius)*y  
          }
        object {oCupAssembly translate  fCupXOffset*x}
        object {oCupAssembly translate -fCupXOffset*x}
        } 
      texture{tHandleTexture}
//      scale 1/12
      }
  oHandle
#end