//***************************************************************************************************************/
//* Persistence of Vision Ray Tracer Scene Description File                                                     */
//* File: Table.inc                                                                                             */
//* Vers: 3.6                                                                                                   */
//* Desc: Table Definitions                                                                                     */
//* Date: 11/10/2004                                                                                            */
//* Auth: D. E. LeMasters                                                                                       */
//***************************************************************************************************************/
                                                                        //*                                     */
//***************************************************************************************************************/
//* Rectangular Table Top Definiton                                                                             */
//*    Parameters :                                                                                             */
//*        fW : Table Top Width                                                                                 */
//*        fH : Table Top Height (Thickness)                                                                    */
//*        fD : Table Top Depth                                                                                 */
//*        fE : Table Top Edge Radius                                                                           */
//*        fC : Table Top Corner radius                                                                         */
//***************************************************************************************************************/
#macro TableTop(fW,fH,fD,fE,fC)
  #local oTableTop =
    object {
      union {
        object {Round_Box(<0,0,fC>,<fW,fH,fD-fC>,fE,false)}
        object {Round_Box(<fC,0,0>,<fW-fC,fH,fD>,fE,false)}
        object {Round_Cylinder(<0,0,0>,<0,fH,0>,fC,fE,false) translate <fC,0,fC>}
        object {Round_Cylinder(<0,0,0>,<0,fH,0>,fC,fE,false) translate <fW-fC,0,fC>}
        object {Round_Cylinder(<0,0,0>,<0,fH,0>,fC,fE,false) translate <fW-fC,0,fD-fC>}
        object {Round_Cylinder(<0,0,0>,<0,fH,0>,fC,fE,false) translate <fC,0,fD-fC>}
        }
      }
  oTableTop
#end
 
//***************************************************************************************************************/
//* Generate Wedge Shaped Table                                                                                 */
//***************************************************************************************************************/
#macro WedgeTable()
  #local oTable =
    object {
      GenTable(1)
      }
  oTable
#end
 
//***************************************************************************************************************/
//* Generate Rectangular Table                                                                                  */
//***************************************************************************************************************/
#macro Table()
  #local oTable =
    object {
      GenTable(2)
      }
  oTable
#end
 
//***************************************************************************************************************/
//* Generate Specified Table Type                                                                               */
//***************************************************************************************************************/
                                                                        //*                                     */
#macro GenTable(iType)                                                  //*                                     */
  #local fWedgeTableWidth      = 24.00;                                 //*                                     */
  #local fLongTableWidth       = 60.00;                                 //*                                     */
  #local fTableDepth           = 32.00;                                 //*                                     */
  #local fTableHeight          = 30.00;                                 //*                                     */
                                                                        //*                                     */
  #local fTableTopWidth        = 24;                                    //*                                     */
  #local fTableTopDepth        = 32;                                    //*                                     */
  #local fTableTopHeight       =  1.25;                                 //*                                     */
  #local fTableTopCornerRadius =  1.00;                                 //*                                     */
  #local fTableTopEdgeRadius   =  0.05;                                 //*                                     */
                                                                        //*                                     */
  #local fTableBaseHeight      =  3.00;                                 //*                                     */
  #local fTableBaseDepth       = 28.00;                                 //*                                     */
  #local fTableBaseRadius      =  1.00;                                 //*                                     */
  
  #local fTableBackBaseDepth   = 12.00;
                                                                        //*                                     */
  #local fTableFootPadRadius   =  0.75;                                 //*                                     */
  #local fTableFootPadHeight   =  0.375;                                //*                                     */
  #local fTableFootRadius      =  0.1875;                               //*                                     */
  #local fTableFootHeight      =  1.00;
 
  #local fTableLegWidth        = 1.50;
  #local fTableLegHeight       = fTableHeight-(fTableTopHeight+fTableFootHeight);
  #local fTableLegDepth        = 3.00;
  #local fTableLegEdge         =  0.25;                                 //*                                     */
  #local fTableLegXOffset      =  2.00;
  #local fTableLegZOffset      =  2.00;
 
  #local fTableTopWedgeDepth   = fTableTopCornerRadius*tan(radians(22.5))+fTableTopDepth;
 
  #local vTableCorner          = <fTableTopCornerRadius,0,fTableTopWedgeDepth-fTableTopCornerRadius>-<fTableTopWidth-fTableTopCornerRadius,0,fTableTopCornerRadius>;
  #local vTableCorner          = vrotate(vTableCorner,22.5*y)+<fTableTopWidth-fTableTopCornerRadius,0,fTableTopCornerRadius>;
  #local fTableWedgeWidth      = (vTableCorner.x-fTableTopWidth/2+fTableTopCornerRadius)*2;
  #local fTableWedgeDepth      = (vTableCorner.z+fTableTopCornerRadius);
 
//  #local vTableTopTexture = pigment{White*0.5}
//  #local vTableTopTexture = pigment{Tan};
  #local vTableTopTexture = texture {                  
                              pigment{rgb <0.60,0.50,0.40>}     
//                               normal { bumps 0.04 scale 0.0005 }
                              finish { phong .5 }               
                              };                                

//  #local vTableTopTexture = T_Glass1
  #local vTableLegTexture = texture{ T_Chrome_3B normal {bumps .4 scale 100 } } ;
  #local vTableLegTexture = texture{ T_Chrome_2B normal {bumps .4 scale 100 } } ;
  #local vTableLegTexture = texture{ T_Chrome_1B normal {bumps .4 scale 100 } } ;
  #local vTableLegTexture = texture{ T_Silver_1B normal {bumps .4 scale 100 } } ;
                                                                       //*                                     */
  //*************************************************************************************************************/
  //* Generate Table Leg Foot Pad                                                                               */
  //*************************************************************************************************************/
  #local oTableFoot =
    object {
      union {
        cylinder{<0,0,0><0,fTableFootPadHeight,0>,fTableFootPadRadius pigment{Black}}
        cylinder{<0,0,0><0,fTableFootHeight,0>,fTableFootRadius pigment{White*0.5}}
        }
      }
                                                                        //*                                     */
  //*************************************************************************************************************/
  //* Generate Table Leg Assembly                                                                               */
  //*************************************************************************************************************/
  #local oTableLeg =
    object {
      union {
        object {
          union {
            object {Round_Box(<0,0,0>,<fTableLegWidth,fTableBaseHeight-fTableBaseRadius+fTableLegEdge,fTableBaseDepth>,fTableLegEdge,false)}
            object {Round_Box(<0,0,fTableBaseRadius-fTableLegEdge>,<fTableLegWidth,fTableBaseHeight,fTableBaseDepth-fTableBaseRadius+fTableLegEdge>,fTableLegEdge,false)}
            object {Round_Cylinder(<0,0,0>,<fTableLegWidth,0,0>,fTableBaseRadius,fTableLegEdge,false) translate <0,fTableBaseHeight-fTableBaseRadius,fTableBaseRadius>}
            object {Round_Cylinder(<0,0,0>,<fTableLegWidth,0,0>,fTableBaseRadius,fTableLegEdge,false) translate <0,fTableBaseHeight-fTableBaseRadius,fTableBaseDepth-fTableBaseRadius>}
            object {Round_Box(<0,0,0>,<fTableLegWidth,fTableLegHeight,fTableLegDepth>,fTableLegEdge,false) translate 2*fTableBaseDepth/3*z}
            object {
              union {
                object {Round_Box(<0,0,0>,<fTableLegWidth,-(fTableBaseHeight-fTableBaseRadius+fTableLegEdge),fTableBaseDepth>,fTableLegEdge,false)}
                object {Round_Box(<0,0,fTableBaseRadius-fTableLegEdge>,<fTableLegWidth,-fTableBaseHeight,fTableBaseDepth-fTableBaseRadius+fTableLegEdge>,fTableLegEdge,false)}
                object {Round_Cylinder(<0,0,0>,<fTableLegWidth,0,0>,fTableBaseRadius,fTableLegEdge,false) translate <0,-(fTableBaseHeight-fTableBaseRadius),fTableBaseRadius>}
                object {Round_Cylinder(<0,0,0>,<fTableLegWidth,0,0>,fTableBaseRadius,fTableLegEdge,false) translate <0,-(fTableBaseHeight-fTableBaseRadius),fTableBaseDepth-fTableBaseRadius>}
                }
              translate fTableLegHeight*y
              }
            }
          translate fTableFootHeight*y
          }
        object {oTableFoot translate <fTableLegWidth/2,0,fTableLegWidth/2>}
        object {oTableFoot translate <fTableLegWidth/2,0,fTableBaseDepth-fTableLegWidth/2>}
        }
      translate -fTableLegWidth/2*x
      }
 
  //*************************************************************************************************************/
  //* Generate Table Back Leg Assembly                                                                          */
  //*************************************************************************************************************/
  #local oTableBackLeg =
    object {
      union {
        object {
          union {
            object {Round_Box(<0,0,0>,<fTableLegWidth,fTableBaseHeight-fTableBaseRadius+fTableLegEdge,fTableBackBaseDepth>,fTableLegEdge,false)}
            object {Round_Box(<0,0,fTableBaseRadius-fTableLegEdge>,<fTableLegWidth,fTableBaseHeight,fTableBackBaseDepth-fTableBaseRadius+fTableLegEdge>,fTableLegEdge,false)}
            object {Round_Cylinder(<0,0,0>,<fTableLegWidth,0,0>,fTableBaseRadius,fTableLegEdge,false) translate <0,fTableBaseHeight-fTableBaseRadius,fTableBaseRadius>}
            object {Round_Cylinder(<0,0,0>,<fTableLegWidth,0,0>,fTableBaseRadius,fTableLegEdge,false) translate <0,fTableBaseHeight-fTableBaseRadius,fTableBackBaseDepth-fTableBaseRadius>}
            object {Round_Box(<0,0,0>,<fTableLegWidth,fTableLegHeight,fTableLegDepth>,fTableLegEdge,false) translate  (fTableBackBaseDepth-fTableLegDepth)/2*z}
            object {
              union {
                object {Round_Box(<0,0,0>,<fTableLegWidth,-(fTableBaseHeight-fTableBaseRadius+fTableLegEdge),fTableBackBaseDepth>,fTableLegEdge,false)}
                object {Round_Box(<0,0,fTableBaseRadius-fTableLegEdge>,<fTableLegWidth,-fTableBaseHeight,fTableBackBaseDepth-fTableBaseRadius+fTableLegEdge>,fTableLegEdge,false)}
                object {Round_Cylinder(<0,0,0>,<fTableLegWidth,0,0>,fTableBaseRadius,fTableLegEdge,false) translate <0,-(fTableBaseHeight-fTableBaseRadius),fTableBaseRadius>}
                object {Round_Cylinder(<0,0,0>,<fTableLegWidth,0,0>,fTableBaseRadius,fTableLegEdge,false) translate <0,-(fTableBaseHeight-fTableBaseRadius),fTableBackBaseDepth-fTableBaseRadius>}
                }
              translate fTableLegHeight*y
              }
            }
          translate fTableFootHeight*y
          }
        object {oTableFoot translate <fTableLegWidth/2,0,fTableLegWidth/2>}
        object {oTableFoot translate <fTableLegWidth/2,0,fTableBackBaseDepth-fTableLegWidth/2>}
        }
      translate -fTableLegWidth/2*x
      translate -fTableBackBaseDepth/2*z
      rotate 90*y
      }
 
  #local oTableLegBrace =
    object {
      Round_Box(<0,0,0>,<fLongTableWidth-2*fTableLegXOffset,fTableLegDepth,fTableLegWidth>,fTableLegEdge,false)
      }
 
  #local oLongTable =
    object {
      union {
        object {
          TableTop(fLongTableWidth,fTableTopHeight,fTableTopDepth,fTableTopEdgeRadius,fTableTopCornerRadius)
          translate (fTableHeight-fTableTopHeight)*y
//          pigment{White*0.5}
          texture{vTableTopTexture}
          }
        object {
          union {
            object {oTableLeg translate <fTableLegXOffset,0,0>}
            object {oTableLeg translate <fLongTableWidth-fTableLegXOffset,0,0>}
            object {oTableLegBrace translate <fTableLegXOffset,fTableHeight/2,(2*fTableBaseDepth/3)+(fTableLegDepth-fTableLegWidth)/2>}
            object {oTableLegBrace translate <fTableLegXOffset,fTableHeight-fTableLegDepth-fTableTopHeight,(2*fTableBaseDepth/3)+(fTableLegDepth-fTableLegWidth)/2>}
            object {oTableLegBrace translate <fTableLegXOffset,fTableHeight-fTableLegDepth-fTableTopHeight,(1*fTableBaseDepth/3)+(fTableLegDepth-fTableLegWidth)/2>}
            }
          translate ((fTableTopDepth-fTableBaseDepth)-fTableLegZOffset)*z
          texture{vTableLegTexture}
          }
        }
      }
 
  #local oWedgeTableTop =
    object {
      union {
        object {
          TableTop(fTableWedgeWidth,fTableTopHeight,fTableWedgeDepth,fTableTopEdgeRadius,fTableTopCornerRadius)
          translate (fTableTopWidth-fTableWedgeWidth)/2*x
          }
        object {TableTop(fTableTopWidth,fTableTopHeight,fTableTopDepth,fTableTopEdgeRadius,fTableTopCornerRadius)}
        object {
          TableTop(fTableTopWidth,fTableTopHeight,fTableTopWedgeDepth,fTableTopEdgeRadius,fTableTopCornerRadius)
          translate <-fTableTopCornerRadius,0,-fTableTopCornerRadius>
          rotate -22.5*y
          translate < fTableTopCornerRadius,0, fTableTopCornerRadius>
          }
        object {
          TableTop(fTableTopWidth,fTableTopHeight,fTableTopWedgeDepth,fTableTopEdgeRadius,fTableTopCornerRadius)
          translate <-(fTableTopWidth-fTableTopCornerRadius),0,-fTableTopCornerRadius>
          rotate  22.5*y
          translate < (fTableTopWidth-fTableTopCornerRadius),0, fTableTopCornerRadius>
          }
        }
      translate <-fTableTopWidth/2,(fTableHeight-fTableTopHeight),0>
      texture{vTableTopTexture}
      }
 
  #local vPoint = <fWedgeTableWidth/2-fTableLegXOffset,0,(fTableTopWedgeDepth-fTableBaseDepth)-fTableLegZOffset>;
  #local vPoint = vPoint+<-(fWedgeTableWidth/2-fTableTopCornerRadius),0,-fTableTopCornerRadius>;
  #local vPoint = vrotate(vPoint,22.5*y);
  #local vPoint = vPoint+< (fWedgeTableWidth/2-fTableTopCornerRadius),0, fTableTopCornerRadius>;
  #local fRadius = vPoint.x/sin(radians(22.5));
  #local fDepth  = fRadius*cos(radians(22.5));
  #local fRadius = fRadius+2*fTableBaseDepth/3+fTableLegDepth/2;
  #local fInnerRadius = fRadius-fTableLegWidth/2;
  #local fOuterRadius = fRadius+fTableLegWidth/2;
  
  #local oWedgeTable =
    object {
      union {
        object { oWedgeTableTop }
        object {
          oTableLeg
          translate <fWedgeTableWidth/2-fTableLegXOffset,0,(fTableTopWedgeDepth-fTableBaseDepth)-fTableLegZOffset>
          translate <-(fWedgeTableWidth/2-fTableTopCornerRadius),0,-fTableTopCornerRadius>
          rotate 22.5*y
          translate < (fWedgeTableWidth/2-fTableTopCornerRadius),0, fTableTopCornerRadius>
          texture{vTableLegTexture}
          }
        object {
          oTableLeg
          translate <-(fWedgeTableWidth/2-fTableLegXOffset),0,(fTableTopWedgeDepth-fTableBaseDepth)-fTableLegZOffset>
          translate < (fWedgeTableWidth/2-fTableTopCornerRadius),0,-fTableTopCornerRadius>
          rotate -22.5*y
          translate <-(fWedgeTableWidth/2-fTableTopCornerRadius),0, fTableTopCornerRadius>
          texture{vTableLegTexture}
          }
        object {
          intersection {
            difference {
              cylinder{<0,0,0><0,fTableLegDepth,0>,fOuterRadius}
              cylinder{<0,-0.1,0><0,fTableLegDepth+0.1,0>,fInnerRadius}
              }
            object {Wedge(45) rotate -22.5*y}
            }
          translate (vPoint.z-fDepth)*z
          translate fTableHeight/2*y
          texture{vTableLegTexture}
          }
        object {oTableBackLeg translate  (fTableWedgeDepth-2*fTableLegZOffset)*z texture{vTableLegTexture}}
        box {<-fTableLegWidth/2,fTableHeight/2,vPoint.z-fDepth+fRadius>< fTableLegWidth/2, fTableHeight/2+fTableLegDepth,fTableWedgeDepth-2*fTableLegZOffset> texture{vTableLegTexture}}
        }
      }
 
  #local oTable =
    object {
      #switch(iType)
        #case (1)
          oWedgeTable
        #break
        #case (2)
          oLongTable
        #break
      #end
      scale 1/12
      }
 
  oTable
#end
