#declare fCarrierWidth     = 11.50;
#declare fCarrierHeight    = 4.25;
#declare fCarrierDepth     = 10.00;
#declare fCarrierThickness = 3/16;
   
#macro TapeCarrier(nVol)
  #local fWidth          = fCarrierWidth;
  #local fHeight         = fCarrierHeight;
  #local fDepth          = fCarrierDepth;   
  #local fRadius         = 1/32;
  #local fThickness      = 3/16;
  #local fLipDepth       = 0.75;
  #local fLipRadius      = 0.25;
  #local fSeperatorDepth = 0.875; 
  #local fXGap           = ((fWidth-2*fThickness)-10*f3490Height)/10;
  #local fZGap           = ((fDepth-2*fThickness-fSeperatorDepth)-2*f3490Width)/2;
  #local fZOffset        = fDepth/2+fSeperatorDepth/2;
  #local fDividerDepth   = 1.00;
  #local fDividerHeight  = 3.00;
  #local fDividerRadius  = 0.50;
  #local fDividerEdge    = fXGap/2;
  #local tTexture        = texture{
                             pigment{White*0.05}        
                             finish {reflection 0.1 phong 0.3 phong_size 60} 
                             };
  #local sVolumes = array[20];
  #local i = 0;
  #while (i < 20)
    #if (i < nVol)
      #local sVolumes[i] = str(30000+rand(fTapeSeed)*10000,-6,0);
    #else
      #local sVolumes[i] = "";
    #end
    #local i = i + 1;
  #end
  
                                  
  #local oBaseCarrier =
    object {
      difference {
        object {Round_Box(<0,0,0>,<fWidth,fHeight,fDepth>,fRadius,false)}
        object {Round_Box(<fThickness,fThickness,fThickness>,<fWidth-fThickness,fHeight+0.1,fDepth-fThickness>,fRadius,false)}
        }
      }
  
  #local oLip =
    object {
      union {
        object {Round_Box(<0,0,-(fLipDepth-fLipRadius+fRadius)>,<fWidth,-fThickness,fThickness>,fRadius,false)}
        object {Round_Box(<fLipRadius-fRadius,0,-fLipDepth>,<fWidth-fLipRadius+fRadius,-fThickness,fThickness>,fRadius,false)}
        object {Round_Cylinder(<fLipRadius,0,-(fLipDepth-fLipRadius)>,<fLipRadius,-fThickness,-(fLipDepth-fLipRadius)>,fLipRadius,fRadius,false)}
        object {Round_Cylinder(<fWidth-fLipRadius,0,-(fLipDepth-fLipRadius)>,<fWidth-fLipRadius,-fThickness,-(fLipDepth-fLipRadius)>,fLipRadius,fRadius,false)}
        }
      translate fHeight*y
      }
  
  #local oDividerSide =
    object {
      union {
        box{<-fDividerEdge,0,0>< fDividerEdge,fDividerHeight-fDividerRadius,fDividerDepth>}
        box{<-fDividerEdge,fDividerHeight-fDividerRadius,0><fDividerEdge,fDividerHeight,fDividerDepth-fDividerRadius>}
        cylinder{<-fDividerEdge,fDividerHeight-fDividerRadius,fDividerDepth-fDividerRadius><fDividerEdge,fDividerHeight-fDividerRadius,fDividerDepth-fDividerRadius>,fDividerRadius}
        }
      }
      
  #local oDivider =
    object {
      union {
        object {oDividerSide}
        object {
          oDividerSide
          rotate 180*y
          translate (fDepth-fSeperatorDepth)/2*z
          }
        }
      }
      
  #local oSeperator =
    object {
      Round_Box(<0,0,0>,<fWidth,fHeight,fSeperatorDepth>,fRadius,false)
      }
      
  #local oCarrier =
    object {
      union {
        object {oBaseCarrier}
        object {oLip}
        object {oLip rotate 180*y translate <fWidth,0,fDepth>}
        object {oSeperator translate (fDepth-fSeperatorDepth)/2*z}
        #local ix = 0;
        #while(ix < 10)
          #local iz = 0;
          #while (iz < 2)
            object {
              oDivider
              translate <fThickness+ix*(fWidth-2*fThickness)/10,0,iz*(fDepth+fSeperatorDepth)/2>
              }
            #if (strlen(sVolumes[iz*10+ix]) > 0)      
              object {
                IBM3490Cart(sVolumes[iz*10+ix])
                rotate 90*x
                rotate -90*y
                translate <f3490Height+fThickness,f3490Depth+fThickness,fThickness>
                translate <fXGap/2+ix*(f3490Height+fXGap),0,fZGap/2+iz*(fZOffset-fThickness)>
                }
            #end    
            #local iz = iz + 1;
          #end
          #local ix = ix + 1;
        #end 
        }
      texture{tTexture}
//      scale 1/12
      }
  oCarrier 
#end