#declare fTapeSeed = seed(192304);
#include "TapeCarrier.inc"

#macro TapeCart()
  #local fWidth = 26.00;
  #local fTopDepth = 12.00;
  #local fSideHeight = 30;
  #local fSideDepth = 8.00;
  #local fSideAngle = 15;
  #local fSideWidth = (fWidth-2*fCarrierWidth)/2;
  #local fTopHeight = fSideHeight*cos(radians(fSideAngle));
  #local fBottomHeight = 3.00;
  #local fBottomDepth = 2*fSideHeight*sin(radians(fSideAngle))+fTopDepth;
  #local fRadius = 0.125; 
  #local tTexture = texture{pigment{rgb <0.8,0.8,0.5>}
                             finish {reflection 0.05 phong 0.3 phong_size 60} 
                             };
  
  #local fRadiusEdge   = 0.25;
  #local fWheelRadius  = 1.0;
  #local fWheelWidth   = 1.5;
  #local fWheelHeight  = 2.5;
  #local fWheelAxleRadius = 0.25;
  #local fWheelPivotRadius = 0.50;
  #local fFenderThickness = 0.0625;
  #local fFenderRadius = 1.1875;
  #local fFenderWidth  = 1.5;
  #local fWheelPivotHeight = fWheelHeight-fWheelRadius;
  #local tPedestalTexture = texture{pigment{White*0.10} 
                            normal { bumps 0.04 scale 0.0005 }
                            finish { phong 0.5 }
                            };
  
  #local fHandleRadius = 0.25;
  #local fHandleCorner = 1.00;
  #local fHandleWidth  = 10.00;
  #local fHandleDepth  = 2.0;
  #local fHandleYOffset = fTopHeight-4;
  #local tHandleTexture = T_Chrome_2B;
  
                            
  #local oHandle =
    object {
      union {
        cylinder{<-fHandleWidth/2,0,0><-fHandleWidth/2,0,fHandleDepth-fHandleCorner>,fHandleRadius}
        cylinder{< fHandleWidth/2,0,0>< fHandleWidth/2,0,fHandleDepth-fHandleCorner>,fHandleRadius}
        cylinder{<-(fHandleWidth/2-fHandleCorner),0,fHandleDepth>< (fHandleWidth/2-fHandleCorner),0,fHandleDepth>,fHandleRadius}
        object {
          intersection {
            object {Wedge(90) rotate -90*y} 
            torus{fHandleCorner,fHandleRadius}
            }
          translate <-(fHandleWidth/2-fHandleCorner),0,fHandleDepth-fHandleCorner>
          }
        object {
          intersection {
            object {Wedge(90) } 
            torus{fHandleCorner,fHandleRadius}
            }
          translate < (fHandleWidth/2-fHandleCorner),0,fHandleDepth-fHandleCorner>
          }
        }
      texture{tHandleTexture}  
      }
  
  #local oPivot =
    object {
      difference {
        cylinder {<0,0,0><0,fWheelPivotHeight,0>,fWheelPivotRadius}
        cylinder {<-fFenderWidth/2,0,0><fFenderWidth/2,0,0>,fFenderRadius translate -fWheelPivotRadius*z} 
        }
      }

  #local oCastor =
    object {
      union {
        sphere{<0,0,0>,fWheelRadius scale <0.25,1,1> translate -fWheelWidth/2*x}
        cylinder{<-fWheelWidth/2,0,0><-0.25,0,0>,fWheelRadius}
        cylinder{<-fWheelWidth/2,0,0><fWheelWidth/2,0,0>,fWheelAxleRadius}
        cylinder{< fWheelWidth/2,0,0>< 0.25,0,0>,fWheelRadius}
        sphere{<0,0,0>,fWheelRadius scale <0.25,1,1> translate  fWheelWidth/2*x}
        }
      translate -fWheelPivotRadius*z  
      }

  #local oFenderMask =
    object {
      difference {
        cylinder{<-0.001,0,0><fFenderWidth+0.001,0,0>,fFenderRadius+0.001}
        cylinder{<-0.1,0,0><fFenderWidth+0.1,0,0>,(fFenderRadius-fFenderThickness)+0.001}
        }
      }

  #local oFender =
    object {
      intersection {
        union {
          difference {
            object {
              difference {
                cylinder{<0,0,0><fFenderWidth,0,0>,fFenderRadius+0.1}
                cylinder{<-0.1,0,0><fFenderWidth+0.1,0,0>,fFenderRadius-fFenderThickness}
                }
              }
            union {
              cylinder{<0,0,-(fFenderRadius+0.1)><0,0,fFenderRadius+0.1>,fRadiusEdge }
              cylinder{<0,0,-(fFenderRadius+0.1)><0,0,fFenderRadius+0.1>,fRadiusEdge translate fFenderWidth*x}
              }
            }
          object {  
            union {
              cylinder{<0,0,-(fFenderRadius+0.1)><0,0,fFenderRadius+0.1>,fRadiusEdge translate <fRadiusEdge,fRadiusEdge,0>}
              cylinder{<0,0,-(fFenderRadius+0.1)><0,0,fFenderRadius+0.1>,fRadiusEdge translate <fFenderWidth-fRadiusEdge,fRadiusEdge,0>}
              }
            }  
          }
        object{oFenderMask} 
        } 
      clipped_by{plane{-y,0}}    
      translate -fFenderWidth/2*x
      translate -fWheelPivotRadius*z  
      }
      
  #local oWheel =
    object {
      union {
        object {oCastor}
        object {oFender}
        object {oPivot}
        }
      rotate 90*y
      texture{tPedestalTexture}  
      }
      
  #local oBottom =
    object {
      union {
        object {
          Round_Box(<0,-fRadius,-fRadius>,<fWidth,fBottomHeight+fRadius,fBottomDepth+fRadius>,fRadius,false)
          }
        object {
          oWheel
          translate <1.5,-fWheelPivotHeight,1.5>
          }
        object {
          oWheel
          translate <fWidth-1.5,-fWheelPivotHeight,1.5>
          }
        object {
          oWheel
          translate <1.5,-fWheelPivotHeight,fBottomDepth-1.5>
          }
        object {
          oWheel
          translate <fWidth-1.5,-fWheelPivotHeight,fBottomDepth-1.5>
          }
        }
      }
    
  #local oSide =
    object {
      union {
        object {
          Round_Box(<0,-fRadius,-fRadius>,<fSideWidth,fSideHeight+fRadius,fSideDepth+fRadius>,fRadius,false)
          }
        object {
          Round_Box(<fWidth-fSideWidth,-fRadius,-fRadius>,<fWidth,fSideHeight+fRadius,fSideDepth+fRadius>,fRadius,false)
          }
        object {
          Round_Box(<fSideWidth-2*fRadius,-fRadius,-fRadius>,<fWidth-fSideWidth+2*fRadius,3,1>,fRadius,false)  
          }
        object {
          Round_Box(<fSideWidth-2*fRadius,0,-fRadius>,<fWidth-fSideWidth+2*fRadius,2,1>,fRadius,false)
          translate (3+fCarrierDepth)*y  
          }
        object {
          Round_Box(<fSideWidth-2*fRadius,0,-fRadius>,<fWidth-fSideWidth+2*fRadius,5+fRadius,1>,fRadius,false)
          translate (3+fCarrierDepth+2+fCarrierDepth)*y  
          }
        object {
          TapeCarrier(20)
          rotate -90*x
          translate <fSideWidth,3,-fRadius-fCarrierThickness+fCarrierHeight>
          }  
        object {
          TapeCarrier(20)
          rotate -90*x
          translate <fSideWidth+fCarrierWidth,3,-fRadius-fCarrierThickness+fCarrierHeight>
          }  
        object {
          TapeCarrier(10)
          rotate -90*x
          translate <fSideWidth,3+fCarrierDepth+2,-fRadius-fCarrierThickness+fCarrierHeight>
          }  
        object {
          TapeCarrier(5)
          rotate -90*x
          translate <fSideWidth+fCarrierWidth,3+fCarrierDepth+2,-fRadius-fCarrierThickness+fCarrierHeight>
          }  
        }
      rotate fSideAngle*x
      translate fBottomHeight*y
      }
  
  #local oTop =
    object {
      union {
        object {
          Round_Box(<0,-fRadius,-fRadius>,<fSideWidth,fTopHeight+fRadius,fTopDepth+fRadius>,fRadius,false)
          }
        object {
          oHandle
          rotate -90*y
          translate <0,fHandleYOffset,fTopDepth/2>
          }
        object {
          Round_Box(<fWidth-fSideWidth,-fRadius,-fRadius>,<fWidth,fTopHeight+fRadius,fTopDepth+fRadius>,fRadius,false)
          }
        object {
          oHandle
          rotate  90*y
          translate <fWidth,fHandleYOffset,fTopDepth/2>
          }
        object {
          Round_Box(<0,fTopHeight+fRadius-1,-fRadius>,<fWidth,fTopHeight+fRadius,(fTopDepth-fCarrierDepth)/2>,fRadius,false)
          }  
        object {
          Round_Box(<0,fTopHeight+fRadius-1,fTopDepth+fRadius>,<fWidth,fTopHeight+fRadius,(fTopDepth+fRadius)-(fTopDepth-fCarrierDepth)/2>,fRadius,false)
          }
        object {
          TapeCarrier(15)
          translate <fSideWidth,fTopHeight+fRadius+fCarrierThickness-fCarrierHeight,(fTopDepth-fCarrierDepth)/2>
          }  
        object {
          TapeCarrier(5)
          translate <fSideWidth+fCarrierWidth,fTopHeight+fRadius+fCarrierThickness-fCarrierHeight,(fTopDepth-fCarrierDepth)/2>
          }  
        }
      translate <0,fBottomHeight,(fBottomDepth-fTopDepth)/2>
      }    
  
  #local oCart =
    object {
      union {
        object {oBottom}
        object {
          oSide
          } 
        object {
          oSide
          rotate 180*y
          translate <fWidth,0,fBottomDepth>
          }
        object {
          oTop
          } 
        }
      texture{tTexture}
      translate fWheelHeight*y
      scale 1/12  
      }
  oCart    
#end