#macro Template()
  #local fWidth = 10.0;
  #local fHeight = 1/32;
  #local fDepth = 4.00;
  #local tTemplateTexture = pigment{color rgbf<0,1,0,1>};
  #local fLineWidth = 0.01;
  #local fLineDepth = 0.001;
  #local fXOffset = 0.3;
  #local fZOffset = 0.4;
  
  #local oOverlay =
    object {
      union {
        #local ix = 0;
        #while (ix <= 9.4)
           box{<ix,0,0><ix+fLineWidth,fLineDepth,3.3>}
          #local ix = ix + 0.1;
        #end
        #local iz = 0;
        #while (iz <= 3.3)
           box{<0,0,iz><9.4,fLineDepth,iz+fLineWidth>}
          #local iz = iz + 0.1;
        #end
        }           
      translate <fXOffset,0,fZOffset>
      pigment{Black}
      }
      
  #local oProcess =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 5,
        <0.0,0.0>,<0.0,0.8>,<1.2,0.8>,<1.2,0.0>,<0.0,0.0>
        }
      translate <0.1,0.0,2.4>
      }
  
  #local oInputOutput =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 5,
        <0.0,0.0>,<0.2,0.8>,<1.2,0.8>,<1.0,0.0>,<0.0,0.0>
        }
      translate <1.6,0.0,2.4>
      }
  
  #local fRadius = 0.6;
  #local fDelta  = 0.3;
  #local fOffset = fRadius*(1-cos(asin(fDelta/fRadius)));    
  #local oDocument =
    object {
      union {
        box{<0.0,-0.1,0.4><1.2,fHeight+0.1,0.8>}
        intersection {
          box{<0.0,-0.1,0.0><0.6,fHeight+0.1,0.4>}
          cylinder{<fDelta,-0.1,fRadius><fDelta,fHeight+0.1,fRadius>,fRadius}
          }
        difference {
          box{<0.6,-0.1,0.0><1.2,fHeight+0.1,0.4>}
          cylinder{<0.6+fDelta,-0.1,2*fOffset-fRadius><0.6+fDelta,fHeight+0.1,2*fOffset-fRadius>,fRadius}
          }
        }
      translate <3.1,0.0,2.4>
      }    
  
  #local oManualOperation =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 5,
        <0.3,0.0>,<0.0,0.8>,<1.2,0.8>,<0.9,0.0>,<0.0,0.0>
        }
      translate <4.6,0.0,2.4>
      }
  
  #local oCommunicationLine =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 9,
        <0.05,0.6>,<0.15,0.6>,<0.15,0.1>,<0.35,0.25>,<0.35,-0.4>,<0.25,-0.4>,<0.25,0.1>,<0.05,-0.05>,<0.05,0.6>
        }
      translate <6.0,0.0,2.4>
      }
  
  #local oPreparation =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 7,
        <0.2,0.0>,<0.0,0.4>,<0.2,0.8>,<1.0,0.8>,<1.2,0.4>,<1.0,0.0>,<0.2,0.0>
        }
      translate <6.6,0.0,2.4>
      }
  
  #local oMerge =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 4,
        <0.4,0.2>,<0.0,0.8>,<0.8,0.8>,<0.4,0.2>
        }
      translate <7.9,0.0,2.4>
      }
  
  #local oDecision =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 5,
        <0.0,0.4>,<0.6,0.8>,<1.2,0.4>,<0.6,0.0>,<0.0,0.4>
        }
      translate <0.1,0.0,1.2>
      }
      
  #local oConnector1 =
    object {
      cylinder {
        <0.4,-0.1,0.4><0.4,fHeight+0.1,0.4>,0.4
        }
      translate <1.6,0.0,1.2>
      }
      
  #local oConnector2 =
    object {
      cylinder {
        <0.2,-0.1,0.2><0.2,fHeight+0.1,0.2>,0.2
        }
      translate <1.1,0.0,0.8>
      }
  
  #local fRadius = sqrt(.80);
  #local oDisplay =
    object {
      union {
        intersection {
          box{<0.6,-0.1,0.0><1.2,fHeight+0.1,0.8>}
          cylinder{<0.6,-0.1,0.4><0.6,fHeight+0.1,0.4>,0.6}
          }                                                
        intersection{
          box{<0.0,-0.1,0.0><0.6,fHeight+0.1,0.8>}
          intersection {
            cylinder{<0.8,-0.1,0.0><0.8,fHeight+0.1,0.0>,fRadius}
            cylinder{<0.8,-0.1,0.8><0.8,fHeight+0.1,0.8>,fRadius}
            }
          }  
        }
      translate <2.7,0.0,1.2>
      }
          
  #local oAuxiliaryOperation =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 5,
        <0.0,0.0>,<0.0,0.8>,<0.8,0.8>,<0.8,0.0>,<0.0,0.0>
        }
      translate <4.2,0.0,1.2>
      }
      
  #local oArrowheads1 =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 4,
        <0.0,0.0>,<0.0,0.2>,<0.2,0.1>,<0.0,0.0>
        }
      translate <5.3,0.0,1.5>
      }
      
  #local oArrowheads2 =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 4,
        <0.1,0.0>,<0.0,0.2>,<0.2,0.2>,<0.1,0.0>
        }
      translate <5.6,0.0,1.8>
      }
      
  #local oArrowheads3 =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 4,
        <0.0,0.1>,<0.2,0.2>,<0.2,0.0>,<0.0,0.1>
        }
      translate <5.9,0.0,1.5>
      }
      
  #local oArrowheads4 =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 4,
        <0.0,0.0>,<0.1,0.2>,<0.2,0.0>,<0.0,0.0>
        }
      translate <5.6,0.0,1.2>
      }
      
  #local oManualInput =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 5,
        <0.0,0.0>,<0.0,0.4>,<1.2,0.6>,<1.2,0.0>,<0.0,0.0>
        }
      translate <6.4,0.0,1.3>
      }
      
  #local oExtract =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 4,
        <0.0,0.0>,<0.4,0.8>,<0.8,0.0>,<0.0,0.0>
        }
      translate <7.9,0.0,1.3>
      }
  
  #local oSort =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 5,
        <0.4,0.0>,<0.0,0.7>,<0.4,1.4>,<0.8,0.7>,<0.4,0.0>
        }
      translate <8.5,0.0,1.6>
      }
  
  #local oTerminalInterrupt =
    object {
      union {
        cylinder{<0.2,-0.1,0.2><0.2,fHeight+0.1,0.2>,0.2}
        box{<0.2,-0.1,0.0><1.0,fHeight+0.1,0.4>}
        cylinder{<1.0,-0.1,0.2><1.0,fHeight+0.1,0.2>,0.2}
        }
      translate <0.1,0.0,0.1>
      }
      
  #local oPunchCard =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 6,
        <0.0,0.0>,<0.0,0.5>,<0.1,0.6>,<1.2,0.6>,<1.2,0.0>,<0.0,0.0>
        }
      translate <1.7,0.0,0.1>
      }
  
  #local fRadius = 0.6;
  #local fDelta  = 0.3;
  #local fOffset = fRadius*(1-cos(asin(fDelta/fRadius)));    
  #local oPunchTape =
    object {
      union {
        intersection {
          box{<0.0,-0.1,0.0><0.6,fHeight+0.1,0.3>}
          cylinder{<fDelta,-0.1,fRadius><fDelta,fHeight+0.1,fRadius>,fRadius}
          }
        difference {
          box{<0.0,-0.1,0.3><0.6,fHeight+0.1,0.6>}
          cylinder{<fDelta,-0.1,0.6-2*fOffset+fRadius><fDelta,fHeight+0.1,0.6-2*fOffset+fRadius>,fRadius}
          }
        intersection {
          box{<0.6,-0.1,0.3><1.2,fHeight+0.1,0.6>}
          cylinder{<0.6+fDelta,-0.1,0.6-fRadius><0.6+fDelta,fHeight+0.1,0.6-fRadius>,fRadius}
          }
        difference {
          box{<0.6,-0.1,0.0><1.2,fHeight+0.1,0.3>}
          cylinder{<0.6+fDelta,-0.1,2*fOffset-fRadius><0.6+fDelta,fHeight+0.1,2*fOffset-fRadius>,fRadius}
          }
        }
      translate <3.3,0.0,0.1>
      }    
  
  #local oOnlineStorage =
    object {
      union{
        intersection {
          box{<0.0,-0.1,0.0><0.15,fHeight+0.1,0.8>}
          cylinder{<0.6,-0.1,0.4><0.6,fHeight+0.1,0.4>,0.6}
          }
        difference{  
          box{<0.15,-0.1,0><1.2,fHeight+0.1,0.8>}
          cylinder{<1.65,-0.1,0.4><1.65,fHeight+0.1,0.4>,0.6}
          }
        }
      translate <4.8,0.0,0.1>
      }
          
  #local oKeying =
    object {
      intersection {
        box{<0,-0.1,0><1.5,fHeight+0.1,0.8>}
        union {
          cylinder{<0.6,-0.1,0.4><0.6,fHeight+0.1,0.4>,0.6}
          cylinder{<0.9,-0.1,0.4><0.9,fHeight+0.1,0.4>,0.6}
          }
        }
      translate <6.25,0.0,0.1>
      }
          
  #local oTransmittalTape =
    object {
      difference {
        box{<0,-0.1,0><0.4,fHeight+0.1,0.8>}
        cylinder{<0.0,-0.1,-0.45><0.0,fHeight+0.1,-0.45>,0.6}
        }
      translate <8.1,0.0,0.1>
      }
          
  #local oOffPageConnector =
    object {
      prism {
        linear_spline
        -0.1, fHeight+0.1, 6,
        <0.2,0.0>,<0.0,0.2>,<0.0,0.5>,<0.4,0.5>,<0.4,0.2>,<0.2,0.0>
        }
      translate <8.9,0.0,0.2>
      }
      

  #local oBaseTemplate =
    object {
      union {
        object {
          box{0,1}
          pigment{image_map{gif "Template" transmit 13,1}}
          scale 0.001*z 
          }
        object {
          box{0,1}
          translate 0.001*z
          texture{tTemplateTexture}
          }
        }
      scale <fWidth,fDepth,fHeight>
      rotate 90*x
      }
  
  #local oTemplate =
    object {
      difference {
        object {
          oBaseTemplate
          }
        object {
          union {
            object{oProcess           }
            object{oInputOutput       }
            object{oDocument          }
            object{oManualOperation   }
            object{oCommunicationLine }
            object{oPreparation       }
            object{oMerge             }
            object{oDecision          }
            object{oConnector1        }
            object{oConnector2        }
            object{oDisplay           }
            object{oAuxiliaryOperation}
            object{oArrowheads1       }
            object{oArrowheads2       }
            object{oArrowheads3       }
            object{oArrowheads4       }
            object{oManualInput       }
            object{oExtract           }
            object{oSort              }
            object{oTerminalInterrupt }
            object{oPunchCard         }
            object{oPunchTape         }
            object{oOnlineStorage     }
            object{oKeying            }
            object{oTransmittalTape   }
            object{oOffPageConnector  }
            }
          texture{tTemplateTexture}
          translate <fXOffset,0.0,fZOffset>
          }
        } 
      scale 1/12  
      }
  oTemplate      
#end